@@ -27,6 +27,7 @@ import com.google.common.collect.ImmutableSet;
 import com.google.inject.Injector;
 import com.google.inject.Key;
 import com.google.inject.multibindings.MapBinder;
+import org.apache.druid.data.input.impl.DimensionsSpec;
 import org.apache.druid.frame.FrameType;
 import org.apache.druid.frame.read.FrameReader;
 import org.apache.druid.frame.segment.FrameSegment;
@@ -61,6 +62,7 @@ import org.apache.druid.query.aggregation.datasketches.theta.sql.ThetaSketchEsti
 import org.apache.druid.query.aggregation.datasketches.tuple.ArrayOfDoublesSketchModule;
 import org.apache.druid.query.lookup.LookupExtractor;
 import org.apache.druid.query.policy.NoopPolicyEnforcer;
+import org.apache.druid.segment.AutoTypeColumnSchema;
 import org.apache.druid.segment.IncrementalIndexSegment;
 import org.apache.druid.segment.IndexSpec;
 import org.apache.druid.segment.PhysicalSegmentInspector;
@@ -74,6 +76,8 @@ import org.apache.druid.segment.data.FrontCodedIndexed;
 import org.apache.druid.segment.generator.SegmentGenerator;
 import org.apache.druid.segment.incremental.IncrementalIndex;
 import org.apache.druid.segment.join.JoinableFactoryWrapper;
+import org.apache.druid.segment.nested.NestedCommonFormatColumnFormatSpec;
+import org.apache.druid.segment.nested.ObjectStorageEncoding;
 import org.apache.druid.server.QueryStackTests;
 import org.apache.druid.server.SpecificSegmentsQuerySegmentWalker;
 import org.apache.druid.server.security.AuthConfig;
@@ -100,6 +104,7 @@ import org.apache.druid.sql.calcite.util.QueryFrameworkUtils;
 import org.apache.druid.sql.calcite.util.testoperator.CalciteTestOperatorModule;
 import org.apache.druid.sql.hook.DruidHookDispatcher;
 import org.apache.druid.timeline.DataSegment;
+import org.apache.druid.timeline.SegmentId;
 import org.openjdk.jmh.annotations.Level;
 import org.openjdk.jmh.annotations.Param;
 import org.openjdk.jmh.annotations.Scope;
@@ -109,6 +114,7 @@ import org.openjdk.jmh.annotations.TearDown;
 
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -177,6 +183,12 @@ public class SqlBaseBenchmark
   })
   protected String complexCompression;
 
+  @Param({
+      "NONE",
+      "SMILE"
+  })
+  protected ObjectStorageEncoding jsonObjectStorageEncoding;
+
   @Param({
       "explicit",
       "auto"
@@ -238,13 +250,14 @@ public class SqlBaseBenchmark
 
     Map<DataSegment, IncrementalIndex> realtimeSegments = new HashMap<>();
     Map<DataSegment, QueryableIndex> segments = new HashMap<>();
+    NestedCommonFormatColumnFormatSpec columnFormatSpec = NestedCommonFormatColumnFormatSpec
+        .builder()
+        .setObjectStorageEncoding(jsonObjectStorageEncoding)
+        .build();
     for (String dataSource : getDatasources()) {
-      final SqlBenchmarkDatasets.BenchmarkSchema schema;
-      if ("auto".equals(schemaType)) {
-        schema = SqlBenchmarkDatasets.getSchema(dataSource).asAutoDimensions();
-      } else {
-        schema = SqlBenchmarkDatasets.getSchema(dataSource);
-      }
+      final SqlBenchmarkDatasets.BenchmarkSchema schema =
+          SqlBenchmarkDatasets.getSchema(dataSource)
+                              .convertDimensions("auto".equals(schemaType), columnFormatSpec);
 
       for (DataSegment dataSegment : schema.getDataSegments()) {
         final SegmentGenerator segmentGenerator = closer.register(new SegmentGenerator());
@@ -355,6 +368,18 @@ public class SqlBaseBenchmark
 
   private void checkIncompatibleParameters()
   {
+    // we only support NONE object storage encoding for auto column with mmap segments
+    if (ObjectStorageEncoding.NONE.equals(jsonObjectStorageEncoding)) {
+      boolean hasAutoColumn = "auto".equals(schemaType) || getDatasources().stream()
+                                                                           .map(SqlBenchmarkDatasets::getSchema)
+                                                                           .map(SqlBenchmarkDatasets.BenchmarkSchema::getDimensionsSpec)
+                                                                           .map(DimensionsSpec::getDimensions)
+                                                                           .flatMap(Collection::stream)
+                                                                           .anyMatch(x -> x instanceof AutoTypeColumnSchema);
+      if (!hasAutoColumn || !BenchmarkStorage.MMAP.equals(storageType)) {
+        System.exit(0);
+      }
+    }
     // if running as fork 0, maybe don't use these combinations since it will kill everything
     if (stringEncoding != BenchmarkStringEncodingStrategy.UTF8 && storageType != BenchmarkStorage.MMAP) {
       System.exit(0);
@@ -364,7 +389,8 @@ public class SqlBaseBenchmark
       System.exit(0);
     }
     // vectorize only works for mmap and frame column segments, bail out if
-    if (vectorizeContext.shouldVectorize(true) && !(storageType == BenchmarkStorage.MMAP || storageType == BenchmarkStorage.FRAME_COLUMNAR)) {
+    if (vectorizeContext.shouldVectorize(true) && !(storageType == BenchmarkStorage.MMAP
+                                                    || storageType == BenchmarkStorage.FRAME_COLUMNAR)) {
       System.exit(0);
     }
   }
@@ -479,6 +505,12 @@ public class SqlBaseBenchmark
               FrameReader.create(cursorFactory.getRowSignature())
           )
           {
+            @Override
+            public SegmentId getId()
+            {
+              return descriptor.getId();
+            }
+
             @Nullable
             @Override
             public <T> T as(@Nonnull Class<T> clazz)
@@ -500,6 +532,12 @@ public class SqlBaseBenchmark
               FrameReader.create(cursorFactory.getRowSignature())
           )
           {
+            @Override
+            public SegmentId getId()
+            {
+              return descriptor.getId();
+            }
+
             @Nullable
             @Override
             public <T> T as(@Nonnull Class<T> clazz)
