@@ -21,11 +21,9 @@ package org.apache.druid.server.coordinator;
 
 import com.google.common.collect.ImmutableList;
 import org.apache.druid.client.DataSourcesSnapshot;
-import org.apache.druid.jackson.DefaultObjectMapper;
 import org.apache.druid.java.util.common.DateTimes;
 import org.apache.druid.server.compaction.CompactionCandidateSearchPolicy;
 import org.apache.druid.server.compaction.CompactionSegmentIterator;
-import org.apache.druid.server.compaction.CompactionStatusTracker;
 import org.apache.druid.server.compaction.NewestSegmentFirstPolicy;
 import org.apache.druid.server.compaction.PriorityBasedCompactionSegmentIterator;
 import org.apache.druid.timeline.DataSegment;
@@ -137,8 +135,7 @@ public class NewestSegmentFirstPolicyBenchmark
         policy,
         compactionConfigs,
         dataSources,
-        Collections.emptyMap(),
-        new CompactionStatusTracker(new DefaultObjectMapper())
+        Collections.emptyMap()
     );
     for (int i = 0; i < numCompactionTaskSlots && iterator.hasNext(); i++) {
       blackhole.consume(iterator.next());
