@@ -22,11 +22,11 @@ package org.apache.druid.compressedbigdecimal;
 
 import com.google.common.base.Supplier;
 import org.apache.druid.java.util.common.IAE;
-import org.apache.druid.java.util.common.io.smoosh.SmooshedFileMapper;
 import org.apache.druid.segment.IndexIO;
 import org.apache.druid.segment.column.ComplexColumn;
 import org.apache.druid.segment.data.CompressedVSizeColumnarIntsSupplier;
 import org.apache.druid.segment.data.V3CompressedVSizeColumnarMultiIntsSupplier;
+import org.apache.druid.segment.file.SegmentFileMapper;
 
 import java.nio.ByteBuffer;
 
@@ -41,12 +41,12 @@ public class CompressedBigDecimalColumnPartSupplier implements Supplier<ComplexC
    * Compressed.
    *
    * @param buffer Byte buffer
-   * @param smooshMapper mapper for secondary files, in case of large columns
+   * @param fileMapper mapper for secondary files, in case of large columns
    * @return new instance of CompressedBigDecimalColumnPartSupplier
    */
   public static CompressedBigDecimalColumnPartSupplier fromByteBuffer(
       ByteBuffer buffer,
-      SmooshedFileMapper smooshMapper
+      SegmentFileMapper fileMapper
   )
   {
     byte versionFromBuffer = buffer.get();
@@ -57,11 +57,11 @@ public class CompressedBigDecimalColumnPartSupplier implements Supplier<ComplexC
       CompressedVSizeColumnarIntsSupplier scaleSupplier = CompressedVSizeColumnarIntsSupplier.fromByteBuffer(
           buffer,
           IndexIO.BYTE_ORDER,
-          smooshMapper
+          fileMapper
       );
 
       V3CompressedVSizeColumnarMultiIntsSupplier magnitudeSupplier =
-          V3CompressedVSizeColumnarMultiIntsSupplier.fromByteBuffer(buffer, IndexIO.BYTE_ORDER, smooshMapper);
+          V3CompressedVSizeColumnarMultiIntsSupplier.fromByteBuffer(buffer, IndexIO.BYTE_ORDER, fileMapper);
 
       return new CompressedBigDecimalColumnPartSupplier(
           buffer.position() - positionStart,
