@@ -20,11 +20,15 @@
 package org.apache.druid.emitter.prometheus;
 
 import io.prometheus.client.SimpleCollector;
+import org.apache.druid.error.DruidException;
 import org.apache.druid.java.util.common.Stopwatch;
 import org.apache.druid.java.util.common.logger.Logger;
 import org.joda.time.Duration;
 
 import javax.annotation.Nullable;
+import java.util.List;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
 
 public class DimensionsAndCollector
 {
@@ -33,7 +37,7 @@ public class DimensionsAndCollector
   private final SimpleCollector collector;
   private final double conversionFactor;
   private final double[] histogramBuckets;
-  private final Stopwatch updateTimer;
+  private final ConcurrentHashMap<List<String>, Stopwatch> labelValuesToStopwatch;
   private final Duration ttlSeconds;
 
   DimensionsAndCollector(String[] dimensions, SimpleCollector collector, double conversionFactor, double[] histogramBuckets, @Nullable Integer ttlSeconds)
@@ -42,7 +46,7 @@ public class DimensionsAndCollector
     this.collector = collector;
     this.conversionFactor = conversionFactor;
     this.histogramBuckets = histogramBuckets;
-    this.updateTimer = Stopwatch.createStarted();
+    this.labelValuesToStopwatch = new ConcurrentHashMap<>();
     this.ttlSeconds = ttlSeconds != null ? Duration.standardSeconds(ttlSeconds) : null;
   }
 
@@ -66,22 +70,45 @@ public class DimensionsAndCollector
     return histogramBuckets;
   }
 
-  public void resetLastUpdateTime()
-  {
-    updateTimer.restart();
-  }
-
-  public long getMillisSinceLastUpdate()
-  {
-    return updateTimer.millisElapsed();
-  }
-
-  public boolean isExpired()
+  /**
+   * For each unique set of labelValues, keeps track of the amount of time that has elapsed since its metric
+   * value has been updated. Label tracking is only required if a metric TTL has been configured
+   */
+  public void resetLastUpdateTime(List<String> labelValues)
   {
     if (ttlSeconds == null) {
-      log.error("Invalid usage of isExpired(), TTL has not been set");
-      return false;
+      return;
     }
-    return updateTimer.hasElapsed(ttlSeconds);
+    labelValuesToStopwatch.compute(labelValues, (k, v) -> {
+      if (v != null) {
+        v.restart();
+        return v;
+      } else {
+        return Stopwatch.createStarted();
+      }
+    });
+  }
+
+  public ConcurrentMap<List<String>, Stopwatch> getLabelValuesToStopwatch()
+  {
+    return labelValuesToStopwatch;
+  }
+
+  /**
+   * For the given labelValues, checks if the metric value has been updated within the configured {@link #ttlSeconds}.
+   * Returns true and removes the entry from the map if it has expired or if the entry doesn't exist, otherwise
+   * returns false.
+   */
+  public boolean shouldRemoveIfExpired(List<String> labelValues)
+  {
+    if (ttlSeconds == null) {
+      throw DruidException.defensive("Invalid usage of shouldRemoveIfExpired, ttlSeconds has not been set");
+    }
+    return labelValuesToStopwatch.computeIfPresent(labelValues, (k, v) -> {
+      if (v.hasElapsed(ttlSeconds)) {
+        return null;
+      }
+      return v;
+    }) == null;
   }
 }
