@@ -20,6 +20,7 @@
 package org.apache.druid.emitter.prometheus;
 
 
+import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.ImmutableMap;
 import io.prometheus.client.CollectorRegistry;
 import io.prometheus.client.Counter;
@@ -36,6 +37,8 @@ import org.apache.druid.java.util.emitter.service.ServiceMetricEvent;
 import java.io.IOException;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.util.Arrays;
+import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
@@ -72,6 +75,12 @@ public class PrometheusEmitter implements Emitter
     metrics = new Metrics(config);
   }
 
+  public PrometheusEmitter(PrometheusEmitterConfig config, ScheduledExecutorService exec)
+  {
+    this(config);
+    this.exec = exec;
+  }
+
   @Override
   public void start()
   {
@@ -87,7 +96,7 @@ public class PrometheusEmitter implements Emitter
         log.error("HTTPServer is already started");
       }
       // Start TTL scheduler if TTL is configured
-      if (config.getFlushPeriod() != null) {
+      if (config.getFlushPeriod() != null && exec == null) {
         exec = ScheduledExecutors.fixed(1, "PrometheusTTLExecutor-%s");
         exec.scheduleAtFixedRate(
             this::cleanUpStaleMetrics,
@@ -170,15 +179,20 @@ public class PrometheusEmitter implements Emitter
       }
 
       if (metric.getCollector() instanceof Counter) {
-        ((Counter) metric.getCollector()).labels(labelValues).inc(value.doubleValue());
-        metric.resetLastUpdateTime();
+        double metricValue = value.doubleValue();
+        if (metricValue >= 0) {
+          ((Counter) metric.getCollector()).labels(labelValues).inc(metricValue);
+          metric.resetLastUpdateTime(Arrays.asList(labelValues));
+        } else {
+          log.warn("Counter increment amount must be non-negative, but got value[%f] for metric[%s]. If this is valid, metric should be defined as a gauge instead of counter.", metricValue, name);
+        }
       } else if (metric.getCollector() instanceof Gauge) {
         ((Gauge) metric.getCollector()).labels(labelValues).set(value.doubleValue());
-        metric.resetLastUpdateTime();
+        metric.resetLastUpdateTime(Arrays.asList(labelValues));
       } else if (metric.getCollector() instanceof Histogram) {
         ((Histogram) metric.getCollector()).labels(labelValues)
                                            .observe(value.doubleValue() / metric.getConversionFactor());
-        metric.resetLastUpdateTime();
+        metric.resetLastUpdateTime(Arrays.asList(labelValues));
       } else {
         log.error("Unrecognized metric type [%s]", metric.getCollector().getClass());
       }
@@ -277,7 +291,8 @@ public class PrometheusEmitter implements Emitter
    * This method is called periodically by the TTL scheduler when using the 'exporter' strategy with
    * a configured flushPeriod.
    */
-  private void cleanUpStaleMetrics()
+  @VisibleForTesting
+  protected void cleanUpStaleMetrics()
   {
     if (config.getFlushPeriod() == null) {
       return;
@@ -286,13 +301,15 @@ public class PrometheusEmitter implements Emitter
     Map<String, DimensionsAndCollector> map = metrics.getRegisteredMetrics();
     for (Map.Entry<String, DimensionsAndCollector> entry : map.entrySet()) {
       DimensionsAndCollector metric = entry.getValue();
-      if (metric.isExpired()) {
-        log.debug(
-            "Metric [%s] has expired (last updated [%d] ms ago)",
-            entry.getKey(),
-            metric.getMillisSinceLastUpdate()
-        );
-        metric.getCollector().clear();
+      for (List<String> labelValues : metric.getLabelValuesToStopwatch().keySet()) {
+        if (metric.shouldRemoveIfExpired(labelValues)) {
+          log.debug(
+              "Metric [%s] with labels [%s] has expired",
+              entry.getKey(),
+              labelValues
+          );
+          metric.getCollector().remove(labelValues.toArray(new String[0]));
+        }
       }
     }
   }
