@@ -24,15 +24,20 @@ import io.prometheus.client.Collector;
 import io.prometheus.client.CollectorRegistry;
 import io.prometheus.client.exporter.HTTPServer;
 import io.prometheus.client.exporter.PushGateway;
+import org.apache.druid.java.util.common.concurrent.ScheduledExecutors;
 import org.apache.druid.java.util.emitter.core.Emitter;
 import org.apache.druid.java.util.emitter.service.ServiceMetricEvent;
 import org.easymock.EasyMock;
+import org.junit.After;
 import org.junit.Assert;
 import org.junit.Test;
 
 import java.io.IOException;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.concurrent.ExecutionException;
+import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 
 import static org.easymock.EasyMock.anyObject;
@@ -45,7 +50,6 @@ public class PrometheusEmitterTest
   @Test
   public void testEmitterWithServiceLabel()
   {
-    CollectorRegistry.defaultRegistry.clear();
     PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, null, null, 0, null, false, true, 60, null, false, null);
     PrometheusEmitterModule prometheusEmitterModule = new PrometheusEmitterModule();
     Emitter emitter = prometheusEmitterModule.getEmitter(config);
@@ -66,7 +70,6 @@ public class PrometheusEmitterTest
   @Test
   public void testEmitterWithServiceAndHostLabel()
   {
-    CollectorRegistry.defaultRegistry.clear();
     PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, null, null, 0, null, true, true, 60, null, false, null);
     PrometheusEmitterModule prometheusEmitterModule = new PrometheusEmitterModule();
     Emitter emitter = prometheusEmitterModule.getEmitter(config);
@@ -87,7 +90,6 @@ public class PrometheusEmitterTest
   @Test
   public void testEmitterWithExtraLabels()
   {
-    CollectorRegistry.defaultRegistry.clear();
     Map<String, String> extraLabels = new HashMap<>();
     extraLabels.put("labelName", "labelValue");
     PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, null, null, 0, null, false, false, 60, extraLabels, false, null);
@@ -109,7 +111,6 @@ public class PrometheusEmitterTest
   @Test
   public void testEmitterWithServiceLabelAndExtraLabel()
   {
-    CollectorRegistry.defaultRegistry.clear();
     Map<String, String> extraLabels = new HashMap<>();
     extraLabels.put("labelName", "labelValue");
     PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, null, null, 0, null, false, true, 60, extraLabels, false, null);
@@ -131,7 +132,6 @@ public class PrometheusEmitterTest
   @Test
   public void testEmitterWithEmptyExtraLabels()
   {
-    CollectorRegistry.defaultRegistry.clear();
     Map<String, String> extraLabels = new HashMap<>();
     PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, null, null, 0, null, false, true, 60, extraLabels, false, null);
     PrometheusEmitterModule prometheusEmitterModule = new PrometheusEmitterModule();
@@ -152,7 +152,6 @@ public class PrometheusEmitterTest
   @Test
   public void testEmitterWithMultipleExtraLabels()
   {
-    CollectorRegistry.defaultRegistry.clear();
     Map<String, String> extraLabels = new HashMap<>();
     extraLabels.put("labelName1", "labelValue1");
     extraLabels.put("labelName2", "labelValue2");
@@ -175,7 +174,6 @@ public class PrometheusEmitterTest
   @Test
   public void testEmitterWithLabelCollision()
   {
-    CollectorRegistry.defaultRegistry.clear();
     // ExtraLabels contains a label that collides with a service label
     Map<String, String> extraLabels = new HashMap<>();
     extraLabels.put("server", "collisionLabelValue");
@@ -205,7 +203,6 @@ public class PrometheusEmitterTest
   @Test
   public void testEmitterMetric()
   {
-    CollectorRegistry.defaultRegistry.clear();
     PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.pushgateway, "namespace", null, 0, "pushgateway", true, true, 60, null, false, null);
     PrometheusEmitterModule prometheusEmitterModule = new PrometheusEmitterModule();
     Emitter emitter = prometheusEmitterModule.getEmitter(config);
@@ -433,15 +430,17 @@ public class PrometheusEmitterTest
   }
 
   @Test
-  public void testMetricTtlExpiration()
+  public void testMetricTtlExpiration() throws ExecutionException, InterruptedException
   {
     int flushPeriod = 3;
-    PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, "test", null, 0, null, false, true, flushPeriod, null, false, null);
-    PrometheusEmitter emitter = new PrometheusEmitter(config);
+    PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, "test", null, 0, null, true, true, flushPeriod, null, false, null);
+    ScheduledExecutorService exec = ScheduledExecutors.fixed(1, "PrometheusTTLExecutor-%s");
+    PrometheusEmitter emitter = new PrometheusEmitter(config, exec);
     emitter.start();
 
     ServiceMetricEvent event = ServiceMetricEvent.builder()
                                                  .setMetric("segment/loadQueue/count", 10)
+                                                 .setDimension("server", "historical1")
                                                  .build(ImmutableMap.of("service", "historical", "host", "druid.test.cn"));
     emitter.emit(event);
 
@@ -452,34 +451,29 @@ public class PrometheusEmitterTest
     Assert.assertNotNull("Test metric should be registered", testMetric);
     Assert.assertFalse(
         "Metric should not be expired initially",
-        testMetric.isExpired()
+        testMetric.shouldRemoveIfExpired(Arrays.asList("historical", "druid.test.cn", "historical1"))
     );
+    Assert.assertEquals(1, testMetric.getCollector().collect().get(0).samples.size());
 
     // Wait for the metric to expire (ttl + 1 second buffer)
-    try {
-      Thread.sleep(TimeUnit.SECONDS.toMillis(flushPeriod) + 1000);
-    }
-    catch (InterruptedException e) {
-      Thread.currentThread().interrupt();
-    }
-
-    Assert.assertTrue(
-        "Metric should be expired after TTL",
-        testMetric.isExpired()
-    );
+    Thread.sleep(TimeUnit.SECONDS.toMillis(flushPeriod) + 1000);
+    exec.submit(emitter::cleanUpStaleMetrics).get();
+    Assert.assertEquals(0, testMetric.getCollector().collect().get(0).samples.size());
     emitter.close();
   }
 
   @Test
-  public void testMetricTtlUpdate()
+  public void testMetricTtlUpdate() throws ExecutionException, InterruptedException
   {
     int flushPeriod = 3;
-    PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, "test", null, 0, null, false, true, flushPeriod, null, false, null);
-    PrometheusEmitter emitter = new PrometheusEmitter(config);
+    PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, "test", null, 0, null, true, true, flushPeriod, null, false, null);
+    ScheduledExecutorService exec = ScheduledExecutors.fixed(1, "PrometheusTTLExecutor-%s");
+    PrometheusEmitter emitter = new PrometheusEmitter(config, exec);
     emitter.start();
 
     ServiceMetricEvent event = ServiceMetricEvent.builder()
                                                  .setMetric("segment/loadQueue/count", 10)
+                                                 .setDimension("server", "historical1")
                                                  .build(ImmutableMap.of("service", "historical", "host", "druid.test.cn"));
     emitter.emit(event);
 
@@ -493,29 +487,127 @@ public class PrometheusEmitterTest
     );
     Assert.assertFalse(
         "Metric should not be expired initially",
-        testMetric.isExpired()
+        testMetric.shouldRemoveIfExpired(Arrays.asList("historical", "druid.test.cn", "historical1"))
     );
+    Assert.assertEquals(1, testMetric.getCollector().collect().get(0).samples.size());
 
     // Wait for a little, but not long enough for the metric to expire
     long waitTime = TimeUnit.SECONDS.toMillis(flushPeriod) / 5;
-    try {
-      Thread.sleep(waitTime);
-    }
-    catch (InterruptedException e) {
-      Thread.currentThread().interrupt();
-    }
+    Thread.sleep(waitTime);
 
     Assert.assertFalse(
         "Metric should not be expired",
-        testMetric.isExpired()
-    );
-    emitter.emit(event);
-
-    long timeSinceLastUpdate = testMetric.getMillisSinceLastUpdate();
-    Assert.assertTrue(
-        "Update time should have been refreshed",
-        timeSinceLastUpdate < waitTime
+        testMetric.shouldRemoveIfExpired(Arrays.asList("historical", "druid.test.cn", "historical1"))
     );
+    exec.submit(emitter::cleanUpStaleMetrics).get();
+    Assert.assertEquals(1, testMetric.getCollector().collect().get(0).samples.size());
     emitter.close();
   }
+
+  @Test
+  public void testMetricTtlUpdateWithDifferentLabels() throws ExecutionException, InterruptedException
+  {
+    int flushPeriod = 3;
+    PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, "test", null, 0, null, true, true, flushPeriod, null, false, null);
+    ScheduledExecutorService exec = ScheduledExecutors.fixed(1, "PrometheusTTLExecutor-%s");
+    PrometheusEmitter emitter = new PrometheusEmitter(config, exec);
+    emitter.start();
+
+    ServiceMetricEvent event1 = ServiceMetricEvent.builder()
+                                                 .setMetric("segment/loadQueue/count", 10)
+                                                 .setDimension("server", "historical1")
+                                                 .build(ImmutableMap.of("service", "historical", "host", "druid.test.cn"));
+    ServiceMetricEvent event2 = ServiceMetricEvent.builder()
+                                                  .setMetric("segment/loadQueue/count", 10)
+                                                  .setDimension("server", "historical2")
+                                                  .build(ImmutableMap.of("service", "historical", "host", "druid.test.cn"));
+    emitter.emit(event1);
+    emitter.emit(event2);
+
+    // Get the metrics and check that it's not expired initially
+    Map<String, DimensionsAndCollector> registeredMetrics = emitter.getMetrics().getRegisteredMetrics();
+    DimensionsAndCollector testMetric = registeredMetrics.get("segment/loadQueue/count");
+
+    Assert.assertNotNull(
+        "Test metric should be registered",
+        testMetric
+    );
+    Assert.assertFalse(
+        "Metric should not be expired initially",
+        testMetric.shouldRemoveIfExpired(Arrays.asList("historical", "druid.test.cn", "historical1"))
+    );
+    Assert.assertFalse(
+        "Metric should not be expired initially",
+        testMetric.shouldRemoveIfExpired(Arrays.asList("historical", "druid.test.cn", "historical2"))
+    );
+    exec.submit(emitter::cleanUpStaleMetrics).get();
+    Assert.assertEquals(2, testMetric.getCollector().collect().get(0).samples.size());
+
+    // Wait for a little, but not long enough for the metric to expire
+    long waitTime = TimeUnit.SECONDS.toMillis(flushPeriod) / 5;
+    Thread.sleep(waitTime);
+
+    Assert.assertFalse(
+        "Metric should not be expired",
+        testMetric.shouldRemoveIfExpired(Arrays.asList("historical", "druid.test.cn", "historical1"))
+    );
+    Assert.assertFalse(
+        "Metric should not be expired",
+        testMetric.shouldRemoveIfExpired(Arrays.asList("historical", "druid.test.cn", "historical2"))
+    );
+    exec.submit(emitter::cleanUpStaleMetrics).get();
+    Assert.assertEquals(2, testMetric.getCollector().collect().get(0).samples.size());
+    // Reset update time only for event2
+    emitter.emit(event2);
+
+    // Wait for the remainder of the TTL to allow event1 to expire
+    Thread.sleep(waitTime * 4);
+
+    exec.submit(emitter::cleanUpStaleMetrics).get();
+    Assert.assertEquals(1, testMetric.getCollector().collect().get(0).samples.size());
+    emitter.close();
+  }
+
+  @Test
+  public void testLabelsNotTrackedWithTtlUnset()
+  {
+    PrometheusEmitterConfig flushPeriodNull = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, "test", null, 0, null, true, true, null, null, false, null);
+    PrometheusEmitterConfig flushPeriodSet = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, "test", null, 0, null, true, true, 3, null, false, null);
+
+    PrometheusEmitter emitter = new PrometheusEmitter(flushPeriodNull);
+    ServiceMetricEvent event = ServiceMetricEvent.builder()
+            .setMetric("segment/loadQueue/count", 10)
+            .setDimension("server", "historical1")
+            .build(ImmutableMap.of("service", "historical", "host", "druid.test.cn"));
+    emitter.emit(event);
+    DimensionsAndCollector metric = emitter.getMetrics().getRegisteredMetrics().get("segment/loadQueue/count");
+    Assert.assertEquals(0, metric.getLabelValuesToStopwatch().size());
+    emitter.close();
+    CollectorRegistry.defaultRegistry.clear();
+
+    emitter = new PrometheusEmitter(flushPeriodSet);
+    emitter.emit(event);
+    metric = emitter.getMetrics().getRegisteredMetrics().get("segment/loadQueue/count");
+    Assert.assertEquals(1, metric.getLabelValuesToStopwatch().size());
+    emitter.close();
+  }
+
+  @Test
+  public void testCounterWithNegativeValue()
+  {
+    PrometheusEmitterConfig config = new PrometheusEmitterConfig(PrometheusEmitterConfig.Strategy.exporter, "test", null, 0, null, true, true, null, null, false, null);
+    PrometheusEmitter emitter = new PrometheusEmitter(config);
+    ServiceMetricEvent event = ServiceMetricEvent.builder()
+            .setMetric("segment/moveSkipped/count", -1)
+            .setDimension("server", "historical1")
+            .build(ImmutableMap.of("service", "historical", "host", "druid.test.cn"));
+    emitter.emit(event);
+    emitter.close();
+  }
+
+  @After
+  public void tearDown()
+  {
+    CollectorRegistry.defaultRegistry.clear();
+  }
 }
