@@ -20,9 +20,9 @@
 package org.apache.druid.segment;
 
 import com.google.common.collect.ImmutableList;
+import org.apache.druid.collections.BlockingPool;
 import org.apache.druid.collections.DefaultBlockingPool;
 import org.apache.druid.collections.StupidPool;
-import org.apache.druid.common.config.NullHandling;
 import org.apache.druid.data.input.MapBasedRow;
 import org.apache.druid.error.DruidException;
 import org.apache.druid.jackson.DefaultObjectMapper;
@@ -44,6 +44,7 @@ import org.apache.druid.query.groupby.GroupByQueryConfig;
 import org.apache.druid.query.groupby.GroupByQueryQueryToolChest;
 import org.apache.druid.query.groupby.GroupByQueryRunnerFactory;
 import org.apache.druid.query.groupby.GroupByResourcesReservationPool;
+import org.apache.druid.query.groupby.GroupByStatsProvider;
 import org.apache.druid.query.groupby.GroupingEngine;
 import org.apache.druid.query.groupby.ResultRow;
 import org.apache.druid.query.spec.MultipleIntervalSegmentSpec;
@@ -70,8 +71,14 @@ public class MapVirtualColumnGroupByTest extends InitializedNullHandlingTest
   {
     final IncrementalIndex incrementalIndex = MapVirtualColumnTestBase.generateIndex();
     final GroupByQueryConfig config = new GroupByQueryConfig();
+
+    final BlockingPool<ByteBuffer> mergePool =
+        new DefaultBlockingPool<>(() -> ByteBuffer.allocate(1024), 1);
+    final GroupByStatsProvider groupByStatsProvider = new GroupByStatsProvider();
+
     final GroupByResourcesReservationPool groupByResourcesReservationPool =
-        new GroupByResourcesReservationPool(new DefaultBlockingPool<>(() -> ByteBuffer.allocate(1024), 1), config);
+        new GroupByResourcesReservationPool(mergePool, config);
+
     final GroupingEngine groupingEngine = new GroupingEngine(
         new DruidProcessingConfig()
         {
@@ -103,7 +110,8 @@ public class MapVirtualColumnGroupByTest extends InitializedNullHandlingTest
         groupByResourcesReservationPool,
         TestHelper.makeJsonMapper(),
         new DefaultObjectMapper(),
-        QueryRunnerTestHelper.NOOP_QUERYWATCHER
+        QueryRunnerTestHelper.NOOP_QUERYWATCHER,
+        groupByStatsProvider
     );
 
     final GroupByQueryRunnerFactory factory = new GroupByQueryRunnerFactory(
@@ -253,14 +261,7 @@ public class MapVirtualColumnGroupByTest extends InitializedNullHandlingTest
     );
 
     final List<ResultRow> result = runner.run(QueryPlus.wrap(query)).toList();
-    final List<ResultRow> expected;
-    if (NullHandling.sqlCompatible()) {
-      expected = Collections.emptyList();
-    } else {
-      expected = ImmutableList.of(
-          new MapBasedRow(DateTimes.of("2011-01-12T00:00:00.000Z"), MapVirtualColumnTestBase.mapOf("count", 2L))
-      ).stream().map(row -> ResultRow.fromLegacyRow(row, query)).collect(Collectors.toList());
-    }
+    final List<ResultRow> expected = Collections.emptyList();
 
     Assert.assertEquals(expected, result);
   }
@@ -284,14 +285,7 @@ public class MapVirtualColumnGroupByTest extends InitializedNullHandlingTest
     );
 
     final List<ResultRow> result = runner.run(QueryPlus.wrap(query)).toList();
-    final List<ResultRow> expected;
-    if (NullHandling.sqlCompatible()) {
-      expected = Collections.emptyList();
-    } else {
-      expected = ImmutableList.of(
-          new MapBasedRow(DateTimes.of("2011-01-12T00:00:00.000Z"), MapVirtualColumnTestBase.mapOf("count", 2L))
-      ).stream().map(row -> ResultRow.fromLegacyRow(row, query)).collect(Collectors.toList());
-    }
+    final List<ResultRow> expected = Collections.emptyList();
 
     Assert.assertEquals(expected, result);
   }
