@@ -85,7 +85,7 @@ public class SketchBufferAggregator implements BufferAggregator
   @Override
   public void close()
   {
-    helper.close();
+    helper.clear();
   }
 
   @Override
