@@ -52,6 +52,7 @@ import org.apache.druid.indexing.common.task.Task;
 import org.apache.druid.indexing.common.task.batch.parallel.ParallelIndexTuningConfig;
 import org.apache.druid.java.util.common.HumanReadableBytes;
 import org.apache.druid.k8s.overlord.KubernetesTaskRunnerConfig;
+import org.apache.druid.k8s.overlord.KubernetesTaskRunnerStaticConfig;
 import org.apache.druid.k8s.overlord.common.DruidK8sConstants;
 import org.apache.druid.k8s.overlord.common.K8sTaskId;
 import org.apache.druid.k8s.overlord.common.K8sTestUtils;
@@ -121,7 +122,7 @@ class K8sTaskAdapterTest
   void testAddingLabelsAndAnnotations() throws IOException
   {
     final PodSpec podSpec = K8sTestUtils.getDummyPodSpec();
-    TestKubernetesClient testClient = new TestKubernetesClient(client)
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "namespace")
     {
       @SuppressWarnings("unchecked")
       @Override
@@ -138,12 +139,12 @@ class K8sTaskAdapterTest
       }
     };
 
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder()
-        .withNamespace("test")
-        .withOverlordNamespace("test_different")
-        .withAnnotations(ImmutableMap.of("annotation_key", "annotation_value"))
-        .withLabels(ImmutableMap.of("label_key", "label_value"))
-        .build();
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder()
+                                                                              .withNamespace("test")
+                                                                              .withOverlordNamespace("test_different")
+                                                                              .withAnnotations(ImmutableMap.of("annotation_key", "annotation_value"))
+                                                                              .withLabels(ImmutableMap.of("label_key", "label_value"))
+                                                                              .build();
     K8sTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
         config,
@@ -174,10 +175,10 @@ class K8sTaskAdapterTest
   public void serializingAndDeserializingATask() throws IOException
   {
     // given a task create a k8s job
-    TestKubernetesClient testClient = new TestKubernetesClient(client);
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder()
-        .withNamespace("test")
-        .build();
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "test");
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder()
+                                                                              .withNamespace("test")
+                                                                              .build();
     K8sTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
         config,
@@ -212,7 +213,7 @@ class K8sTaskAdapterTest
   public void fromTask_dontSetTaskJSON() throws IOException
   {
     final PodSpec podSpec = K8sTestUtils.getDummyPodSpec();
-    TestKubernetesClient testClient = new TestKubernetesClient(client)
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "test")
     {
       @SuppressWarnings("unchecked")
       @Override
@@ -229,9 +230,9 @@ class K8sTaskAdapterTest
       }
     };
 
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder()
-        .withNamespace("test")
-        .build();
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder()
+                                                                              .withNamespace("test")
+                                                                              .build();
     K8sTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
         config,
@@ -276,10 +277,10 @@ class K8sTaskAdapterTest
   @Test
   public void toTask_useTaskPayloadManager() throws IOException
   {
-    TestKubernetesClient testClient = new TestKubernetesClient(client);
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder()
-        .withNamespace("test")
-        .build();
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "test");
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder()
+                                                                              .withNamespace("test")
+                                                                              .build();
     Task taskInTaskPayloadManager = K8sTestUtils.getTask();
     TaskLogs mockTestLogs = Mockito.mock(TaskLogs.class);
     Mockito.when(mockTestLogs.streamTaskPayload("ID")).thenReturn(com.google.common.base.Optional.of(
@@ -308,8 +309,8 @@ class K8sTaskAdapterTest
   @Test
   public void getTaskId()
   {
-    TestKubernetesClient testClient = new TestKubernetesClient(client);
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder().build();
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "test");
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder().build();
     K8sTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
         config,
@@ -330,8 +331,8 @@ class K8sTaskAdapterTest
   @Test
   public void getTaskId_noAnnotations()
   {
-    TestKubernetesClient testClient = new TestKubernetesClient(client);
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder().build();
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "test");
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder().build();
     K8sTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
         config,
@@ -352,8 +353,8 @@ class K8sTaskAdapterTest
   @Test
   public void getTaskId_missingTaskIdAnnotation()
   {
-    TestKubernetesClient testClient = new TestKubernetesClient(client);
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder().build();
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "test");
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder().build();
     K8sTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
         config,
@@ -451,16 +452,16 @@ class K8sTaskAdapterTest
   @Test
   void testAddingMonitors() throws IOException
   {
-    TestKubernetesClient testClient = new TestKubernetesClient(client);
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "test");
     PeonCommandContext context = new PeonCommandContext(
         new ArrayList<>(),
         new ArrayList<>(),
         new File("/tmp/"),
         0
     );
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder()
-        .withNamespace("test")
-        .build();
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder()
+                                                                              .withNamespace("test")
+                                                                              .build();
     K8sTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
         config,
@@ -482,9 +483,9 @@ class K8sTaskAdapterTest
 
     // we have an override, but nothing in the overlord
     config = KubernetesTaskRunnerConfig.builder()
-        .withNamespace("test")
-        .withPeonMonitors(ImmutableList.of("org.apache.druid.java.util.metrics.JvmMonitor"))
-        .build();
+                                             .withNamespace("test")
+                                             .withPeonMonitors(ImmutableList.of("org.apache.druid.java.util.metrics.JvmMonitor"))
+                                             .build();
     adapter = new SingleContainerTaskAdapter(
         testClient,
         config,
@@ -530,11 +531,11 @@ class K8sTaskAdapterTest
   @Test
   void testEphemeralStorageIsRespected() throws IOException
   {
-    TestKubernetesClient testClient = new TestKubernetesClient(client);
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "namespace");
     Pod pod = K8sTestUtils.fileToResource("ephemeralPodSpec.yaml", Pod.class);
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder()
-        .withNamespace("namespace")
-        .build();
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder()
+                                                                              .withNamespace("namespace")
+                                                                              .build();
 
     SingleContainerTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
@@ -580,11 +581,11 @@ class K8sTaskAdapterTest
   @Test
   void testProbesRemoved() throws IOException
   {
-    TestKubernetesClient testClient = new TestKubernetesClient(client);
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "test");
     Pod pod = K8sTestUtils.fileToResource("probesPodSpec.yaml", Pod.class);
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder()
-                                                                  .withNamespace("test")
-                                                                  .build();
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder()
+                                                                              .withNamespace("test")
+                                                                              .build();
 
     SingleContainerTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
@@ -630,16 +631,16 @@ class K8sTaskAdapterTest
   @Test
   void testCPUResourceIsRespected() throws IOException
   {
-    TestKubernetesClient testClient = new TestKubernetesClient(client);
+    TestKubernetesClient testClient = new TestKubernetesClient(client, "namespace");
     Pod pod = K8sTestUtils.fileToResource("ephemeralPodSpec.yaml", Pod.class);
 
     List<String> javaOpts = new ArrayList<>();
     javaOpts.add("-Xms1G -Xmx2G -XX:MaxDirectMemorySize=3G");
-    KubernetesTaskRunnerConfig config = KubernetesTaskRunnerConfig.builder()
-                                                                  .withNamespace("namespace")
-                                                                  .withJavaOptsArray(javaOpts)
-                                                                  .withCpuCore(2000)
-                                                                  .build();
+    KubernetesTaskRunnerStaticConfig config = KubernetesTaskRunnerConfig.builder()
+                                                                              .withNamespace("namespace")
+                                                                              .withJavaOptsArray(javaOpts)
+                                                                              .withCpuCore(2000)
+                                                                              .build();
 
     SingleContainerTaskAdapter adapter = new SingleContainerTaskAdapter(
         testClient,
