@@ -99,7 +99,12 @@ public class PollingLookupTest extends InitializedNullHandlingTest
     }
 
     @Override
-    @SuppressWarnings("EqualsHashCode")
+    public int hashCode()
+    {
+      return 0;
+    }
+
+    @Override
     public boolean equals(Object obj)
     {
       return obj instanceof MockDataFetcher;
