@@ -30,7 +30,7 @@ public class LockListAction implements TaskAction<List<TaskLock>>
   @Override
   public TypeReference<List<TaskLock>> getReturnTypeReference()
   {
-    return new TypeReference<List<TaskLock>>() {};
+    return new TypeReference<>() {};
   }
 
   @Override
