@@ -80,6 +80,9 @@ public class TaskConfig implements TaskDirectory
   @JsonProperty
   private final boolean allowHadoopTaskExecution;
 
+  @JsonProperty
+  private final boolean buildV10;
+
   @JsonCreator
   public TaskConfig(
       @JsonProperty("baseDir") String baseDir,
@@ -92,7 +95,8 @@ public class TaskConfig implements TaskDirectory
       @JsonProperty("storeEmptyColumns") @Nullable Boolean storeEmptyColumns,
       @JsonProperty("encapsulatedTask") boolean enableTaskLevelLogPush,
       @JsonProperty("tmpStorageBytesPerTask") @Nullable Long tmpStorageBytesPerTask,
-      @JsonProperty("allowHadoopTaskExecution") boolean allowHadoopTaskExecution
+      @JsonProperty("allowHadoopTaskExecution") boolean allowHadoopTaskExecution,
+      @JsonProperty("buildV10") boolean buildV10
   )
   {
     this.baseDir = Configs.valueOrDefault(baseDir, System.getProperty("java.io.tmpdir"));
@@ -119,6 +123,7 @@ public class TaskConfig implements TaskDirectory
     this.storeEmptyColumns = Configs.valueOrDefault(storeEmptyColumns, DEFAULT_STORE_EMPTY_COLUMNS);
     this.tmpStorageBytesPerTask = Configs.valueOrDefault(tmpStorageBytesPerTask, DEFAULT_TMP_STORAGE_BYTES_PER_TASK);
     this.allowHadoopTaskExecution = allowHadoopTaskExecution;
+    this.buildV10 = buildV10;
   }
 
   private TaskConfig(
@@ -132,7 +137,8 @@ public class TaskConfig implements TaskDirectory
       boolean storeEmptyColumns,
       boolean encapsulatedTask,
       long tmpStorageBytesPerTask,
-      boolean allowHadoopTaskExecution
+      boolean allowHadoopTaskExecution,
+      boolean buildV10
   )
   {
     this.baseDir = baseDir;
@@ -146,6 +152,7 @@ public class TaskConfig implements TaskDirectory
     this.encapsulatedTask = encapsulatedTask;
     this.tmpStorageBytesPerTask = tmpStorageBytesPerTask;
     this.allowHadoopTaskExecution = allowHadoopTaskExecution;
+    this.buildV10 = buildV10;
   }
 
   @JsonProperty
@@ -244,6 +251,12 @@ public class TaskConfig implements TaskDirectory
     return allowHadoopTaskExecution;
   }
 
+  @JsonProperty
+  public boolean buildV10()
+  {
+    return buildV10;
+  }
+
   private String defaultDir(@Nullable String configParameter, final String defaultVal)
   {
     if (configParameter == null) {
@@ -266,7 +279,8 @@ public class TaskConfig implements TaskDirectory
         storeEmptyColumns,
         encapsulatedTask,
         tmpStorageBytesPerTask,
-        allowHadoopTaskExecution
+        allowHadoopTaskExecution,
+        buildV10
     );
   }
 
@@ -283,7 +297,8 @@ public class TaskConfig implements TaskDirectory
         storeEmptyColumns,
         encapsulatedTask,
         tmpStorageBytesPerTask,
-        allowHadoopTaskExecution
+        allowHadoopTaskExecution,
+        buildV10
     );
   }
 }
