@@ -21,23 +21,25 @@ package org.apache.druid.indexing.common.stats;
 
 import com.codahale.metrics.Meter;
 import com.codahale.metrics.MetricRegistry;
+import org.apache.druid.segment.incremental.InputRowFilterResult;
 import org.apache.druid.segment.incremental.RowIngestionMeters;
 import org.apache.druid.segment.incremental.RowIngestionMetersTotals;
 
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 
 public class DropwizardRowIngestionMeters implements RowIngestionMeters
 {
-  private static final String ONE_MINUTE_NAME = "1m";
-  private static final String FIVE_MINUTE_NAME = "5m";
-  private static final String FIFTEEN_MINUTE_NAME = "15m";
+  public static final String ONE_MINUTE_NAME = "1m";
+  public static final String FIVE_MINUTE_NAME = "5m";
+  public static final String FIFTEEN_MINUTE_NAME = "15m";
 
   private final Meter processed;
   private final Meter processedBytes;
   private final Meter processedWithError;
   private final Meter unparseable;
-  private final Meter thrownAway;
+  private final Meter[] thrownAwayByReason = new Meter[InputRowFilterResult.numValues()];
 
   public DropwizardRowIngestionMeters()
   {
@@ -46,7 +48,9 @@ public class DropwizardRowIngestionMeters implements RowIngestionMeters
     this.processedBytes = metricRegistry.meter(PROCESSED_BYTES);
     this.processedWithError = metricRegistry.meter(PROCESSED_WITH_ERROR);
     this.unparseable = metricRegistry.meter(UNPARSEABLE);
-    this.thrownAway = metricRegistry.meter(THROWN_AWAY);
+    for (InputRowFilterResult reason : InputRowFilterResult.values()) {
+      this.thrownAwayByReason[reason.ordinal()] = metricRegistry.meter(THROWN_AWAY + "_" + reason.name());
+    }
   }
 
   @Override
@@ -100,13 +104,30 @@ public class DropwizardRowIngestionMeters implements RowIngestionMeters
   @Override
   public long getThrownAway()
   {
-    return thrownAway.getCount();
+    long totalThrownAway = 0;
+    for (InputRowFilterResult reason : InputRowFilterResult.rejectedValues()) {
+      totalThrownAway += thrownAwayByReason[reason.ordinal()].getCount();
+    }
+    return totalThrownAway;
   }
 
   @Override
-  public void incrementThrownAway()
+  public void incrementThrownAway(InputRowFilterResult reason)
   {
-    thrownAway.mark();
+    thrownAwayByReason[reason.ordinal()].mark();
+  }
+
+  @Override
+  public Map<String, Long> getThrownAwayByReason()
+  {
+    Map<String, Long> result = new HashMap<>();
+    for (InputRowFilterResult reason : InputRowFilterResult.rejectedValues()) {
+      long count = thrownAwayByReason[reason.ordinal()].getCount();
+      if (count > 0) {
+        result.put(reason.getReason(), count);
+      }
+    }
+    return result;
   }
 
   @Override
@@ -116,7 +137,7 @@ public class DropwizardRowIngestionMeters implements RowIngestionMeters
         processed.getCount(),
         processedBytes.getCount(),
         processedWithError.getCount(),
-        thrownAway.getCount(),
+        getThrownAwayByReason(),
         unparseable.getCount()
     );
   }
@@ -131,21 +152,21 @@ public class DropwizardRowIngestionMeters implements RowIngestionMeters
     oneMinute.put(PROCESSED_BYTES, processedBytes.getOneMinuteRate());
     oneMinute.put(PROCESSED_WITH_ERROR, processedWithError.getOneMinuteRate());
     oneMinute.put(UNPARSEABLE, unparseable.getOneMinuteRate());
-    oneMinute.put(THROWN_AWAY, thrownAway.getOneMinuteRate());
+    oneMinute.put(THROWN_AWAY, Arrays.stream(thrownAwayByReason).mapToDouble(Meter::getOneMinuteRate).sum());
 
     Map<String, Object> fiveMinute = new HashMap<>();
     fiveMinute.put(PROCESSED, processed.getFiveMinuteRate());
     fiveMinute.put(PROCESSED_BYTES, processedBytes.getFiveMinuteRate());
     fiveMinute.put(PROCESSED_WITH_ERROR, processedWithError.getFiveMinuteRate());
     fiveMinute.put(UNPARSEABLE, unparseable.getFiveMinuteRate());
-    fiveMinute.put(THROWN_AWAY, thrownAway.getFiveMinuteRate());
+    fiveMinute.put(THROWN_AWAY, Arrays.stream(thrownAwayByReason).mapToDouble(Meter::getFiveMinuteRate).sum());
 
     Map<String, Object> fifteenMinute = new HashMap<>();
     fifteenMinute.put(PROCESSED, processed.getFifteenMinuteRate());
     fifteenMinute.put(PROCESSED_BYTES, processedBytes.getFifteenMinuteRate());
     fifteenMinute.put(PROCESSED_WITH_ERROR, processedWithError.getFifteenMinuteRate());
     fifteenMinute.put(UNPARSEABLE, unparseable.getFifteenMinuteRate());
-    fifteenMinute.put(THROWN_AWAY, thrownAway.getFifteenMinuteRate());
+    fifteenMinute.put(THROWN_AWAY, Arrays.stream(thrownAwayByReason).mapToDouble(Meter::getFifteenMinuteRate).sum());
 
     movingAverages.put(ONE_MINUTE_NAME, oneMinute);
     movingAverages.put(FIVE_MINUTE_NAME, fiveMinute);
