@@ -29,14 +29,12 @@ import org.apache.druid.indexer.TaskStatus;
 import org.apache.druid.indexer.TaskStatusPlus;
 import org.apache.druid.indexing.common.TaskLock;
 import org.apache.druid.indexing.common.task.Task;
-import org.apache.druid.indexing.overlord.autoscaling.ProvisioningStrategy;
 import org.apache.druid.indexing.overlord.http.TaskStateLookup;
 import org.apache.druid.indexing.overlord.http.TotalWorkerCapacityResponse;
 import org.apache.druid.indexing.overlord.setup.WorkerBehaviorConfig;
 import org.apache.druid.java.util.common.IAE;
 import org.apache.druid.java.util.common.Intervals;
 import org.apache.druid.java.util.common.StringUtils;
-import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.metadata.LockFilterPolicy;
 import org.apache.druid.metadata.TaskLookup;
 import org.apache.druid.metadata.TaskLookup.TaskLookupType;
@@ -60,20 +58,16 @@ import java.util.stream.Stream;
  */
 public class TaskQueryTool
 {
-  private static final Logger log = new Logger(TaskQueryTool.class);
-
   private final TaskStorage storage;
   private final GlobalTaskLockbox taskLockbox;
   private final TaskMaster taskMaster;
   private final Supplier<WorkerBehaviorConfig> workerBehaviorConfigSupplier;
-  private final ProvisioningStrategy provisioningStrategy;
 
   @Inject
   public TaskQueryTool(
       TaskStorage storage,
       GlobalTaskLockbox taskLockbox,
       TaskMaster taskMaster,
-      ProvisioningStrategy provisioningStrategy,
       Supplier<WorkerBehaviorConfig> workerBehaviorConfigSupplier
   )
   {
@@ -81,7 +75,6 @@ public class TaskQueryTool
     this.taskLockbox = taskLockbox;
     this.taskMaster = taskMaster;
     this.workerBehaviorConfigSupplier = workerBehaviorConfigSupplier;
-    this.provisioningStrategy = provisioningStrategy;
   }
 
   /**
@@ -155,19 +148,22 @@ public class TaskQueryTool
     return storage.getTaskInfo(taskId);
   }
 
+  /**
+   * Retrieves all active tasks from the {@link TaskQueue} if available,
+   * otherwise from the metadata store.
+   */
   public List<TaskStatusPlus> getAllActiveTasks()
   {
     final Optional<TaskQueue> taskQueue = taskMaster.getTaskQueue();
     if (taskQueue.isPresent()) {
-      // Serve active task statuses from memory
+      // Serve active task statuses from the TaskQueue memory
       final List<TaskStatusPlus> taskStatusPlusList = new ArrayList<>();
       final List<TaskInfo> activeTasks = taskQueue.get().getTaskInfos();
 
       for (TaskInfo taskInfo : activeTasks) {
         final Task task = taskInfo.getTask();
-        final Optional<TaskStatus> statusOptional = taskQueue.get().getTaskStatus(task.getId());
-        if (statusOptional.isPresent()) {
-          final TaskStatus status = statusOptional.get();
+        final TaskStatus status = taskInfo.getStatus();
+        if (status.isRunnable()) {
           taskStatusPlusList.add(
               new TaskStatusPlus(
                   task.getId(),
@@ -220,7 +216,7 @@ public class TaskQueryTool
     // This way, we can use the snapshot from taskStorage as the source of truth for the set of tasks to process
     // and use the snapshot from taskRunner as a reference for potential task state updates happened
     // after the first snapshotting.
-    Stream<TaskStatusPlus> taskStatusPlusStream = getTaskStatusPlusStream(
+    Stream<TaskStatusPlus> taskStatusPlusStream = retrieveTaskStatusesFromMetadataStore(
         state,
         dataSource,
         createdTimeDuration,
@@ -286,7 +282,7 @@ public class TaskQueryTool
     return taskStatuses;
   }
 
-  private Stream<TaskStatusPlus> getTaskStatusPlusStream(
+  private Stream<TaskStatusPlus> retrieveTaskStatusesFromMetadataStore(
       TaskStateLookup state,
       @Nullable String dataSource,
       Duration createdTimeDuration,
