@@ -23,30 +23,29 @@ import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.common.base.Suppliers;
 import org.apache.druid.indexing.common.TestUtils;
 import org.apache.druid.indexing.common.config.TaskStorageConfig;
+import org.apache.druid.indexing.overlord.GlobalTaskLockbox;
 import org.apache.druid.indexing.overlord.HeapMemoryTaskStorage;
 import org.apache.druid.indexing.overlord.IndexerMetadataStorageCoordinator;
-import org.apache.druid.indexing.overlord.TaskLockbox;
 import org.apache.druid.indexing.overlord.TaskStorage;
 import org.apache.druid.indexing.overlord.config.TaskLockConfig;
 import org.apache.druid.indexing.overlord.supervisor.SupervisorManager;
 import org.apache.druid.java.util.common.concurrent.ScheduledExecutors;
+import org.apache.druid.java.util.emitter.service.ServiceEmitter;
+import org.apache.druid.java.util.metrics.StubServiceEmitter;
 import org.apache.druid.metadata.IndexerSQLMetadataStorageCoordinator;
 import org.apache.druid.metadata.MetadataStorageConnectorConfig;
 import org.apache.druid.metadata.MetadataStorageTablesConfig;
-import org.apache.druid.metadata.SegmentsMetadataManager;
 import org.apache.druid.metadata.SegmentsMetadataManagerConfig;
-import org.apache.druid.metadata.SqlSegmentsMetadataManager;
 import org.apache.druid.metadata.TestDerbyConnector;
 import org.apache.druid.metadata.segment.SqlSegmentMetadataTransactionFactory;
 import org.apache.druid.metadata.segment.cache.HeapMemorySegmentMetadataCache;
 import org.apache.druid.metadata.segment.cache.SegmentMetadataCache;
 import org.apache.druid.segment.metadata.CentralizedDatasourceSchemaConfig;
-import org.apache.druid.segment.metadata.SegmentSchemaCache;
+import org.apache.druid.segment.metadata.NoopSegmentSchemaCache;
 import org.apache.druid.segment.metadata.SegmentSchemaManager;
 import org.apache.druid.server.coordinator.simulate.BlockingExecutorService;
 import org.apache.druid.server.coordinator.simulate.TestDruidLeaderSelector;
 import org.apache.druid.server.coordinator.simulate.WrappingScheduledExecutorService;
-import org.apache.druid.server.metrics.NoopServiceEmitter;
 import org.easymock.EasyMock;
 import org.joda.time.Period;
 import org.junit.rules.ExternalResource;
@@ -56,20 +55,33 @@ public class TaskActionTestKit extends ExternalResource
   private final MetadataStorageTablesConfig metadataStorageTablesConfig = MetadataStorageTablesConfig.fromBase("druid");
 
   private TaskStorage taskStorage;
-  private TaskLockbox taskLockbox;
+  private GlobalTaskLockbox taskLockbox;
+  private StubServiceEmitter emitter;
   private TestDerbyConnector testDerbyConnector;
   private IndexerMetadataStorageCoordinator metadataStorageCoordinator;
-  private SegmentsMetadataManager segmentsMetadataManager;
   private TaskActionToolbox taskActionToolbox;
-  private SegmentSchemaManager segmentSchemaManager;
-  private SegmentSchemaCache segmentSchemaCache;
   private SegmentMetadataCache segmentMetadataCache;
   private BlockingExecutorService metadataCachePollExec;
 
   private boolean useSegmentMetadataCache = false;
   private boolean skipSegmentPayloadFetchForAllocation = new TaskLockConfig().isBatchAllocationReduceMetadataIO();
 
-  public TaskLockbox getTaskLockbox()
+  public StubServiceEmitter getServiceEmitter()
+  {
+    return emitter;
+  }
+
+  public TestDerbyConnector getTestDerbyConnector()
+  {
+    return testDerbyConnector;
+  }
+
+  public MetadataStorageTablesConfig getMetadataStorageTablesConfig()
+  {
+    return metadataStorageTablesConfig;
+  }
+
+  public GlobalTaskLockbox getTaskLockbox()
   {
     return taskLockbox;
   }
@@ -79,11 +91,6 @@ public class TaskActionTestKit extends ExternalResource
     return metadataStorageCoordinator;
   }
 
-  public SegmentsMetadataManager getSegmentsMetadataManager()
-  {
-    return segmentsMetadataManager;
-  }
-
   public TaskActionToolbox getTaskActionToolbox()
   {
     return taskActionToolbox;
@@ -107,15 +114,20 @@ public class TaskActionTestKit extends ExternalResource
   @Override
   public void before()
   {
+    emitter = new StubServiceEmitter();
     taskStorage = new HeapMemoryTaskStorage(new TaskStorageConfig(new Period("PT24H")));
     testDerbyConnector = new TestDerbyConnector(
-        Suppliers.ofInstance(new MetadataStorageConnectorConfig()),
-        Suppliers.ofInstance(metadataStorageTablesConfig)
+        new MetadataStorageConnectorConfig(),
+        metadataStorageTablesConfig
     );
     final ObjectMapper objectMapper = new TestUtils().getTestObjectMapper();
-    segmentSchemaManager = new SegmentSchemaManager(metadataStorageTablesConfig, objectMapper, testDerbyConnector);
+    final SegmentSchemaManager segmentSchemaManager = new SegmentSchemaManager(
+        metadataStorageTablesConfig,
+        objectMapper,
+        testDerbyConnector
+    );
 
-    final SqlSegmentMetadataTransactionFactory transactionFactory = setupTransactionFactory(objectMapper);
+    final SqlSegmentMetadataTransactionFactory transactionFactory = setupTransactionFactory(objectMapper, emitter);
     metadataStorageCoordinator = new IndexerSQLMetadataStorageCoordinator(
         transactionFactory,
         objectMapper,
@@ -124,17 +136,8 @@ public class TaskActionTestKit extends ExternalResource
         segmentSchemaManager,
         CentralizedDatasourceSchemaConfig.create()
     );
-    taskLockbox = new TaskLockbox(taskStorage, metadataStorageCoordinator);
-    segmentSchemaCache = new SegmentSchemaCache(NoopServiceEmitter.instance());
-    segmentsMetadataManager = new SqlSegmentsMetadataManager(
-        objectMapper,
-        Suppliers.ofInstance(new SegmentsMetadataManagerConfig(null, null)),
-        Suppliers.ofInstance(metadataStorageTablesConfig),
-        testDerbyConnector,
-        segmentSchemaCache,
-        CentralizedDatasourceSchemaConfig.create(),
-        NoopServiceEmitter.instance()
-    );
+    taskLockbox = new GlobalTaskLockbox(taskStorage, metadataStorageCoordinator);
+    taskLockbox.syncFromStorage();
     final TaskLockConfig taskLockConfig = new TaskLockConfig()
     {
       @Override
@@ -158,10 +161,10 @@ public class TaskActionTestKit extends ExternalResource
             taskLockbox,
             taskLockConfig,
             metadataStorageCoordinator,
-            NoopServiceEmitter.instance(),
+            emitter,
             ScheduledExecutors::fixed
         ),
-        NoopServiceEmitter.instance(),
+        emitter,
         EasyMock.createMock(SupervisorManager.class),
         objectMapper
     );
@@ -179,20 +182,25 @@ public class TaskActionTestKit extends ExternalResource
     syncSegmentMetadataCache();
   }
 
-  private SqlSegmentMetadataTransactionFactory setupTransactionFactory(ObjectMapper objectMapper)
+  private SqlSegmentMetadataTransactionFactory setupTransactionFactory(
+      ObjectMapper objectMapper,
+      ServiceEmitter emitter
+  )
   {
     metadataCachePollExec = new BlockingExecutorService("test-cache-poll-exec");
     SegmentMetadataCache.UsageMode cacheMode
         = useSegmentMetadataCache
           ? SegmentMetadataCache.UsageMode.ALWAYS
           : SegmentMetadataCache.UsageMode.NEVER;
+
     segmentMetadataCache = new HeapMemorySegmentMetadataCache(
         objectMapper,
-        Suppliers.ofInstance(new SegmentsMetadataManagerConfig(Period.seconds(1), cacheMode)),
+        Suppliers.ofInstance(new SegmentsMetadataManagerConfig(Period.seconds(1), cacheMode, null)),
         Suppliers.ofInstance(metadataStorageTablesConfig),
+        new NoopSegmentSchemaCache(),
         testDerbyConnector,
         (poolSize, name) -> new WrappingScheduledExecutorService(name, metadataCachePollExec, false),
-        NoopServiceEmitter.instance()
+        emitter
     );
 
     final TestDruidLeaderSelector leaderSelector = new TestDruidLeaderSelector();
@@ -204,7 +212,7 @@ public class TaskActionTestKit extends ExternalResource
         testDerbyConnector,
         leaderSelector,
         segmentMetadataCache,
-        NoopServiceEmitter.instance()
+        emitter
     )
     {
       @Override
@@ -223,7 +231,6 @@ public class TaskActionTestKit extends ExternalResource
     taskLockbox = null;
     testDerbyConnector = null;
     metadataStorageCoordinator = null;
-    segmentsMetadataManager = null;
     taskActionToolbox = null;
     segmentMetadataCache.stopBeingLeader();
     segmentMetadataCache.stop();
