@@ -102,7 +102,9 @@ public class SupervisorManagerTest extends EasyMockSupport
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     metadataSupervisorManager.insert("id1", spec);
     supervisor3.start();
+    EasyMock.expect(supervisor3.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     replayAll();
 
     manager.start();
@@ -115,6 +117,7 @@ public class SupervisorManagerTest extends EasyMockSupport
 
     resetAll();
     supervisor2.start();
+    EasyMock.expect(supervisor2.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.stop(true);
     replayAll();
 
@@ -164,6 +167,7 @@ public class SupervisorManagerTest extends EasyMockSupport
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(ImmutableMap.of());
     metadataSupervisorManager.insert("id1", spec);
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     replayAll();
 
     manager.start();
@@ -225,6 +229,7 @@ public class SupervisorManagerTest extends EasyMockSupport
     );
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     replayAll();
     manager.start();
     Assert.assertFalse(manager.shouldUpdateSupervisor(spec));
@@ -249,6 +254,7 @@ public class SupervisorManagerTest extends EasyMockSupport
     );
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     exception.expect(DruidException.class);
     replayAll();
     manager.start();
@@ -332,6 +338,7 @@ public class SupervisorManagerTest extends EasyMockSupport
 
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     EasyMock.expect(supervisor1.getStatus()).andReturn(report);
     replayAll();
 
@@ -352,6 +359,7 @@ public class SupervisorManagerTest extends EasyMockSupport
 
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.handoffTaskGroupsEarly(ImmutableList.of(1));
 
     replayAll();
@@ -373,6 +381,7 @@ public class SupervisorManagerTest extends EasyMockSupport
 
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor3.start();
+    EasyMock.expect(supervisor3.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
 
     replayAll();
 
@@ -414,6 +423,8 @@ public class SupervisorManagerTest extends EasyMockSupport
 
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor3.start();
+    EasyMock.expect(supervisor3.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.start();
     EasyMock.expectLastCall().andThrow(new RuntimeException("supervisor explosion"));
     replayAll();
@@ -433,7 +444,9 @@ public class SupervisorManagerTest extends EasyMockSupport
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(Collections.emptyMap());
     metadataSupervisorManager.insert(EasyMock.eq("id1"), EasyMock.capture(capturedInsert));
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.stop(true);
+    EasyMock.expect(supervisor2.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor2.start();
     EasyMock.expectLastCall().andThrow(new RuntimeException("supervisor failed to start"));
     replayAll();
@@ -461,6 +474,7 @@ public class SupervisorManagerTest extends EasyMockSupport
 
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.stopAsync();
     EasyMock.expectLastCall().andThrow(new RuntimeException("RTE"));
     replayAll();
@@ -479,6 +493,7 @@ public class SupervisorManagerTest extends EasyMockSupport
 
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.reset(EasyMock.anyObject(DataSourceMetadata.class));
     replayAll();
 
@@ -498,6 +513,7 @@ public class SupervisorManagerTest extends EasyMockSupport
 
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor3.start();
+    EasyMock.expect(supervisor3.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     replayAll();
 
     manager.start();
@@ -533,6 +549,7 @@ public class SupervisorManagerTest extends EasyMockSupport
 
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.resetOffsets(datasourceMetadata);
     replayAll();
 
@@ -558,7 +575,9 @@ public class SupervisorManagerTest extends EasyMockSupport
     EasyMock.expect(metadataSupervisorManager.getLatest()).andReturn(existingSpecs);
     metadataSupervisorManager.insert("id1", spec);
     supervisor3.start();
+    EasyMock.expect(supervisor3.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     replayAll();
 
     manager.start();
@@ -574,6 +593,7 @@ public class SupervisorManagerTest extends EasyMockSupport
     resetAll();
     metadataSupervisorManager.insert(EasyMock.eq("id1"), EasyMock.capture(capturedInsert));
     supervisor2.start();
+    EasyMock.expect(supervisor2.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     supervisor1.stop(true);
     replayAll();
 
@@ -589,6 +609,7 @@ public class SupervisorManagerTest extends EasyMockSupport
     metadataSupervisorManager.insert(EasyMock.eq("id1"), EasyMock.capture(capturedInsert));
     supervisor2.stop(true);
     supervisor1.start();
+    EasyMock.expect(supervisor1.createAutoscaler(EasyMock.anyObject())).andReturn(null).anyTimes();
     replayAll();
 
     manager.suspendOrResumeSupervisor("id1", false);
@@ -631,29 +652,29 @@ public class SupervisorManagerTest extends EasyMockSupport
     metadataSupervisorManager.insert(EasyMock.anyString(), EasyMock.anyObject());
 
     SeekableStreamSupervisorSpec suspendedSpec = EasyMock.createNiceMock(SeekableStreamSupervisorSpec.class);
-    Supervisor suspendedSupervisor = EasyMock.mock(SeekableStreamSupervisor.class);
+    Supervisor suspendedSupervisor = EasyMock.createNiceMock(SeekableStreamSupervisor.class);
     EasyMock.expect(suspendedSpec.getId()).andReturn("suspendedSpec").anyTimes();
     EasyMock.expect(suspendedSpec.isSuspended()).andReturn(true).anyTimes();
     EasyMock.expect(suspendedSpec.getDataSources()).andReturn(ImmutableList.of("suspendedDS")).anyTimes();
     EasyMock.expect(suspendedSpec.createSupervisor()).andReturn(suspendedSupervisor).anyTimes();
     EasyMock.expect(suspendedSpec.createAutoscaler(suspendedSupervisor)).andReturn(null).anyTimes();
     EasyMock.expect(suspendedSpec.getContext()).andReturn(null).anyTimes();
-    EasyMock.replay(suspendedSpec);
+    EasyMock.replay(suspendedSpec, suspendedSupervisor);
     metadataSupervisorManager.insert(EasyMock.anyString(), EasyMock.anyObject());
 
     SeekableStreamSupervisorSpec activeSpec = EasyMock.createNiceMock(SeekableStreamSupervisorSpec.class);
-    Supervisor activeSupervisor = EasyMock.mock(SeekableStreamSupervisor.class);
+    Supervisor activeSupervisor = EasyMock.createNiceMock(SeekableStreamSupervisor.class);
     EasyMock.expect(activeSpec.getId()).andReturn("activeSpec").anyTimes();
     EasyMock.expect(activeSpec.isSuspended()).andReturn(false).anyTimes();
     EasyMock.expect(activeSpec.getDataSources()).andReturn(ImmutableList.of("activeDS")).anyTimes();
     EasyMock.expect(activeSpec.createSupervisor()).andReturn(activeSupervisor).anyTimes();
     EasyMock.expect(activeSpec.createAutoscaler(activeSupervisor)).andReturn(null).anyTimes();
     EasyMock.expect(activeSpec.getContext()).andReturn(null).anyTimes();
-    EasyMock.replay(activeSpec);
+    EasyMock.replay(activeSpec, activeSupervisor);
     metadataSupervisorManager.insert(EasyMock.anyString(), EasyMock.anyObject());
 
     SeekableStreamSupervisorSpec activeSpecWithConcurrentLocks = EasyMock.createNiceMock(SeekableStreamSupervisorSpec.class);
-    Supervisor activeSupervisorWithConcurrentLocks = EasyMock.mock(SeekableStreamSupervisor.class);
+    Supervisor activeSupervisorWithConcurrentLocks = EasyMock.createNiceMock(SeekableStreamSupervisor.class);
     EasyMock.expect(activeSpecWithConcurrentLocks.getId()).andReturn("activeSpecWithConcurrentLocks").anyTimes();
     EasyMock.expect(activeSpecWithConcurrentLocks.isSuspended()).andReturn(false).anyTimes();
     EasyMock.expect(activeSpecWithConcurrentLocks.getDataSources())
@@ -664,11 +685,11 @@ public class SupervisorManagerTest extends EasyMockSupport
             .andReturn(null).anyTimes();
     EasyMock.expect(activeSpecWithConcurrentLocks.getContext())
             .andReturn(ImmutableMap.of(Tasks.USE_CONCURRENT_LOCKS, true)).anyTimes();
-    EasyMock.replay(activeSpecWithConcurrentLocks);
+    EasyMock.replay(activeSpecWithConcurrentLocks, activeSupervisorWithConcurrentLocks);
     metadataSupervisorManager.insert(EasyMock.anyString(), EasyMock.anyObject());
 
     SeekableStreamSupervisorSpec activeAppendSpec = EasyMock.createNiceMock(SeekableStreamSupervisorSpec.class);
-    Supervisor activeAppendSupervisor = EasyMock.mock(SeekableStreamSupervisor.class);
+    Supervisor activeAppendSupervisor = EasyMock.createNiceMock(SeekableStreamSupervisor.class);
     EasyMock.expect(activeAppendSpec.getId()).andReturn("activeAppendSpec").anyTimes();
     EasyMock.expect(activeAppendSpec.isSuspended()).andReturn(false).anyTimes();
     EasyMock.expect(activeAppendSpec.getDataSources()).andReturn(ImmutableList.of("activeAppendDS")).anyTimes();
@@ -678,12 +699,12 @@ public class SupervisorManagerTest extends EasyMockSupport
         Tasks.TASK_LOCK_TYPE,
         TaskLockType.APPEND.name()
     )).anyTimes();
-    EasyMock.replay(activeAppendSpec);
+    EasyMock.replay(activeAppendSpec, activeAppendSupervisor);
     metadataSupervisorManager.insert(EasyMock.anyString(), EasyMock.anyObject());
 
     // A supervisor with useConcurrentLocks set to false explicitly must not use an append lock
     SeekableStreamSupervisorSpec specWithUseConcurrentLocksFalse = EasyMock.createNiceMock(SeekableStreamSupervisorSpec.class);
-    Supervisor supervisorWithUseConcurrentLocksFalse = EasyMock.mock(SeekableStreamSupervisor.class);
+    Supervisor supervisorWithUseConcurrentLocksFalse = EasyMock.createNiceMock(SeekableStreamSupervisor.class);
     EasyMock.expect(specWithUseConcurrentLocksFalse.getId()).andReturn("useConcurrentLocksFalse").anyTimes();
     EasyMock.expect(specWithUseConcurrentLocksFalse.isSuspended()).andReturn(false).anyTimes();
     EasyMock.expect(specWithUseConcurrentLocksFalse.getDataSources())
@@ -697,7 +718,7 @@ public class SupervisorManagerTest extends EasyMockSupport
         Tasks.TASK_LOCK_TYPE,
         TaskLockType.APPEND.name()
     )).anyTimes();
-    EasyMock.replay(specWithUseConcurrentLocksFalse);
+    EasyMock.replay(specWithUseConcurrentLocksFalse, supervisorWithUseConcurrentLocksFalse);
     metadataSupervisorManager.insert(EasyMock.anyString(), EasyMock.anyObject());
 
     replayAll();
@@ -737,7 +758,7 @@ public class SupervisorManagerTest extends EasyMockSupport
     metadataSupervisorManager.insert(EasyMock.anyString(), EasyMock.anyObject());
 
     SeekableStreamSupervisorSpec streamingSpec = EasyMock.createNiceMock(SeekableStreamSupervisorSpec.class);
-    SeekableStreamSupervisor streamSupervisor = EasyMock.mock(SeekableStreamSupervisor.class);
+    SeekableStreamSupervisor streamSupervisor = EasyMock.createNiceMock(SeekableStreamSupervisor.class);
     streamSupervisor.registerNewVersionOfPendingSegment(EasyMock.anyObject());
     EasyMock.expectLastCall().once();
     EasyMock.expect(streamingSpec.getId()).andReturn("sss").anyTimes();
@@ -746,7 +767,7 @@ public class SupervisorManagerTest extends EasyMockSupport
     EasyMock.expect(streamingSpec.createSupervisor()).andReturn(streamSupervisor).anyTimes();
     EasyMock.expect(streamingSpec.createAutoscaler(streamSupervisor)).andReturn(null).anyTimes();
     EasyMock.expect(streamingSpec.getContext()).andReturn(null).anyTimes();
-    EasyMock.replay(streamingSpec);
+    EasyMock.replay(streamingSpec, streamSupervisor);
     metadataSupervisorManager.insert(EasyMock.anyString(), EasyMock.anyObject());
     EasyMock.expectLastCall().once();
 
