@@ -25,35 +25,16 @@ package org.apache.druid.tests;
  */
 public class TestNGGroup
 {
-  public static final String KAFKA_INDEX = "kafka-index";
-
-  public static final String KAFKA_INDEX_SLOW = "kafka-index-slow";
-
-  public static final String TRANSACTIONAL_KAFKA_INDEX = "kafka-transactional-index";
-
-  public static final String TRANSACTIONAL_KAFKA_INDEX_SLOW = "kafka-transactional-index-slow";
-
-  public static final String APPEND_INGESTION = "append-ingestion";
-
   /**
    * This group can only be run individually using -Dgroups=query since it requires specific test data setup.
    */
   public static final String QUERY = "query";
 
-  public static final String QUERY_RETRY = "query-retry";
-
-  public static final String QUERY_ERROR = "query-error";
-
   /**
    * This group can only be run individually using -Dgroups=security since it requires specific test data setup.
    */
   public static final String SECURITY = "security";
 
-  /**
-   * This group can only be run individually using -Dgroups=ldap-security since it requires specific test data setup.
-   */
-  public static final String LDAP_SECURITY = "ldap-security";
-
   /**
    * This group is not part of CI. To run this group, s3 configs/credentials for your s3 must be provided in a file.
    * The path of the file must then be pass to mvn with -Doverride.config.path=<PATH_TO_FILE>
@@ -124,11 +105,5 @@ public class TestNGGroup
    */
   public static final String KINESIS_DATA_FORMAT = "kinesis-data-format";
 
-  public static final String CUSTOM_COORDINATOR_DUTIES = "custom-coordinator-duties";
-
   public static final String CENTRALIZED_DATASOURCE_SCHEMA = "centralized-datasource-schema";
-
-  public static final String CDS_TASK_SCHEMA_PUBLISH_DISABLED = "cds-task-schema-publish-disabled";
-
-  public static final String CDS_COORDINATOR_METADATA_QUERY_DISABLED = "cds-coordinator-metadata-query-disabled";
 }
