@@ -23,6 +23,8 @@ import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
+import com.google.common.math.IntMath;
+import com.google.common.primitives.Ints;
 import it.unimi.dsi.fastutil.ints.Int2IntAVLTreeMap;
 import it.unimi.dsi.fastutil.ints.Int2IntMap;
 import it.unimi.dsi.fastutil.ints.Int2ObjectAVLTreeMap;
@@ -36,14 +38,15 @@ import org.apache.druid.java.util.common.ISE;
 import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.msq.exec.ExtraInfoHolder;
 import org.apache.druid.msq.exec.OutputChannelMode;
-import org.apache.druid.msq.exec.QueryValidator;
 import org.apache.druid.msq.indexing.error.CanceledFault;
 import org.apache.druid.msq.indexing.error.MSQException;
 import org.apache.druid.msq.indexing.error.MSQFault;
 import org.apache.druid.msq.indexing.error.MSQFaultUtils;
+import org.apache.druid.msq.indexing.error.TooManyInputFilesFault;
 import org.apache.druid.msq.indexing.error.UnknownFault;
 import org.apache.druid.msq.indexing.error.WorkerFailedFault;
 import org.apache.druid.msq.indexing.error.WorkerRpcFailedFault;
+import org.apache.druid.msq.input.InputSlice;
 import org.apache.druid.msq.input.InputSpecSlicerFactory;
 import org.apache.druid.msq.input.stage.ReadablePartitions;
 import org.apache.druid.msq.kernel.QueryDefinition;
@@ -56,6 +59,7 @@ import org.apache.druid.msq.statistics.CompleteKeyStatisticsInformation;
 import org.apache.druid.msq.statistics.PartialKeyStatisticsInformation;
 
 import javax.annotation.Nullable;
+import java.math.RoundingMode;
 import java.util.ArrayDeque;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -178,14 +182,18 @@ public class ControllerQueryKernel
       final InputSpecSlicerFactory slicerFactory,
       final WorkerAssignmentStrategy assignmentStrategy,
       final FrameType rowBasedFrameType,
-      final long maxInputBytesPerWorker
+      final int maxInputFilesPerWorker,
+      final long maxInputBytesPerWorker,
+      final int maxPartitions
   )
   {
     createNewKernels(
         slicerFactory,
         assignmentStrategy,
         rowBasedFrameType,
-        maxInputBytesPerWorker
+        maxInputFilesPerWorker,
+        maxInputBytesPerWorker,
+        maxPartitions
     );
 
     return stageTrackers.values()
@@ -284,6 +292,7 @@ public class ControllerQueryKernel
    */
   public Int2ObjectMap<WorkOrder> createWorkOrders(
       final int stageNumber,
+      final int maxInputFilesPerWorker,
       @Nullable final Int2ObjectMap<Object> extraInfos
   )
   {
@@ -292,6 +301,8 @@ public class ControllerQueryKernel
     final WorkerInputs workerInputs = stageKernel.getWorkerInputs();
     final OutputChannelMode outputChannelMode = stageOutputChannelModes.get(stageKernel.getStageDefinition().getId());
 
+    int totalFileCount = 0;
+    boolean fault = false;
     for (int workerNumber : workerInputs.workers()) {
       final Object extraInfo = extraInfos != null ? extraInfos.get(workerNumber) : null;
 
@@ -310,9 +321,16 @@ public class ControllerQueryKernel
           config.getWorkerContextMap()
       );
 
-      QueryValidator.validateWorkOrder(workOrder);
+      final int numInputFiles = Ints.checkedCast(workOrder.getInputs().stream().mapToLong(InputSlice::fileCount).sum());
+      fault = fault || IntMath.divide(numInputFiles, maxInputFilesPerWorker, RoundingMode.CEILING) > 1;
+      totalFileCount += numInputFiles;
       workerToWorkOrder.put(workerNumber, workOrder);
     }
+
+    final int requiredWorkers = IntMath.divide(totalFileCount, maxInputFilesPerWorker, RoundingMode.CEILING);
+    if (fault) {
+      throw new MSQException(new TooManyInputFilesFault(totalFileCount, maxInputFilesPerWorker, requiredWorkers));
+    }
     stageWorkOrders.put(new StageId(queryDef.getQueryId(), stageNumber), workerToWorkOrder);
     return workerToWorkOrder;
   }
@@ -321,7 +339,9 @@ public class ControllerQueryKernel
       final InputSpecSlicerFactory slicerFactory,
       final WorkerAssignmentStrategy assignmentStrategy,
       final FrameType rowBasedFrameType,
-      final long maxInputBytesPerWorker
+      final int maxInputFilesPerWorker,
+      final long maxInputBytesPerWorker,
+      final int maxPartitions
   )
   {
     StageGroup stageGroup;
@@ -341,7 +361,9 @@ public class ControllerQueryKernel
                   slicerFactory,
                   assignmentStrategy,
                   rowBasedFrameType,
-                  maxInputBytesPerWorker
+                  maxInputFilesPerWorker,
+                  maxInputBytesPerWorker,
+                  maxPartitions
               )
           );
 
@@ -364,7 +386,9 @@ public class ControllerQueryKernel
       final InputSpecSlicerFactory slicerFactory,
       final WorkerAssignmentStrategy assignmentStrategy,
       final FrameType rowBasedFrameType,
-      final long maxInputBytesPerWorker
+      final int maxInputFilesPerWorker,
+      final long maxInputBytesPerWorker,
+      final int maxPartitions
   )
   {
     final Int2IntMap stageWorkerCountMap = new Int2IntAVLTreeMap();
@@ -394,7 +418,9 @@ public class ControllerQueryKernel
         assignmentStrategy,
         rowBasedFrameType,
         config.getMaxRetainedPartitionSketchBytes(),
-        maxInputBytesPerWorker
+        maxInputFilesPerWorker,
+        maxInputBytesPerWorker,
+        maxPartitions
     );
   }
 
@@ -555,7 +581,8 @@ public class ControllerQueryKernel
 
   /**
    * Checks if the stage can be started, delegates call to {@link ControllerStageTracker#start()} for internal phase
-   * transition and registers the transition in this queryKernel. Work orders need to be created via {@link ControllerQueryKernel#createWorkOrders(int, Int2ObjectMap)} before calling this method.
+   * transition and registers the transition in this queryKernel. Work orders need to be created via
+   * {@link ControllerQueryKernel#createWorkOrders(int, int, Int2ObjectMap)} before calling this method.
    */
   public void startStage(final StageId stageId)
   {
