@@ -34,11 +34,11 @@ import org.apache.druid.java.util.common.granularity.PeriodGranularity;
 import org.apache.druid.query.OrderBy;
 import org.apache.druid.query.aggregation.AggregatorFactory;
 import org.apache.druid.query.filter.DimFilter;
-import org.apache.druid.segment.AggregateProjectionMetadata;
 import org.apache.druid.segment.VirtualColumn;
 import org.apache.druid.segment.VirtualColumns;
 import org.apache.druid.segment.column.ColumnHolder;
 import org.apache.druid.segment.column.ValueType;
+import org.apache.druid.segment.projections.AggregateProjectionSchema;
 import org.apache.druid.utils.CollectionUtils;
 import org.joda.time.DateTimeZone;
 
@@ -162,9 +162,9 @@ public class AggregateProjectionSpec
   }
 
   @JsonIgnore
-  public AggregateProjectionMetadata.Schema toMetadataSchema()
+  public AggregateProjectionSchema toMetadataSchema()
   {
-    return new AggregateProjectionMetadata.Schema(
+    return new AggregateProjectionSchema(
         name,
         timeColumnName,
         filter,
