@@ -176,6 +176,17 @@ public abstract class DimensionSchema
   @JsonIgnore
   public abstract ColumnType getColumnType();
 
+  /**
+   * Returns true if the {@link DimensionHandler#makeIndexer()} of this schema can produce multi-valued
+   * {@link ColumnType#STRING} columns. This method is used by MSQ compaction to determine if it needs to download the
+   * segments to check if any are actually multi-valued.
+   */
+  @JsonIgnore
+  public boolean canBeMultiValued()
+  {
+    return false;
+  }
+
   @JsonIgnore
   public DimensionHandler getDimensionHandler()
   {
