@@ -23,6 +23,7 @@ import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import org.apache.druid.java.util.common.IAE;
 import org.apache.druid.java.util.common.StringUtils;
+import org.apache.druid.query.groupby.orderby.OrderByColumnSpec;
 
 import java.util.Objects;
 
@@ -84,4 +85,12 @@ public class KeyColumn
   {
     return StringUtils.format("%s%s", columnName, order == KeyOrder.NONE ? "" : " " + order);
   }
+
+  public static KeyColumn fromOrderByColumnSpec(OrderByColumnSpec orderByColumnSpec)
+  {
+    return new KeyColumn(
+        orderByColumnSpec.getDimension(),
+        KeyOrder.fromDirection(orderByColumnSpec.getDirection())
+    );
+  }
 }
