@@ -19,6 +19,8 @@
 
 package org.apache.druid.frame.write;
 
+import org.apache.druid.error.DruidException;
+import org.apache.druid.frame.FrameType;
 import org.apache.druid.frame.allocation.MemoryAllocatorFactory;
 import org.apache.druid.frame.key.KeyColumn;
 import org.apache.druid.frame.write.columnar.ColumnarFrameWriterFactory;
@@ -44,20 +46,35 @@ public class FrameWriters
   /**
    * Creates a {@link FrameWriterFactory}.
    *
+   * @param frameType        frame type to write
    * @param allocatorFactory supplier of allocators, which ultimately determine frame size. Frames are closed and
    *                         written once the allocator runs out of memory.
    * @param signature        signature of the frames
    * @param sortColumns      sort columns for the frames. If nonempty, {@link FrameSort#sort} is used to sort the
    *                         resulting frames.
+   * @param removeNullBytes  whether null bytes should be removed from strings as part of writing to the frame.
+   *                         Can only be set to "true" for row-based frame types.
    */
-  public static FrameWriterFactory makeRowBasedFrameWriterFactory(
+  public static FrameWriterFactory makeFrameWriterFactory(
+      final FrameType frameType,
       final MemoryAllocatorFactory allocatorFactory,
       final RowSignature signature,
       final List<KeyColumn> sortColumns,
       final boolean removeNullBytes
   )
   {
-    return new RowBasedFrameWriterFactory(allocatorFactory, signature, sortColumns, removeNullBytes);
+    if (frameType.isRowBased()) {
+      return new RowBasedFrameWriterFactory(allocatorFactory, frameType, signature, sortColumns, removeNullBytes);
+    } else {
+      // Columnar.
+      if (removeNullBytes) {
+        // Defensive exception because user-provided "removeNullBytes" should never make it this far. Calling code
+        // should take care to not request columnar writers with removeNullBytes = true.
+        throw DruidException.defensive("Cannot use removeNullBytes with frameType[%s]", frameType);
+      }
+
+      return new ColumnarFrameWriterFactory(allocatorFactory, signature, sortColumns);
+    }
   }
 
   public static FrameWriterFactory makeColumnBasedFrameWriterFactory(
