@@ -20,6 +20,7 @@
 package org.apache.druid.guice;
 
 import com.fasterxml.jackson.annotation.JacksonInject;
+import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.fasterxml.jackson.databind.introspect.AnnotatedField;
@@ -45,15 +46,19 @@ import javax.validation.Validator;
 import java.io.IOException;
 import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.Properties;
 import java.util.Set;
 
 /**
+ *
  */
 public class JsonConfigurator
 {
@@ -125,8 +130,14 @@ public class JsonConfigurator
     try {
       if (defaultClass != null && jsonMap.isEmpty()) {
         // No configs were provided. Don't use the jsonMapper; instead create a default instance of the default class
-        // using the no-arg constructor. We know it exists because verifyClazzIsConfigurable checks for it.
-        config = defaultClass.getConstructor().newInstance();
+        // using the JsonCreator annotated factory method or no-arg constructor.
+        // We know it exists because verifyClazzIsConfigurable checks for it.
+        Optional<Method> factoryMethod = findJsonCreatorFactoryMethod(defaultClass);
+        if (factoryMethod.isPresent()) {
+          config = (T) factoryMethod.get().invoke(null);
+        } else {
+          config = defaultClass.getConstructor().newInstance();
+        }
       } else {
         config = jsonMapper.convertValue(jsonMap, clazz);
       }
@@ -256,7 +267,9 @@ public class JsonConfigurator
   {
     if (defaultClass != null) {
       try {
-        defaultClass.getConstructor();
+        if (findJsonCreatorFactoryMethod(defaultClass).isEmpty()) {
+          defaultClass.getConstructor();
+        }
       }
       catch (NoSuchMethodException e) {
         throw new ProvisionException(
@@ -283,4 +296,15 @@ public class JsonConfigurator
       }
     }
   }
+
+  private static <T> Optional<Method> findJsonCreatorFactoryMethod(Class<T> clazz)
+  {
+    return Arrays.stream(clazz.getMethods())
+                 .filter(m -> m.getAnnotation(JsonCreator.class) != null
+                              && m.getParameterCount() == 0
+                              && m.getReturnType()
+                                  .equals(clazz))
+                 .findFirst();
+
+  }
 }
