@@ -21,6 +21,7 @@ package org.apache.druid.indexer.partitions;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import org.apache.druid.error.InvalidInput;
 
 import javax.annotation.Nullable;
 import java.util.Objects;
@@ -50,6 +51,15 @@ public class DynamicPartitionsSpec implements PartitionsSpec
       @JsonProperty("maxTotalRows") @Nullable Long maxTotalRows
   )
   {
+
+    if (!PartitionsSpec.isEffectivelyNull(maxRowsPerSegment) && maxRowsPerSegment <= 0) {
+      throw InvalidInput.exception("maxRowsPerSegment must be greater than 0");
+    }
+
+    if (!PartitionsSpec.isEffectivelyNull(maxTotalRows) && maxTotalRows <= 0) {
+      throw InvalidInput.exception("maxTotalRows must be greater than 0");
+    }
+
     this.maxRowsPerSegment = PartitionsSpec.isEffectivelyNull(maxRowsPerSegment)
                              ? DEFAULT_MAX_ROWS_PER_SEGMENT
                              : maxRowsPerSegment;
