@@ -24,6 +24,7 @@ import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.java.util.emitter.service.ServiceEmitter;
 import org.apache.druid.java.util.emitter.service.ServiceMetricEvent;
 import org.apache.druid.java.util.metrics.cgroups.CgroupDiscoverer;
+import org.apache.druid.java.util.metrics.cgroups.CgroupVersion;
 import org.apache.druid.java.util.metrics.cgroups.Cpu;
 import org.apache.druid.java.util.metrics.cgroups.ProcSelfCgroupDiscoverer;
 
@@ -39,64 +40,61 @@ public class CgroupCpuMonitor extends FeedDefiningMonitor
   private static final Logger LOG = new Logger(CgroupCpuMonitor.class);
   private static final Long DEFAULT_USER_HZ = 100L;
   final CgroupDiscoverer cgroupDiscoverer;
-  final Map<String, String[]> dimensions;
   private Long userHz;
-  private KeyedDiff jiffies = new KeyedDiff();
+  private final KeyedDiff jiffies = new KeyedDiff();
   private long prevJiffiesSnapshotAt = 0;
+  private final boolean isRunningOnCgroupsV2;
+  private final CgroupV2CpuMonitor cgroupV2CpuMonitor;
 
-  public CgroupCpuMonitor(CgroupDiscoverer cgroupDiscoverer, final Map<String, String[]> dimensions, String feed)
+  public CgroupCpuMonitor(CgroupDiscoverer cgroupDiscoverer, String feed)
   {
     super(feed);
     this.cgroupDiscoverer = cgroupDiscoverer;
-    this.dimensions = dimensions;
-    try {
-      Process p = new ProcessBuilder("getconf", "CLK_TCK").start();
-      try (BufferedReader in = new BufferedReader(new InputStreamReader(p.getInputStream(), StandardCharsets.UTF_8))) {
-        String line = in.readLine();
-        if (line != null) {
-          userHz = Long.valueOf(line.trim());
-        }
-      }
-    }
-    catch (IOException | NumberFormatException e) {
-      LOG.warn(e, "Error getting the USER_HZ value");
-    }
-    finally {
-      if (userHz == null) {
-        LOG.warn("Using default value for USER_HZ");
-        userHz = DEFAULT_USER_HZ;
-      }
+
+    // Check if we're running on cgroups v2
+    this.isRunningOnCgroupsV2 = cgroupDiscoverer.getCgroupVersion().equals(CgroupVersion.V2);
+    if (isRunningOnCgroupsV2) {
+      this.cgroupV2CpuMonitor = new CgroupV2CpuMonitor(cgroupDiscoverer, feed);
+      LOG.info("Detected cgroups v2, using CgroupV2CpuMonitor behavior for accurate metrics");
+    } else {
+      this.cgroupV2CpuMonitor = null;
+      initUzerHz();
     }
+
   }
 
-  public CgroupCpuMonitor(final Map<String, String[]> dimensions, String feed)
+  public CgroupCpuMonitor(String feed)
   {
-    this(new ProcSelfCgroupDiscoverer(), dimensions, feed);
-  }
-
-  public CgroupCpuMonitor(final Map<String, String[]> dimensions)
-  {
-    this(dimensions, DEFAULT_METRICS_FEED);
+    this(ProcSelfCgroupDiscoverer.autoCgroupDiscoverer(), feed);
   }
 
   public CgroupCpuMonitor()
   {
-    this(ImmutableMap.of());
+    this(DEFAULT_METRICS_FEED);
   }
 
   @Override
   public boolean doMonitor(ServiceEmitter emitter)
   {
-    final Cpu cpu = new Cpu(cgroupDiscoverer);
-    final Cpu.CpuMetrics cpuSnapshot = cpu.snapshot();
+    if (isRunningOnCgroupsV2) {
+      return cgroupV2CpuMonitor.doMonitor(emitter);
+    } else {
+      return doMonitorV1(emitter);
+    }
+  }
+
+  private boolean doMonitorV1(ServiceEmitter emitter)
+  {
+    final Cpu.CpuMetrics cpuSnapshot = cgroupDiscoverer.getCpuMetrics();
     long now = Instant.now().getEpochSecond();
 
     final ServiceMetricEvent.Builder builder = builder();
-    MonitorUtils.addDimensionsToBuilder(builder, dimensions);
+    builder.setDimension("cgroupversion", cgroupDiscoverer.getCgroupVersion().name());
+
     emitter.emit(builder.setMetric("cgroup/cpu/shares", cpuSnapshot.getShares()));
     emitter.emit(builder.setMetric(
         "cgroup/cpu/cores_quota",
-        computeProcessorQuota(cpuSnapshot.getQuotaUs(), cpuSnapshot.getPeriodUs())
+        CgroupUtil.computeProcessorQuota(cpuSnapshot.getQuotaUs(), cpuSnapshot.getPeriodUs())
     ));
 
     long elapsedJiffiesSnapshotSecs = now - prevJiffiesSnapshotAt;
@@ -122,18 +120,25 @@ public class CgroupCpuMonitor extends FeedDefiningMonitor
     return true;
   }
 
-  /**
-   * Calculates the total cores allocated through quotas. A negative value indicates that no quota has been specified.
-   * We use -1 because that's the default value used in the cgroup.
-   *
-   * @param quotaUs  the cgroup quota value.
-   * @param periodUs the cgroup period value.
-   * @return the calculated processor quota, -1 if no quota or period set.
-   */
-  public static double computeProcessorQuota(long quotaUs, long periodUs)
+  private void initUzerHz()
   {
-    return quotaUs < 0 || periodUs == 0
-           ? -1
-           : (double) quotaUs / periodUs;
+    try {
+      Process p = new ProcessBuilder("getconf", "CLK_TCK").start();
+      try (BufferedReader in = new BufferedReader(new InputStreamReader(p.getInputStream(), StandardCharsets.UTF_8))) {
+        String line = in.readLine();
+        if (line != null) {
+          userHz = Long.valueOf(line.trim());
+        }
+      }
+    }
+    catch (IOException | NumberFormatException e) {
+      LOG.warn(e, "Error getting the USER_HZ value");
+    }
+    finally {
+      if (userHz == null) {
+        LOG.warn("Using default value for USER_HZ");
+        userHz = DEFAULT_USER_HZ;
+      }
+    }
   }
 }
