@@ -20,14 +20,13 @@
 package org.apache.druid.java.util.metrics;
 
 import com.google.common.collect.ImmutableList;
-import com.google.common.collect.ImmutableMap;
 import org.apache.druid.java.util.emitter.service.ServiceEmitter;
 
 public class NoopOshiSysMonitor extends OshiSysMonitor
 {
   public NoopOshiSysMonitor()
   {
-    super(ImmutableMap.of(), new OshiSysMonitorConfig(ImmutableList.of()));
+    super(new OshiSysMonitorConfig(ImmutableList.of()));
   }
 
   @Override
