@@ -32,6 +32,11 @@ import org.apache.druid.query.filter.ColumnIndexSelector;
 import org.apache.druid.segment.column.ColumnCapabilities;
 import org.apache.druid.segment.column.ColumnIndexSupplier;
 import org.apache.druid.segment.column.ColumnType;
+import org.apache.druid.segment.filter.Filters;
+import org.apache.druid.segment.index.AllFalseBitmapColumnIndex;
+import org.apache.druid.segment.index.AllTrueBitmapColumnIndex;
+import org.apache.druid.segment.index.AllUnknownBitmapColumnIndex;
+import org.apache.druid.segment.index.BitmapColumnIndex;
 import org.apache.druid.segment.index.semantic.DictionaryEncodedValueIndex;
 import org.apache.druid.segment.serde.NoIndexesColumnIndexSupplier;
 import org.apache.druid.segment.virtual.ExpressionSelectors;
@@ -184,13 +189,6 @@ public interface Expr extends Cacheable
     return false;
   }
 
-
-  default boolean canFallbackVectorize(InputBindingInspector inspector, List<Expr> args)
-  {
-    return ExpressionProcessing.allowVectorizeFallback() &&
-           getOutputType(inspector) != null &&
-           inspector.canVectorize(args);
-  }
   /**
    * Possibly convert the {@link Expr} into an optimized, possibly not thread-safe {@link Expr}. Does not convert
    * child {@link Expr}. Most callers should use {@link Expr#singleThreaded(Expr, InputBindingInspector)} to convert
@@ -212,6 +210,19 @@ public interface Expr extends Cacheable
     throw Exprs.cannotVectorize(this);
   }
 
+  /**
+   * Allows an {@link Expr} to provide an {@link ColumnIndexSupplier} given access to the underlying
+   * {@link ColumnIndexSupplier} and {@link org.apache.druid.segment.column.ColumnHolder} of the base table.
+   * <p>
+   * The default implementation provides an index supplier if there is a single input column, and that column can
+   * provide {@link DictionaryEncodedValueIndex}, then the expression can provide
+   * {@link org.apache.druid.segment.index.semantic.DruidPredicateIndexes} that apply a predicate.
+   * <p>
+   * This method has the same null contract as {@link ColumnIndexSelector#getIndexSupplier(String)}, and should only
+   * return null if the column is completely null and the {@link Expr} produces a null constant in the missing column
+   * case. Otherwise, if no index supplier can be provided, this method should return
+   * {@link NoIndexesColumnIndexSupplier#getInstance()}.
+   */
   @Nullable
   default ColumnIndexSupplier asColumnIndexSupplier(
       ColumnIndexSelector columnIndexSelector,
@@ -228,7 +239,7 @@ public interface Expr extends Cacheable
       if (delegateIndexSupplier == null) {
         // if the column doesn't exist, check to see if the expression evaluates to a non-null result... if so, we might
         // need to make a value matcher anyway
-        if (eval(InputBindings.nilBindings()).valueOrDefault() != null) {
+        if (eval(InputBindings.nilBindings()).value() != null) {
           return NoIndexesColumnIndexSupplier.getInstance();
         }
         return null;
@@ -264,6 +275,52 @@ public interface Expr extends Cacheable
     return NoIndexesColumnIndexSupplier.getInstance();
   }
 
+  /**
+   * Allows an {@link Expr} to be computed into a {@link BitmapColumnIndex}. The supplied {@link ColumnIndexSelector}
+   * provides access to underlying {@link ColumnIndexSupplier} and even
+   * {@link org.apache.druid.segment.column.ColumnHolder}. Coupled with
+   * {@link #asColumnIndexSupplier(ColumnIndexSelector, ColumnType)}, which allows {@link Expr} to provide indexes of
+   * their own, it allows for a system of composing additional indexes on top of any base column structures.
+   * <p>
+   * For example, {@link BinEqExpr} where one argument is a constant, can use the
+   * {@link org.apache.druid.segment.index.semantic.ValueIndexes} if present of the non-constant arguments' index
+   * supplier.
+   * <p>
+   * If this method returns null, it means that an index could not be produced for this {@link Expr}.
+   */
+  @Nullable
+  default BitmapColumnIndex asBitmapColumnIndex(ColumnIndexSelector selector)
+  {
+    final Expr.BindingAnalysis details = analyzeInputs();
+    if (details.getRequiredBindings().isEmpty()) {
+      // Constant expression.
+      final ExprEval<?> eval = eval(InputBindings.nilBindings());
+      if (eval.value() == null) {
+        return new AllUnknownBitmapColumnIndex(selector);
+      }
+      if (eval.asBoolean()) {
+        return new AllTrueBitmapColumnIndex(selector);
+      }
+      return new AllFalseBitmapColumnIndex(selector.getBitmapFactory());
+    } else if (details.getRequiredBindings().size() == 1) {
+      // Single-column expression. We can use bitmap indexes if this column has an index and the expression can
+      // map over the values of the index.
+      final String column = Iterables.getOnlyElement(details.getRequiredBindings());
+
+      // we use a default 'all false' capabilities here because if the column has a bitmap index, but the capabilities
+      // are null, it means that the column is missing and should take the single valued path, while truly unknown
+      // things will not have a bitmap index available
+      final ColumnCapabilities capabilities = selector.getColumnCapabilities(column);
+      if (ExpressionSelectors.canMapOverDictionary(details, capabilities)) {
+        return Filters.makePredicateIndex(
+            column,
+            selector,
+            new ExpressionDruidPredicateFactory(this, capabilities)
+        );
+      }
+    }
+    return null;
+  }
 
   /**
    * Decorates the {@link CacheKeyBuilder} for the default implementation of {@link #getCacheKey()}. The default cache
