@@ -19,6 +19,7 @@
 
 package org.apache.druid.math.expr.vector;
 
+import org.apache.druid.math.expr.Evals;
 import org.apache.druid.math.expr.ExpressionType;
 
 import java.util.Arrays;
@@ -69,4 +70,13 @@ public final class ExprEvalDoubleVector extends BaseExprEvalVector<double[]>
     }
     return objects;
   }
+
+  @Override
+  public boolean elementAsBoolean(int index)
+  {
+    if (nulls != null && nulls[index]) {
+      return false;
+    }
+    return Evals.asBoolean(values[index]);
+  }
 }
