@@ -21,9 +21,10 @@ package org.apache.druid.query;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonValue;
+import org.apache.druid.java.util.common.Cacheable;
 import org.apache.druid.java.util.common.StringUtils;
 
-public enum Order
+public enum Order implements Cacheable
 {
   ASCENDING,
   DESCENDING,
@@ -41,4 +42,10 @@ public enum Order
   {
     return valueOf(StringUtils.toUpperCase(name));
   }
+
+  @Override
+  public byte[] getCacheKey()
+  {
+    return StringUtils.toUtf8(toString());
+  }
 }
