@@ -361,6 +361,52 @@ public interface QueryMetrics<QueryType extends Query<?>>
    */
   QueryMetrics<QueryType> reportSegmentAndCacheTime(long timeNs);
 
+
+  /**
+   * Registers the apparent time spent loading segments on demand, before queing up for processing. This measurement is
+   * wall-clock time to when the last segment is finished loading and ready for processing.
+   * <p>
+   * Emitted once per query
+   */
+  QueryMetrics<QueryType> reportSegmentOnDemandLoadTime(long timeNs);
+  /**
+   * Registers the average time spent loading segments on demand across threads.
+   * <p>
+   * Emitted once per query
+   */
+  QueryMetrics<QueryType> reportSegmentOnDemandLoadTimeAvg(long timeNs);
+  /**
+   * Registers the maximum time spent loading segments on demand across all load threads.
+   * <p>
+   * Emitted once per query
+   */
+  QueryMetrics<QueryType> reportSegmentOnDemandLoadWaitTimeMax(long timeNs);
+  /**
+   * Registers the average time spent waiting for a thread to start loading segments on demand across threads.
+   * <p>
+   * Emitted once per query
+   */
+  QueryMetrics<QueryType> reportSegmentOnDemandLoadWaitTimeAvg(long timeNs);
+  /**
+   * Registers the maximum time spent waiting for a thread to start loading segments on demand across all load threads.
+   * <p>
+   * Emitted once per query
+   */
+  QueryMetrics<QueryType> reportSegmentOnDemandLoadTimeMax(long timeNs);
+  /**
+   * Registers the total number of bytes added to the cache when loading segments on demand, summing the sizes loaded by
+   * individual segement load threads.
+   * <p>
+   * Emitted once per query
+   */
+  QueryMetrics<QueryType> reportSegmentOnDemandLoadBytes(long byteCount);
+  /**
+   * Registers the total numer of segments loaded on demand.
+   * <p>
+   * Emitted once per query
+   */
+  QueryMetrics<QueryType> reportSegmentOnDemandLoadCount(long count);
+
   /**
    * Emits iff a given query polled the result-level cache and the success of that operation.
    */
