@@ -24,4 +24,8 @@ package org.apache.druid.query;
 public interface QueryRunnerFactoryConglomerate
 {
   <T, QueryType extends Query<T>> QueryRunnerFactory<T, QueryType> findFactory(QueryType query);
+
+  <T, QueryType extends Query<T>> QueryToolChest<T, QueryType> getToolChest(QueryType query);
+
+  <T, QueryType extends Query<T>> QueryLogic getQueryLogic(QueryType query);
 }
