@@ -422,4 +422,11 @@ public abstract class QueryToolChest<ResultType, QueryType extends Query<ResultT
   {
     return Optional.empty();
   }
+
+  public <T> boolean canExecuteFully(Query<T> query)
+  {
+    DataSource dataSourceFromQuery = query.getDataSource();
+    return (!(dataSourceFromQuery instanceof QueryDataSource)
+        || canPerformSubquery(((QueryDataSource) dataSourceFromQuery).getQuery()));
+  }
 }
