@@ -23,6 +23,7 @@ import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import com.google.common.base.Preconditions;
 import com.google.common.collect.ImmutableList;
+import org.apache.druid.math.expr.ExprMacroTable;
 import org.apache.druid.segment.ColumnInspector;
 import org.apache.druid.segment.ColumnSelectorFactory;
 import org.apache.druid.segment.column.ColumnType;
@@ -39,9 +40,7 @@ public class CountAggregatorFactory extends AggregatorFactory
   private final String name;
 
   @JsonCreator
-  public CountAggregatorFactory(
-      @JsonProperty("name") String name
-  )
+  public CountAggregatorFactory(@JsonProperty("name") String name)
   {
     Preconditions.checkNotNull(name, "Must have a valid, non-null aggregator name");
 
@@ -93,7 +92,7 @@ public class CountAggregatorFactory extends AggregatorFactory
   @Override
   public AggregatorFactory getCombiningFactory()
   {
-    return new LongSumAggregatorFactory(name, name);
+    return new LongSumAggregatorFactory(name, name, null, ExprMacroTable.nil(), true);
   }
 
   @Override
