@@ -19,8 +19,6 @@
 
 package org.apache.druid.query.expression;
 
-import org.apache.druid.error.InvalidInput;
-import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.math.expr.Expr;
 import org.apache.druid.math.expr.ExprEval;
 import org.apache.druid.math.expr.ExprMacroTable;
@@ -31,7 +29,6 @@ import javax.annotation.Nullable;
 import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-import java.util.regex.PatternSyntaxException;
 
 public class RegexpExtractExprMacro implements ExprMacroTable.ExprMacro
 {
@@ -61,7 +58,7 @@ public class RegexpExtractExprMacro implements ExprMacroTable.ExprMacro
     }
 
     // Precompile the pattern.
-    final Pattern pattern = compilePattern((String) patternExpr.getLiteralValue());
+    final Pattern pattern = RegexpExprUtils.compilePattern((String) patternExpr.getLiteralValue(), FN_NAME);
 
     final int index = indexExpr == null ? 0 : ((Number) indexExpr.getLiteralValue()).intValue();
 
@@ -97,25 +94,4 @@ public class RegexpExtractExprMacro implements ExprMacroTable.ExprMacro
     }
     return new RegexpExtractExpr(args);
   }
-
-  /**
-   * Compile the provided pattern, or provide a nice error message if it cannot be compiled.
-   */
-  private static Pattern compilePattern(@Nullable String pattern)
-  {
-    try {
-      return Pattern.compile(StringUtils.nullToEmptyNonDruidDataString(pattern));
-    }
-    catch (PatternSyntaxException e) {
-      throw InvalidInput.exception(
-          e,
-          StringUtils.format(
-              "An invalid pattern [%s] was provided for the %s function, error: [%s]",
-              e.getPattern(),
-              FN_NAME,
-              e.getMessage()
-          )
-      );
-    }
-  }
 }
