@@ -27,6 +27,9 @@ import org.apache.druid.math.expr.ExprEval;
 import org.apache.druid.math.expr.ExprMacroTable;
 import org.apache.druid.math.expr.ExpressionType;
 import org.apache.druid.math.expr.InputBindings;
+import org.apache.druid.math.expr.vector.CastToTypeVectorProcessor;
+import org.apache.druid.math.expr.vector.ExprVectorProcessor;
+import org.apache.druid.math.expr.vector.LongUnivariateLongFunctionVectorProcessor;
 
 import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
@@ -73,7 +76,7 @@ public class TimestampCeilExprMacro implements ExprMacroTable.ExprMacro
       ExprEval eval = args.get(0).eval(bindings);
       if (eval.isNumericNull()) {
         // Return null if the argument if null.
-        return ExprEval.of(null);
+        return ExprEval.ofLong(null);
       }
       long argTime = eval.asLong();
       long bucketStartTime = granularity.bucketStart(argTime);
@@ -90,6 +93,29 @@ public class TimestampCeilExprMacro implements ExprMacroTable.ExprMacro
       return ExpressionType.LONG;
     }
 
+    @Override
+    public boolean canVectorize(InputBindingInspector inspector)
+    {
+      return args.get(0).canVectorize(inspector);
+    }
+
+    @Override
+    public <T> ExprVectorProcessor<T> asVectorProcessor(VectorInputBindingInspector inspector)
+    {
+      final ExprVectorProcessor<?> processor = new LongUnivariateLongFunctionVectorProcessor(
+          CastToTypeVectorProcessor.cast(args.get(0).asVectorProcessor(inspector), ExpressionType.LONG),
+          argTime -> {
+            long bucketStartTime = granularity.bucketStart(argTime);
+            if (argTime == bucketStartTime) {
+              return bucketStartTime;
+            }
+            return granularity.increment(bucketStartTime);
+          }
+      );
+
+      return (ExprVectorProcessor<T>) processor;
+    }
+
     @Override
     public boolean equals(Object o)
     {
