@@ -275,7 +275,7 @@ public class TimeseriesQueryQueryToolChest extends QueryToolChest<Result<Timeser
       private final List<AggregatorFactory> aggs = query.getAggregatorSpecs();
 
       @Override
-      public boolean isCacheable(TimeseriesQuery query, boolean willMergeRunners, boolean bySegment)
+      public boolean isCacheable(TimeseriesQuery query, boolean willMergeRunners, boolean segmentLevel)
       {
         return true;
       }
