@@ -31,8 +31,6 @@ import org.apache.druid.java.util.common.ISE;
 import org.apache.druid.java.util.common.Pair;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.io.Closer;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
-import org.apache.druid.java.util.common.io.smoosh.SmooshedFileMapper;
 import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.query.filter.DruidPredicateFactory;
 import org.apache.druid.query.filter.ValueMatcher;
@@ -54,6 +52,8 @@ import org.apache.druid.segment.data.SingleValueColumnarIntsSerializer;
 import org.apache.druid.segment.data.V3CompressedVSizeColumnarMultiIntsSerializer;
 import org.apache.druid.segment.data.VSizeColumnarIntsSerializer;
 import org.apache.druid.segment.data.VSizeColumnarMultiIntsSerializer;
+import org.apache.druid.segment.file.SegmentFileBuilder;
+import org.apache.druid.segment.file.SegmentFileMapper;
 import org.apache.druid.segment.serde.ColumnSerializerUtils;
 import org.apache.druid.segment.serde.Serializer;
 import org.apache.druid.segment.writeout.SegmentWriteOutMedium;
@@ -769,7 +769,7 @@ public abstract class DictionaryEncodedColumnMerger<T extends Comparable<T>> imp
     }
 
     @Override
-    public void writeTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException
+    public void writeTo(WritableByteChannel channel, SegmentFileBuilder fileBuilder) throws IOException
     {
       // currently no support for id conversion buffers larger than 2gb
       buffer.position(0);
@@ -829,7 +829,7 @@ public abstract class DictionaryEncodedColumnMerger<T extends Comparable<T>> imp
   protected static class PersistedIdConversion implements Closeable
   {
     private final File idConversionFile;
-    private final SmooshedFileMapper bufferMapper;
+    private final SegmentFileMapper bufferMapper;
     private final IntBuffer buffer;
 
     private boolean isClosed;
