@@ -22,8 +22,8 @@ package org.apache.druid.segment.data;
 import com.google.common.base.Supplier;
 import org.apache.druid.io.Channels;
 import org.apache.druid.java.util.common.IAE;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
-import org.apache.druid.java.util.common.io.smoosh.SmooshedFileMapper;
+import org.apache.druid.segment.file.SegmentFileBuilder;
+import org.apache.druid.segment.file.SegmentFileMapper;
 import org.apache.druid.segment.serde.MetaSerdeHelper;
 import org.apache.druid.segment.serde.Serializer;
 
@@ -78,7 +78,7 @@ public class CompressedColumnarFloatsSupplier implements Supplier<ColumnarFloats
   }
 
   @Override
-  public void writeTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException
+  public void writeTo(WritableByteChannel channel, SegmentFileBuilder fileBuilder) throws IOException
   {
     META_SERDE_HELPER.writeTo(channel, this);
     Channels.writeFully(channel, buffer.asReadOnlyBuffer());
@@ -86,17 +86,17 @@ public class CompressedColumnarFloatsSupplier implements Supplier<ColumnarFloats
 
   /**
    * Reads a column from a {@link ByteBuffer}, possibly using additional secondary files from a
-   * {@link SmooshedFileMapper}.
+   * {@link SegmentFileMapper}.
    *
-   * @param buffer       primary buffer to read from
-   * @param order        byte order
-   * @param smooshMapper required for reading version 2 (multi-file) indexed. May be null if you know you are reading
-   *                     a single-file column. Generally, this should only be null in tests, not production code.
+   * @param buffer     primary buffer to read from
+   * @param order      byte order
+   * @param fileMapper required for reading version 2 (multi-file) indexed. May be null if you know you are reading
+   *                   a single-file column. Generally, this should only be null in tests, not production code.
    */
   public static CompressedColumnarFloatsSupplier fromByteBuffer(
       ByteBuffer buffer,
       ByteOrder order,
-      @Nullable SmooshedFileMapper smooshMapper
+      @Nullable SegmentFileMapper fileMapper
   )
   {
     byte versionFromBuffer = buffer.get();
@@ -115,7 +115,7 @@ public class CompressedColumnarFloatsSupplier implements Supplier<ColumnarFloats
           buffer.asReadOnlyBuffer(),
           order,
           compression,
-          smooshMapper
+          fileMapper
       );
       return new CompressedColumnarFloatsSupplier(
           totalSize,
