@@ -22,8 +22,8 @@ package org.apache.druid.segment.data;
 import com.google.common.base.Supplier;
 import org.apache.druid.io.Channels;
 import org.apache.druid.java.util.common.IAE;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
-import org.apache.druid.java.util.common.io.smoosh.SmooshedFileMapper;
+import org.apache.druid.segment.file.SegmentFileBuilder;
+import org.apache.druid.segment.file.SegmentFileMapper;
 import org.apache.druid.segment.serde.MetaSerdeHelper;
 import org.apache.druid.segment.serde.Serializer;
 
@@ -93,7 +93,7 @@ public class CompressedColumnarLongsSupplier implements Supplier<ColumnarLongs>,
   }
 
   @Override
-  public void writeTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException
+  public void writeTo(WritableByteChannel channel, SegmentFileBuilder fileBuilder) throws IOException
   {
     META_SERDE_HELPER.writeTo(channel, this);
     Channels.writeFully(channel, buffer.asReadOnlyBuffer());
@@ -101,17 +101,17 @@ public class CompressedColumnarLongsSupplier implements Supplier<ColumnarLongs>,
 
   /**
    * Reads a column from a {@link ByteBuffer}, possibly using additional secondary files from a
-   * {@link SmooshedFileMapper}.
+   * {@link SegmentFileMapper}.
    *
-   * @param buffer       primary buffer to read from
-   * @param order        byte order
-   * @param smooshMapper required for reading version 2 (multi-file) indexed. May be null if you know you are reading
-   *                     a single-file column. Generally, this should only be null in tests, not production code.
+   * @param buffer     primary buffer to read from
+   * @param order      byte order
+   * @param fileMapper required for reading version 2 (multi-file) indexed. May be null if you know you are reading
+   *                   a single-file column. Generally, this should only be null in tests, not production code.
    */
   public static CompressedColumnarLongsSupplier fromByteBuffer(
       ByteBuffer buffer,
       ByteOrder order,
-      @Nullable SmooshedFileMapper smooshMapper
+      @Nullable SegmentFileMapper fileMapper
   )
   {
     byte versionFromBuffer = buffer.get();
@@ -136,7 +136,7 @@ public class CompressedColumnarLongsSupplier implements Supplier<ColumnarLongs>,
           order,
           encoding,
           compression,
-          smooshMapper
+          fileMapper
       );
       return new CompressedColumnarLongsSupplier(
           totalSize,
