@@ -21,8 +21,8 @@ package org.apache.druid.segment.data;
 
 import org.apache.druid.common.utils.ByteUtils;
 import org.apache.druid.java.util.common.io.Closer;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
 import org.apache.druid.segment.IndexIO;
+import org.apache.druid.segment.file.SegmentFileBuilder;
 import org.apache.druid.segment.serde.MetaSerdeHelper;
 import org.apache.druid.segment.writeout.SegmentWriteOutMedium;
 
@@ -176,11 +176,11 @@ public class CompressedVSizeColumnarIntsSerializer extends SingleValueColumnarIn
   }
 
   @Override
-  public void writeTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException
+  public void writeTo(WritableByteChannel channel, SegmentFileBuilder fileBuilder) throws IOException
   {
     writeEndBuffer();
     META_SERDE_HELPER.writeTo(channel, this);
-    flattener.writeTo(channel, smoosher);
+    flattener.writeTo(channel, fileBuilder);
   }
 
   private void writeEndBuffer() throws IOException
