@@ -21,9 +21,9 @@ package org.apache.druid.segment.data;
 
 import org.apache.druid.error.DruidException;
 import org.apache.druid.io.Channels;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
 import org.apache.druid.segment.column.TypeStrategies;
 import org.apache.druid.segment.column.TypeStrategy;
+import org.apache.druid.segment.file.SegmentFileBuilder;
 import org.apache.druid.segment.writeout.SegmentWriteOutMedium;
 import org.apache.druid.segment.writeout.WriteOutBytes;
 
@@ -129,7 +129,7 @@ public class FixedIndexedWriter<T> implements DictionaryWriter<T>
   @Override
   public void writeTo(
       WritableByteChannel channel,
-      FileSmoosher smoosher
+      SegmentFileBuilder fileBuilder
   ) throws IOException
   {
     scratch.clear();
