@@ -19,7 +19,6 @@
 
 package org.apache.druid.segment.index;
 
-import org.apache.druid.common.config.NullHandling;
 import org.apache.druid.query.BitmapResultFactory;
 import org.apache.druid.segment.column.ColumnIndexCapabilities;
 
@@ -52,7 +51,6 @@ public interface BitmapColumnIndex
    * @param includeUnknown      mapping for Druid native two state logic system into SQL three-state logic system. If set
    *                            to true, bitmaps returned by this method should include true bits for any rows where
    *                            the matching result is 'unknown', such as from the input being null valued.
-   *                            See {@link NullHandling#useThreeValueLogic()}.
    * @return bitmap result representing rows matched by this index
    */
   <T> T computeBitmapResult(
@@ -75,7 +73,7 @@ public interface BitmapColumnIndex
    * @param includeUnknown      mapping for Druid native two state logic system into SQL three-state logic system. If
    *                            set to true, bitmaps returned by this method should include true bits for any rows where
    *                            the matching result is 'unknown', such as from the input being null valued.
-   *                            See {@link NullHandling#useThreeValueLogic()}.
+   *
    * @return bitmap result representing rows matched by this index
    */
   @Nullable
