@@ -30,15 +30,16 @@ import org.apache.druid.collections.bitmap.ImmutableBitmap;
 import org.apache.druid.collections.bitmap.MutableBitmap;
 import org.apache.druid.io.Channels;
 import org.apache.druid.java.util.common.io.Closer;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
-import org.apache.druid.java.util.common.io.smoosh.SmooshedWriter;
 import org.apache.druid.java.util.common.logger.Logger;
+import org.apache.druid.segment.column.BitmapIndexType;
 import org.apache.druid.segment.data.CompressedVSizeColumnarIntsSerializer;
 import org.apache.druid.segment.data.CompressionStrategy;
 import org.apache.druid.segment.data.FixedIndexedIntWriter;
 import org.apache.druid.segment.data.GenericIndexedWriter;
 import org.apache.druid.segment.data.SingleValueColumnarIntsSerializer;
 import org.apache.druid.segment.data.VSizeColumnarIntsSerializer;
+import org.apache.druid.segment.file.SegmentFileBuilder;
+import org.apache.druid.segment.file.SegmentFileChannel;
 import org.apache.druid.segment.serde.ColumnSerializerUtils;
 import org.apache.druid.segment.serde.DictionaryEncodedColumnPartSerde;
 import org.apache.druid.segment.serde.Serializer;
@@ -58,8 +59,8 @@ import java.nio.channels.WritableByteChannel;
  * the global dictionary ({@link #globalDictionaryIdLookup}) and writes this unsorted localId to an intermediate
  * integer column, {@link #intermediateValueWriter}.
  * <p>
- * When processing the 'raw' value column is complete, the {@link #writeTo(int, FileSmoosher)} method will sort the
- * local ids and write them out to a local sorted dictionary, iterate over {@link #intermediateValueWriter} swapping
+ * When processing the 'raw' value column is complete, the {@link #writeTo(int, SegmentFileBuilder)} method will sort
+ * the local ids and write them out to a local sorted dictionary, iterate over {@link #intermediateValueWriter} swapping
  * the unsorted local ids with the sorted ids and writing to the compressed id column writer
  * {@link #encodedValueSerializer}, building the bitmap indexes along the way.
  *
@@ -80,6 +81,7 @@ public abstract class GlobalDictionaryEncodedFieldColumnWriter<T>
   protected final DictionaryIdLookup globalDictionaryIdLookup;
   protected final LocalDimensionDictionary localDictionary = new LocalDimensionDictionary();
 
+  public BitmapIndexType bitmapIndexType = BitmapIndexType.DictionaryEncodedValueIndex.INSTANCE;
   protected final Int2ObjectRBTreeMap<MutableBitmap> arrayElements = new Int2ObjectRBTreeMap<>();
 
   protected final Closer fieldResourceCloser = Closer.create();
@@ -117,8 +119,8 @@ public abstract class GlobalDictionaryEncodedFieldColumnWriter<T>
   }
 
   /**
-   * Hook to allow implementors the chance to do additional operations during {@link #writeTo(int, FileSmoosher)}, such
-   * as writing an additional value column
+   * Hook to allow implementors the chance to do additional operations during {@link #writeTo(int, SegmentFileBuilder)},
+   * such as writing an additional value column
    */
   void writeValue(@Nullable T value) throws IOException
   {
@@ -176,7 +178,7 @@ public abstract class GlobalDictionaryEncodedFieldColumnWriter<T>
 
 
   /**
-   * How many bytes {@link #writeColumnTo(WritableByteChannel, FileSmoosher)} is expected to write to the segment.
+   * How many bytes {@link #writeColumnTo(WritableByteChannel, SegmentFileBuilder)} is expected to write to the segment.
    */
   long getSerializedColumnSize() throws IOException
   {
@@ -187,9 +189,13 @@ public abstract class GlobalDictionaryEncodedFieldColumnWriter<T>
    * Defines how to write the column, including the dictionary id column, along with any additional columns
    * such as the long or double value column as type appropriate.
    */
-  abstract void writeColumnTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException;
+  void writeColumnTo(WritableByteChannel channel, SegmentFileBuilder fileBuilder) throws IOException
+  {
+    writeLongAndDoubleColumnLength(channel, 0, 0);
+    encodedValueSerializer.writeTo(channel, fileBuilder);
+  }
 
-  public void writeTo(int finalRowCount, FileSmoosher smoosher) throws IOException
+  public void writeTo(int finalRowCount, SegmentFileBuilder fileBuilder) throws IOException
   {
     if (finalRowCount > cursorPosition) {
       fillNull(finalRowCount);
@@ -201,13 +207,8 @@ public abstract class GlobalDictionaryEncodedFieldColumnWriter<T>
     sortedDictionaryWriter.open();
     final FixedIndexedIntWriter arrayElementDictionaryWriter = new FixedIndexedIntWriter(tmpWriteoutMedium, true);
     arrayElementDictionaryWriter.open();
-    GenericIndexedWriter<ImmutableBitmap> bitmapIndexWriter = new GenericIndexedWriter<>(
-        tmpWriteoutMedium,
-        columnName,
-        columnFormatSpec.getBitmapEncoding().getObjectStrategy()
-    );
-    bitmapIndexWriter.open();
-    bitmapIndexWriter.setObjectsNotSorted();
+    BitmapIndexType.Writer bitmapIndexWriter = bitmapIndexType.getWriter();
+    bitmapIndexWriter.openWriter(tmpWriteoutMedium, columnName, columnFormatSpec.getBitmapEncoding().getObjectStrategy());
     GenericIndexedWriter<ImmutableBitmap> arrayElementIndexWriter = new GenericIndexedWriter<>(
         tmpWriteoutMedium,
         columnName,
@@ -226,13 +227,11 @@ public abstract class GlobalDictionaryEncodedFieldColumnWriter<T>
     IntArrays.unstableSort(sortedGlobal);
 
     final int[] unsortedToSorted = new int[unsortedToGlobal.length];
-    final MutableBitmap[] bitmaps = new MutableBitmap[sortedGlobal.length];
     for (int index = 0; index < sortedGlobal.length; index++) {
       final int globalId = sortedGlobal[index];
       sortedDictionaryWriter.write(globalId);
       final int unsortedId = globalToUnsorted.get(globalId);
       unsortedToSorted[unsortedId] = index;
-      bitmaps[index] = columnFormatSpec.getBitmapEncoding().getBitmapFactory().makeEmptyMutableBitmap();
     }
 
     for (Int2ObjectMap.Entry<MutableBitmap> arrayElement : arrayElements.int2ObjectEntrySet()) {
@@ -243,23 +242,19 @@ public abstract class GlobalDictionaryEncodedFieldColumnWriter<T>
     }
 
     openColumnSerializer(tmpWriteoutMedium, sortedGlobal[sortedGlobal.length - 1]);
+    bitmapIndexWriter.init(columnFormatSpec.getBitmapEncoding().getBitmapFactory(), sortedGlobal.length);
     final IntIterator rows = intermediateValueWriter.getIterator();
     int rowCount = 0;
     while (rows.hasNext()) {
       final int unsortedLocalId = rows.nextInt();
       final int sortedLocalId = unsortedToSorted[unsortedLocalId];
       encodedValueSerializer.addValue(sortedLocalId);
-      writeValue((T) globalDictionaryIdLookup.getDictionaryValue(unsortedToGlobal[unsortedLocalId]));
-      bitmaps[sortedLocalId].add(rowCount++);
-    }
-
-    for (int i = 0; i < bitmaps.length; i++) {
-      final MutableBitmap bitmap = bitmaps[i];
-      bitmapIndexWriter.write(
-          columnFormatSpec.getBitmapEncoding().getBitmapFactory().makeImmutableBitmap(bitmap)
-      );
-      bitmaps[i] = null; // Reclaim memory
+      T value = (T) globalDictionaryIdLookup.getDictionaryValue(unsortedToGlobal[unsortedLocalId]);
+      writeValue(value);
+      bitmapIndexWriter.add(rowCount, sortedLocalId, value);
+      rowCount++;
     }
+    bitmapIndexWriter.finalizeWriter(columnFormatSpec.getBitmapEncoding().getBitmapFactory());
 
     final Serializer fieldSerializer = new Serializer()
     {
@@ -272,32 +267,32 @@ public abstract class GlobalDictionaryEncodedFieldColumnWriter<T>
         } else {
           arraySize = 0;
         }
-        return 1 + Integer.BYTES +
+        return 1 + Integer.BYTES + // version + feature flags
                sortedDictionaryWriter.getSerializedSize() +
+               getSerializedColumnSize() +
                bitmapIndexWriter.getSerializedSize() +
-               arraySize +
-               getSerializedColumnSize();
+               arraySize;
       }
 
       @Override
-      public void writeTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException
+      public void writeTo(WritableByteChannel channel, SegmentFileBuilder fileBuilder) throws IOException
       {
         Channels.writeFully(channel, ByteBuffer.wrap(new byte[]{version.asByte()}));
-        channel.write(ByteBuffer.wrap(Ints.toByteArray(flags)));
-        sortedDictionaryWriter.writeTo(channel, smoosher);
-        writeColumnTo(channel, smoosher);
-        bitmapIndexWriter.writeTo(channel, smoosher);
+        Channels.writeFully(channel, ByteBuffer.wrap(Ints.toByteArray(flags)));
+        sortedDictionaryWriter.writeTo(channel, fileBuilder);
+        writeColumnTo(channel, fileBuilder);
+        bitmapIndexWriter.writeTo(channel, fileBuilder);
         if (arrayElements.size() > 0) {
-          arrayElementDictionaryWriter.writeTo(channel, smoosher);
-          arrayElementIndexWriter.writeTo(channel, smoosher);
+          arrayElementDictionaryWriter.writeTo(channel, fileBuilder);
+          arrayElementIndexWriter.writeTo(channel, fileBuilder);
         }
       }
     };
     final String fieldFileName = ColumnSerializerUtils.getInternalFileName(columnName, fieldName);
     final long size = fieldSerializer.getSerializedSize();
     log.debug("Column [%s] serializing [%s] field of size [%d].", columnName, fieldName, size);
-    try (SmooshedWriter smooshChannel = smoosher.addWithSmooshedWriter(fieldFileName, size)) {
-      fieldSerializer.writeTo(smooshChannel, smoosher);
+    try (SegmentFileChannel channel = fileBuilder.addWithChannel(fieldFileName, size)) {
+      fieldSerializer.writeTo(channel, fileBuilder);
     }
     finally {
       tmpWriteoutMedium.close();
