@@ -24,6 +24,7 @@ import com.fasterxml.jackson.annotation.JsonIgnore;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import org.apache.druid.java.util.common.ISE;
 import org.apache.druid.segment.IndexSpec;
+import org.apache.druid.segment.column.BitmapIndexType;
 import org.apache.druid.segment.column.StringEncodingStrategy;
 import org.apache.druid.segment.data.BitmapSerdeFactory;
 import org.apache.druid.segment.data.CompressionFactory;
@@ -34,8 +35,7 @@ import java.util.Objects;
 
 /**
  * Defines storage format for 'auto' and json columns. This can be convered into the 'effective' format spec by calling
- * {@link #getEffectiveSpec(IndexSpec)}, which will fill in any values which were not specified from
- * {@link IndexSpec#getAutoColumnFormatSpec()}, falling back to hard-coded defaults, useful when generating segments or
+ * {@link #getEffectiveFormatSpec(NestedCommonFormatColumnFormatSpec, IndexSpec)}, useful when generating segments or
  * comparing compaction state.
  */
 public class NestedCommonFormatColumnFormatSpec
@@ -43,6 +43,8 @@ public class NestedCommonFormatColumnFormatSpec
   private static final NestedCommonFormatColumnFormatSpec DEFAULT =
       builder().setObjectFieldsDictionaryEncoding(StringEncodingStrategy.UTF8_STRATEGY)
                .setObjectStorageEncoding(ObjectStorageEncoding.SMILE)
+               .setLongFieldBitmapIndexType(BitmapIndexType.DictionaryEncodedValueIndex.INSTANCE)
+               .setDoubleFieldBitmapIndexType(BitmapIndexType.DictionaryEncodedValueIndex.INSTANCE)
                .build();
 
   public static Builder builder()
@@ -56,10 +58,13 @@ public class NestedCommonFormatColumnFormatSpec
   }
 
   /**
-   * Create a {@link NestedCommonFormatColumnFormatSpec} with all fields fully populated. Values from the supplied
-   * column format spec take priority, any null values are then populated by checking
-   * {@link IndexSpec#getAutoColumnFormatSpec()}, then falling back to fields on {@link IndexSpec} itself if applicable,
-   * and finally resorting to hard coded defaults.
+   * Create a {@link NestedCommonFormatColumnFormatSpec} with all fields fully populated. Values are populated in the following order:
+   * <ul>
+   *   <li> value in the given column format spec, if non-null </li>
+   *   <li> value in {@link IndexSpec#getAutoColumnFormatSpec()}, if non-null </li>
+   *   <li> fall back to equivalent fields on {@link IndexSpec} itself if applicable </li>
+   *   <li> hard coded defaults in {@link #DEFAULT}</li>
+   * </ul>
    */
   public static NestedCommonFormatColumnFormatSpec getEffectiveFormatSpec(
       @Nullable NestedCommonFormatColumnFormatSpec columnFormatSpec,
@@ -85,6 +90,22 @@ public class NestedCommonFormatColumnFormatSpec
       defaultSpec = DEFAULT;
     }
 
+    if (builder.longFieldBitmapIndexType == null) {
+      if (defaultSpec.getLongFieldBitmapIndexType() != null) {
+        builder.setLongFieldBitmapIndexType(defaultSpec.getLongFieldBitmapIndexType());
+      } else {
+        builder.setLongFieldBitmapIndexType(DEFAULT.getLongFieldBitmapIndexType());
+      }
+    }
+
+    if (builder.doubleFieldBitmapIndexType == null) {
+      if (defaultSpec.getDoubleFieldBitmapIndexType() != null) {
+        builder.setDoubleFieldBitmapIndexType(defaultSpec.getDoubleFieldBitmapIndexType());
+      } else {
+        builder.setDoubleFieldBitmapIndexType(DEFAULT.getDoubleFieldBitmapIndexType());
+      }
+    }
+
     if (builder.objectFieldsDictionaryEncoding == null) {
       if (defaultSpec.getObjectFieldsDictionaryEncoding() != null) {
         builder.setObjectFieldsDictionaryEncoding(defaultSpec.getObjectFieldsDictionaryEncoding());
@@ -172,14 +193,21 @@ public class NestedCommonFormatColumnFormatSpec
   private final CompressionStrategy doubleColumnCompression;
   @Nullable
   private final BitmapSerdeFactory bitmapEncoding;
+  @Nullable
+  private final BitmapIndexType longFieldBitmapIndexType;
+  @Nullable
+  private final BitmapIndexType doubleFieldBitmapIndexType;
 
   @JsonCreator
   public NestedCommonFormatColumnFormatSpec(
       @JsonProperty("objectFieldsDictionaryEncoding") @Nullable StringEncodingStrategy objectFieldsDictionaryEncoding,
+      @JsonProperty("longFieldBitmapIndexType") @Nullable BitmapIndexType longFieldBitmapIndexType,
+      @JsonProperty("doubleFieldBitmapIndexType") @Nullable BitmapIndexType doubleFieldBitmapIndexType,
       @JsonProperty("objectStorageEncoding") @Nullable ObjectStorageEncoding objectStorageEncoding,
       @JsonProperty("objectStorageCompression") @Nullable CompressionStrategy objectStorageCompression,
       @JsonProperty("stringDictionaryEncoding") @Nullable StringEncodingStrategy stringDictionaryEncoding,
-      @JsonProperty("dictionaryEncodedColumnCompression") @Nullable CompressionStrategy dictionaryEncodedColumnCompression,
+      @JsonProperty("dictionaryEncodedColumnCompression") @Nullable
+      CompressionStrategy dictionaryEncodedColumnCompression,
       @JsonProperty("longColumnEncoding") @Nullable CompressionFactory.LongEncodingStrategy longColumnEncoding,
       @JsonProperty("longColumnCompression") @Nullable CompressionStrategy longColumnCompression,
       @JsonProperty("doubleColumnCompression") @Nullable CompressionStrategy doubleColumnCompression
@@ -194,7 +222,9 @@ public class NestedCommonFormatColumnFormatSpec
         longColumnEncoding,
         longColumnCompression,
         doubleColumnCompression,
-        null
+        null,
+        longFieldBitmapIndexType,
+        doubleFieldBitmapIndexType
     );
   }
 
@@ -212,7 +242,9 @@ public class NestedCommonFormatColumnFormatSpec
       @Nullable CompressionFactory.LongEncodingStrategy longColumnEncoding,
       @Nullable CompressionStrategy longColumnCompression,
       @Nullable CompressionStrategy doubleColumnCompression,
-      @Nullable BitmapSerdeFactory bitmapEncoding
+      @Nullable BitmapSerdeFactory bitmapEncoding,
+      @Nullable BitmapIndexType longFieldBitmapIndexType,
+      @Nullable BitmapIndexType doubleFieldBitmapIndexType
   )
   {
     this.objectFieldsDictionaryEncoding = objectFieldsDictionaryEncoding;
@@ -224,6 +256,8 @@ public class NestedCommonFormatColumnFormatSpec
     this.longColumnCompression = longColumnCompression;
     this.doubleColumnCompression = doubleColumnCompression;
     this.bitmapEncoding = bitmapEncoding;
+    this.longFieldBitmapIndexType = longFieldBitmapIndexType;
+    this.doubleFieldBitmapIndexType = doubleFieldBitmapIndexType;
   }
 
   @Nullable
@@ -289,6 +323,20 @@ public class NestedCommonFormatColumnFormatSpec
     return bitmapEncoding;
   }
 
+  @Nullable
+  @JsonProperty
+  public BitmapIndexType getLongFieldBitmapIndexType()
+  {
+    return longFieldBitmapIndexType;
+  }
+
+  @Nullable
+  @JsonProperty
+  public BitmapIndexType getDoubleFieldBitmapIndexType()
+  {
+    return doubleFieldBitmapIndexType;
+  }
+
   @Override
   public boolean equals(Object o)
   {
@@ -304,7 +352,9 @@ public class NestedCommonFormatColumnFormatSpec
            && longColumnEncoding == that.longColumnEncoding
            && longColumnCompression == that.longColumnCompression
            && doubleColumnCompression == that.doubleColumnCompression
-           && Objects.equals(bitmapEncoding, that.bitmapEncoding);
+           && Objects.equals(bitmapEncoding, that.bitmapEncoding)
+           && Objects.equals(longFieldBitmapIndexType, that.longFieldBitmapIndexType)
+           && Objects.equals(doubleFieldBitmapIndexType, that.doubleFieldBitmapIndexType);
   }
 
   @Override
@@ -319,7 +369,9 @@ public class NestedCommonFormatColumnFormatSpec
         longColumnEncoding,
         longColumnCompression,
         doubleColumnCompression,
-        bitmapEncoding
+        bitmapEncoding,
+        longFieldBitmapIndexType,
+        doubleFieldBitmapIndexType
     );
   }
 
@@ -336,6 +388,8 @@ public class NestedCommonFormatColumnFormatSpec
            ", longColumnCompression=" + longColumnCompression +
            ", doubleColumnCompression=" + doubleColumnCompression +
            ", bitmapEncoding=" + bitmapEncoding +
+           ", longFieldBitmapIndexType=" + longFieldBitmapIndexType +
+           ", doubleFieldBitmapIndexType=" + doubleFieldBitmapIndexType +
            '}';
   }
 
@@ -358,6 +412,10 @@ public class NestedCommonFormatColumnFormatSpec
     @Nullable
     private CompressionStrategy doubleColumnCompression;
     @Nullable
+    private BitmapIndexType longFieldBitmapIndexType;
+    @Nullable
+    private BitmapIndexType doubleFieldBitmapIndexType;
+    @Nullable
     private BitmapSerdeFactory bitmapEncoding;
 
     public Builder()
@@ -376,6 +434,8 @@ public class NestedCommonFormatColumnFormatSpec
       this.longColumnCompression = spec.longColumnCompression;
       this.doubleColumnCompression = spec.doubleColumnCompression;
       this.bitmapEncoding = spec.bitmapEncoding;
+      this.longFieldBitmapIndexType = spec.longFieldBitmapIndexType;
+      this.doubleFieldBitmapIndexType = spec.doubleFieldBitmapIndexType;
     }
 
     public Builder setObjectFieldsDictionaryEncoding(@Nullable StringEncodingStrategy objectFieldsDictionaryEncoding)
@@ -428,6 +488,18 @@ public class NestedCommonFormatColumnFormatSpec
       return this;
     }
 
+    public Builder setLongFieldBitmapIndexType(@Nullable BitmapIndexType longFieldBitmapIndexType)
+    {
+      this.longFieldBitmapIndexType = longFieldBitmapIndexType;
+      return this;
+    }
+
+    public Builder setDoubleFieldBitmapIndexType(@Nullable BitmapIndexType doubleFieldBitmapIndexType)
+    {
+      this.doubleFieldBitmapIndexType = doubleFieldBitmapIndexType;
+      return this;
+    }
+
     public Builder setBitmapEncoding(@Nullable BitmapSerdeFactory bitmapEncoding)
     {
       this.bitmapEncoding = bitmapEncoding;
@@ -445,7 +517,9 @@ public class NestedCommonFormatColumnFormatSpec
           longColumnEncoding,
           longColumnCompression,
           doubleColumnCompression,
-          bitmapEncoding
+          bitmapEncoding,
+          longFieldBitmapIndexType,
+          doubleFieldBitmapIndexType
       );
     }
   }
