@@ -25,7 +25,6 @@ import org.apache.druid.collections.bitmap.ImmutableBitmap;
 import org.apache.druid.collections.bitmap.MutableBitmap;
 import org.apache.druid.error.DruidException;
 import org.apache.druid.java.util.common.io.Closer;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
 import org.apache.druid.java.util.common.io.smoosh.SmooshedWriter;
 import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.math.expr.ExprEval;
@@ -39,6 +38,7 @@ import org.apache.druid.segment.data.CompressedVariableSizedBlobColumnSerializer
 import org.apache.druid.segment.data.DictionaryWriter;
 import org.apache.druid.segment.data.FixedIndexedWriter;
 import org.apache.druid.segment.data.FrontCodedIntArrayIndexedWriter;
+import org.apache.druid.segment.file.SegmentFileBuilder;
 import org.apache.druid.segment.serde.ColumnSerializerUtils;
 import org.apache.druid.segment.writeout.SegmentWriteOutMedium;
 
@@ -142,7 +142,7 @@ public class NestedDataColumnSerializer extends NestedCommonFormatColumnSerializ
   private FixedIndexedWriter<Long> longDictionaryWriter;
   private FixedIndexedWriter<Double> doubleDictionaryWriter;
   private FrontCodedIntArrayIndexedWriter arrayDictionaryWriter;
-  private CompressedVariableSizedBlobColumnSerializer rawWriter;
+  @Nullable private CompressedVariableSizedBlobColumnSerializer rawWriter;
   private ByteBufferWriter<ImmutableBitmap> nullBitmapWriter;
   private MutableBitmap nullRowsBitmap;
   private Map<String, GlobalDictionaryEncodedFieldColumnWriter<?>> fieldWriters;
@@ -243,12 +243,19 @@ public class NestedDataColumnSerializer extends NestedCommonFormatColumnSerializ
   @Override
   public void open() throws IOException
   {
-    rawWriter = new CompressedVariableSizedBlobColumnSerializer(
-        ColumnSerializerUtils.getInternalFileName(name, RAW_FILE_NAME),
-        segmentWriteOutMedium,
-        columnFormatSpec.getObjectStorageCompression()
-    );
-    rawWriter.open();
+    if (ObjectStorageEncoding.NONE.equals(columnFormatSpec.getObjectStorageEncoding())) {
+      rawWriter = null;
+    } else if (ObjectStorageEncoding.SMILE.equals(columnFormatSpec.getObjectStorageEncoding())) {
+      rawWriter = new CompressedVariableSizedBlobColumnSerializer(
+          ColumnSerializerUtils.getInternalFileName(name, RAW_FILE_NAME),
+          segmentWriteOutMedium,
+          columnFormatSpec.getObjectStorageCompression()
+      );
+      rawWriter.open();
+    } else {
+      throw DruidException.defensive("Unknown object storage encoding [%s]", columnFormatSpec.getObjectStorageEncoding()
+      );
+    }
 
     nullBitmapWriter = new ByteBufferWriter<>(
         segmentWriteOutMedium,
@@ -339,7 +346,9 @@ public class NestedDataColumnSerializer extends NestedCommonFormatColumnSerializ
     if (data == null) {
       nullRowsBitmap.add(rowCount);
     }
-    rawWriter.addValue(NestedDataComplexTypeSerde.INSTANCE.toBytes(data));
+    if (rawWriter != null) {
+      rawWriter.addValue(NestedDataComplexTypeSerde.INSTANCE.toBytes(data));
+    }
     if (data != null) {
       fieldProcessor.processFields(data.getValue());
     }
@@ -376,7 +385,7 @@ public class NestedDataColumnSerializer extends NestedCommonFormatColumnSerializ
   @Override
   public void writeTo(
       WritableByteChannel channel,
-      FileSmoosher smoosher
+      SegmentFileBuilder fileBuilder
   ) throws IOException
   {
     Preconditions.checkState(closedForWrite, "Not closed yet!");
@@ -387,32 +396,34 @@ public class NestedDataColumnSerializer extends NestedCommonFormatColumnSerializ
 
 
     if (writeDictionary) {
-      fieldsWriter.writeTo(channel, smoosher);
-      fieldsInfoWriter.writeTo(channel, smoosher);
+      fieldsWriter.writeTo(channel, fileBuilder);
+      fieldsInfoWriter.writeTo(channel, fileBuilder);
       if (globalDictionaryIdLookup.getStringBufferMapper() != null) {
-        copyFromTempSmoosh(smoosher, globalDictionaryIdLookup.getStringBufferMapper());
+        copyFromTempSmoosh(fileBuilder, globalDictionaryIdLookup.getStringBufferMapper());
       } else {
-        writeInternal(smoosher, dictionaryWriter, ColumnSerializerUtils.STRING_DICTIONARY_FILE_NAME);
+        writeInternal(fileBuilder, dictionaryWriter, ColumnSerializerUtils.STRING_DICTIONARY_FILE_NAME);
       }
       if (globalDictionaryIdLookup.getLongBufferMapper() != null) {
-        copyFromTempSmoosh(smoosher, globalDictionaryIdLookup.getLongBufferMapper());
+        copyFromTempSmoosh(fileBuilder, globalDictionaryIdLookup.getLongBufferMapper());
       } else {
-        writeInternal(smoosher, longDictionaryWriter, ColumnSerializerUtils.LONG_DICTIONARY_FILE_NAME);
+        writeInternal(fileBuilder, longDictionaryWriter, ColumnSerializerUtils.LONG_DICTIONARY_FILE_NAME);
       }
       if (globalDictionaryIdLookup.getDoubleBufferMapper() != null) {
-        copyFromTempSmoosh(smoosher, globalDictionaryIdLookup.getDoubleBufferMapper());
+        copyFromTempSmoosh(fileBuilder, globalDictionaryIdLookup.getDoubleBufferMapper());
       } else {
-        writeInternal(smoosher, doubleDictionaryWriter, ColumnSerializerUtils.DOUBLE_DICTIONARY_FILE_NAME);
+        writeInternal(fileBuilder, doubleDictionaryWriter, ColumnSerializerUtils.DOUBLE_DICTIONARY_FILE_NAME);
       }
       if (globalDictionaryIdLookup.getArrayBufferMapper() != null) {
-        copyFromTempSmoosh(smoosher, globalDictionaryIdLookup.getArrayBufferMapper());
+        copyFromTempSmoosh(fileBuilder, globalDictionaryIdLookup.getArrayBufferMapper());
       } else {
-        writeInternal(smoosher, arrayDictionaryWriter, ColumnSerializerUtils.ARRAY_DICTIONARY_FILE_NAME);
+        writeInternal(fileBuilder, arrayDictionaryWriter, ColumnSerializerUtils.ARRAY_DICTIONARY_FILE_NAME);
       }
     }
-    writeInternal(smoosher, rawWriter, RAW_FILE_NAME);
+    if (rawWriter != null) {
+      writeInternal(fileBuilder, rawWriter, RAW_FILE_NAME);
+    }
     if (!nullRowsBitmap.isEmpty()) {
-      writeInternal(smoosher, nullBitmapWriter, ColumnSerializerUtils.NULL_BITMAP_FILE_NAME);
+      writeInternal(fileBuilder, nullBitmapWriter, ColumnSerializerUtils.NULL_BITMAP_FILE_NAME);
     }
 
 
@@ -428,7 +439,7 @@ public class NestedDataColumnSerializer extends NestedCommonFormatColumnSerializ
     for (Map.Entry<String, FieldTypeInfo.MutableTypeSet> field : fields.entrySet()) {
       // remove writer so that it can be collected when we are done with it
       GlobalDictionaryEncodedFieldColumnWriter<?> writer = fieldWriters.remove(field.getKey());
-      writer.writeTo(rowCount, smoosher);
+      writer.writeTo(rowCount, fileBuilder);
     }
     log.info("Column [%s] serialized successfully with [%d] nested columns.", name, fields.size());
   }
