@@ -24,7 +24,6 @@ import com.google.common.base.Supplier;
 import org.apache.druid.collections.bitmap.ImmutableBitmap;
 import org.apache.druid.java.util.common.RE;
 import org.apache.druid.java.util.common.StringUtils;
-import org.apache.druid.java.util.common.io.smoosh.SmooshedFileMapper;
 import org.apache.druid.segment.IndexMerger;
 import org.apache.druid.segment.column.ColumnBuilder;
 import org.apache.druid.segment.column.ColumnConfig;
@@ -32,12 +31,12 @@ import org.apache.druid.segment.column.ColumnType;
 import org.apache.druid.segment.column.ComplexColumn;
 import org.apache.druid.segment.column.StringEncodingStrategies;
 import org.apache.druid.segment.column.TypeStrategy;
-import org.apache.druid.segment.data.BitmapSerdeFactory;
 import org.apache.druid.segment.data.CompressedVariableSizedBlobColumnSupplier;
 import org.apache.druid.segment.data.FixedIndexed;
 import org.apache.druid.segment.data.FrontCodedIntArrayIndexed;
 import org.apache.druid.segment.data.GenericIndexed;
 import org.apache.druid.segment.data.Indexed;
+import org.apache.druid.segment.file.SegmentFileMapper;
 import org.apache.druid.segment.serde.ColumnSerializerUtils;
 import org.apache.druid.segment.serde.ComplexColumnMetadata;
 
@@ -79,7 +78,7 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
     // v5 was never actually released, but it existed for a short time in the master branch, and doesn't hurt to be here
     if (version == 0x03 || version == 0x04 || version == 0x05) {
       try {
-        final SmooshedFileMapper mapper = columnBuilder.getFileMapper();
+        final SegmentFileMapper mapper = columnBuilder.getFileMapper();
         final ComplexColumnMetadata metadata;
         final GenericIndexed<ByteBuffer> fields;
         final FieldTypeInfo fieldInfo;
@@ -105,7 +104,8 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
           simpleType = ColumnType.STRING;
         } else if (fields.size() == 1 &&
                    ((version == 0x03 && NestedPathFinder.JQ_PATH_ROOT.equals(StringUtils.fromUtf8(fields.get(0)))) ||
-                    ((version == 0x04 || version == 0x05) && NestedPathFinder.JSON_PATH_ROOT.equals(StringUtils.fromUtf8(fields.get(0)))))
+                    ((version == 0x04 || version == 0x05)
+                     && NestedPathFinder.JSON_PATH_ROOT.equals(StringUtils.fromUtf8(fields.get(0)))))
         ) {
           simpleType = fieldInfo.getTypes(0).getSingleType();
         } else {
@@ -158,7 +158,11 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
         } else {
           arrayDictionarySupplier = null;
         }
-        final ByteBuffer rawBuffer = loadInternalFile(mapper, metadata, NestedCommonFormatColumnSerializer.RAW_FILE_NAME);
+        final ByteBuffer rawBuffer = loadInternalFile(
+            mapper,
+            metadata,
+            NestedCommonFormatColumnSerializer.RAW_FILE_NAME
+        );
         compressedRawColumnSupplier = CompressedVariableSizedBlobColumnSupplier.fromByteBuffer(
             ColumnSerializerUtils.getInternalFileName(
                 metadata.getFileNameBase(), NestedCommonFormatColumnSerializer.RAW_FILE_NAME
@@ -193,7 +197,7 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
             doubleDictionarySupplier,
             arrayDictionarySupplier,
             mapper,
-            metadata.getBitmapSerdeFactory(),
+            NestedCommonFormatColumnFormatSpec.builder().setBitmapEncoding(metadata.getBitmapSerdeFactory()).build(),
             metadata.getByteOrder(),
             simpleType
         );
@@ -217,12 +221,12 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
   private final Supplier<FixedIndexed<Long>> longDictionarySupplier;
   private final Supplier<FixedIndexed<Double>> doubleDictionarySupplier;
   private final Supplier<FrontCodedIntArrayIndexed> arrayDictionarySupplier;
-  private final SmooshedFileMapper fileMapper;
+  private final SegmentFileMapper fileMapper;
 
   @Nullable
   private final ColumnType simpleType;
   private final ColumnType logicalType;
-  private final BitmapSerdeFactory bitmapSerdeFactory;
+  private final NestedCommonFormatColumnFormatSpec formatSpec;
   private final ByteOrder byteOrder;
 
   private NestedDataColumnSupplierV4(
@@ -237,8 +241,8 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
       Supplier<FixedIndexed<Long>> longDictionarySupplier,
       Supplier<FixedIndexed<Double>> doubleDictionarySupplier,
       Supplier<FrontCodedIntArrayIndexed> arrayDictionarySupplier,
-      SmooshedFileMapper fileMapper,
-      BitmapSerdeFactory bitmapSerdeFactory,
+      SegmentFileMapper fileMapper,
+      NestedCommonFormatColumnFormatSpec formatSpec,
       ByteOrder byteOrder,
       @Nullable ColumnType simpleType
   )
@@ -255,7 +259,7 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
     this.doubleDictionarySupplier = doubleDictionarySupplier;
     this.arrayDictionarySupplier = arrayDictionarySupplier;
     this.fileMapper = fileMapper;
-    this.bitmapSerdeFactory = bitmapSerdeFactory;
+    this.formatSpec = formatSpec;
     this.byteOrder = byteOrder;
     this.simpleType = simpleType;
     this.logicalType = simpleType == null ? ColumnType.NESTED_DATA : simpleType;
@@ -293,7 +297,7 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
         longDictionarySupplier,
         doubleDictionarySupplier,
         fileMapper,
-        bitmapSerdeFactory,
+        formatSpec,
         byteOrder
     );
   }
@@ -312,7 +316,7 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
         longDictionarySupplier,
         doubleDictionarySupplier,
         fileMapper,
-        bitmapSerdeFactory,
+        formatSpec,
         byteOrder
     );
   }
@@ -332,13 +336,13 @@ public class NestedDataColumnSupplierV4 implements Supplier<ComplexColumn>
         doubleDictionarySupplier,
         arrayDictionarySupplier,
         fileMapper,
-        bitmapSerdeFactory,
+        formatSpec,
         byteOrder
     );
   }
 
   private static ByteBuffer loadInternalFile(
-      SmooshedFileMapper fileMapper,
+      SegmentFileMapper fileMapper,
       ComplexColumnMetadata metadata,
       String internalFileName
   ) throws IOException
