@@ -21,9 +21,9 @@ package org.apache.druid.segment.nested;
 
 import com.google.common.primitives.Ints;
 import org.apache.druid.java.util.common.StringUtils;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
 import org.apache.druid.segment.data.ColumnarDoublesSerializer;
 import org.apache.druid.segment.data.CompressionFactory;
+import org.apache.druid.segment.file.SegmentFileBuilder;
 import org.apache.druid.segment.writeout.SegmentWriteOutMedium;
 
 import javax.annotation.Nullable;
@@ -49,6 +49,7 @@ public final class ScalarDoubleFieldColumnWriter extends GlobalDictionaryEncoded
   )
   {
     super(columnName, fieldName, segmentWriteOutMedium, columnFormatSpec, globalDictionaryIdLookup);
+    bitmapIndexType = columnFormatSpec.getDoubleFieldBitmapIndexType();
   }
 
   @Override
@@ -83,16 +84,18 @@ public final class ScalarDoubleFieldColumnWriter extends GlobalDictionaryEncoded
   }
 
   @Override
-  void writeColumnTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException
+  void writeColumnTo(WritableByteChannel channel, SegmentFileBuilder fileBuilder) throws IOException
   {
     writeLongAndDoubleColumnLength(channel, 0, Ints.checkedCast(doublesSerializer.getSerializedSize()));
-    doublesSerializer.writeTo(channel, smoosher);
-    encodedValueSerializer.writeTo(channel, smoosher);
+    doublesSerializer.writeTo(channel, fileBuilder);
+    encodedValueSerializer.writeTo(channel, fileBuilder);
   }
 
   @Override
   long getSerializedColumnSize() throws IOException
   {
-    return super.getSerializedColumnSize() + doublesSerializer.getSerializedSize();
+    return Integer.BYTES + Integer.BYTES
+           + doublesSerializer.getSerializedSize()
+           + encodedValueSerializer.getSerializedSize();
   }
 }
