@@ -28,7 +28,6 @@ import org.apache.druid.java.util.common.IAE;
 import org.apache.druid.java.util.common.ISE;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.io.Closer;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
 import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.math.expr.ExprEval;
 import org.apache.druid.math.expr.ExpressionType;
@@ -43,6 +42,7 @@ import org.apache.druid.segment.data.FixedIndexedWriter;
 import org.apache.druid.segment.data.FrontCodedIntArrayIndexedWriter;
 import org.apache.druid.segment.data.GenericIndexedWriter;
 import org.apache.druid.segment.data.SingleValueColumnarIntsSerializer;
+import org.apache.druid.segment.file.SegmentFileBuilder;
 import org.apache.druid.segment.serde.ColumnSerializerUtils;
 import org.apache.druid.segment.serde.Serializer;
 import org.apache.druid.segment.writeout.SegmentWriteOutMedium;
@@ -411,15 +411,15 @@ public class VariantColumnSerializer extends NestedCommonFormatColumnSerializer
   }
 
   @Override
-  public void writeTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException
+  public void writeTo(WritableByteChannel channel, SegmentFileBuilder fileBuilder) throws IOException
   {
     closeForWrite();
-    internalSerializer.writeTo(channel, smoosher);
+    internalSerializer.writeTo(channel, fileBuilder);
   }
 
   /**
    * Internal serializer used to serialize a {@link VariantColumn}. Encapsulates just the logic to write out the column
-   * to a {@link FileSmoosher} without the parts to update the dictionaries themselves, so that it can be reused.
+   * to a {@link SegmentFileBuilder} without the parts to update the dictionaries themselves, so that it can be reused.
    * Created by {@link VariantColumnSerializer} once it is closed for writes.
    */
   public static class InternalSerializer implements Serializer
@@ -501,7 +501,7 @@ public class VariantColumnSerializer extends NestedCommonFormatColumnSerializer
     }
 
     @Override
-    public void writeTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException
+    public void writeTo(WritableByteChannel channel, SegmentFileBuilder fileBuilder) throws IOException
     {
       writeV0Header(channel, columnNameBytes);
       if (variantTypeSetByte != null) {
@@ -510,33 +510,33 @@ public class VariantColumnSerializer extends NestedCommonFormatColumnSerializer
 
       if (writeDictionary) {
         if (dictionaryIdLookup.getStringBufferMapper() != null) {
-          copyFromTempSmoosh(smoosher, dictionaryIdLookup.getStringBufferMapper());
+          copyFromTempSmoosh(fileBuilder, dictionaryIdLookup.getStringBufferMapper());
         } else {
-          ColumnSerializerUtils.writeInternal(smoosher, dictionaryWriter, columnName, ColumnSerializerUtils.STRING_DICTIONARY_FILE_NAME);
+          ColumnSerializerUtils.writeInternal(fileBuilder, dictionaryWriter, columnName, ColumnSerializerUtils.STRING_DICTIONARY_FILE_NAME);
         }
 
         if (dictionaryIdLookup.getLongBufferMapper() != null) {
-          copyFromTempSmoosh(smoosher, dictionaryIdLookup.getLongBufferMapper());
+          copyFromTempSmoosh(fileBuilder, dictionaryIdLookup.getLongBufferMapper());
         } else {
-          ColumnSerializerUtils.writeInternal(smoosher, longDictionaryWriter, columnName, ColumnSerializerUtils.LONG_DICTIONARY_FILE_NAME);
+          ColumnSerializerUtils.writeInternal(fileBuilder, longDictionaryWriter, columnName, ColumnSerializerUtils.LONG_DICTIONARY_FILE_NAME);
         }
 
         if (dictionaryIdLookup.getDoubleBufferMapper() != null) {
-          copyFromTempSmoosh(smoosher, dictionaryIdLookup.getDoubleBufferMapper());
+          copyFromTempSmoosh(fileBuilder, dictionaryIdLookup.getDoubleBufferMapper());
         } else {
-          ColumnSerializerUtils.writeInternal(smoosher, doubleDictionaryWriter, columnName, ColumnSerializerUtils.DOUBLE_DICTIONARY_FILE_NAME);
+          ColumnSerializerUtils.writeInternal(fileBuilder, doubleDictionaryWriter, columnName, ColumnSerializerUtils.DOUBLE_DICTIONARY_FILE_NAME);
         }
         if (dictionaryIdLookup.getArrayBufferMapper() != null) {
-          copyFromTempSmoosh(smoosher, dictionaryIdLookup.getArrayBufferMapper());
+          copyFromTempSmoosh(fileBuilder, dictionaryIdLookup.getArrayBufferMapper());
         } else {
-          ColumnSerializerUtils.writeInternal(smoosher, arrayDictionaryWriter, columnName, ColumnSerializerUtils.ARRAY_DICTIONARY_FILE_NAME);
+          ColumnSerializerUtils.writeInternal(fileBuilder, arrayDictionaryWriter, columnName, ColumnSerializerUtils.ARRAY_DICTIONARY_FILE_NAME);
         }
 
-        ColumnSerializerUtils.writeInternal(smoosher, arrayElementDictionaryWriter, columnName, ColumnSerializerUtils.ARRAY_ELEMENT_DICTIONARY_FILE_NAME);
+        ColumnSerializerUtils.writeInternal(fileBuilder, arrayElementDictionaryWriter, columnName, ColumnSerializerUtils.ARRAY_ELEMENT_DICTIONARY_FILE_NAME);
       }
-      ColumnSerializerUtils.writeInternal(smoosher, encodedValueSerializer, columnName, ColumnSerializerUtils.ENCODED_VALUE_COLUMN_FILE_NAME);
-      ColumnSerializerUtils.writeInternal(smoosher, bitmapIndexWriter, columnName, ColumnSerializerUtils.BITMAP_INDEX_FILE_NAME);
-      ColumnSerializerUtils.writeInternal(smoosher, arrayElementIndexWriter, columnName, ColumnSerializerUtils.ARRAY_ELEMENT_BITMAP_INDEX_FILE_NAME);
+      ColumnSerializerUtils.writeInternal(fileBuilder, encodedValueSerializer, columnName, ColumnSerializerUtils.ENCODED_VALUE_COLUMN_FILE_NAME);
+      ColumnSerializerUtils.writeInternal(fileBuilder, bitmapIndexWriter, columnName, ColumnSerializerUtils.BITMAP_INDEX_FILE_NAME);
+      ColumnSerializerUtils.writeInternal(fileBuilder, arrayElementIndexWriter, columnName, ColumnSerializerUtils.ARRAY_ELEMENT_BITMAP_INDEX_FILE_NAME);
 
       log.info("Column [%s] serialized successfully.", columnName);
     }
