@@ -20,12 +20,8 @@
 package org.apache.druid.segment.nested;
 
 import com.google.common.base.Preconditions;
-import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
 import org.apache.druid.segment.writeout.SegmentWriteOutMedium;
 
-import java.io.IOException;
-import java.nio.channels.WritableByteChannel;
-
 /**
  * Nested field writer for mixed type scalar or array columns of {@link NestedDataColumnSerializer}.
  */
@@ -86,11 +82,4 @@ public final class VariantFieldColumnWriter extends GlobalDictionaryEncodedField
       return globalDictionaryIdLookup.lookupString(String.valueOf(value));
     }
   }
-
-  @Override
-  void writeColumnTo(WritableByteChannel channel, FileSmoosher smoosher) throws IOException
-  {
-    writeLongAndDoubleColumnLength(channel, 0, 0);
-    encodedValueSerializer.writeTo(channel, smoosher);
-  }
 }
