@@ -23,6 +23,7 @@ import com.google.common.collect.ImmutableList;
 import com.google.common.collect.Iterables;
 import it.unimi.dsi.fastutil.ints.IntSet;
 import it.unimi.dsi.fastutil.ints.IntSets;
+import org.apache.druid.error.DruidException;
 import org.apache.druid.frame.allocation.HeapMemoryAllocator;
 import org.apache.druid.frame.channel.BlockingQueueFrameChannel;
 import org.hamcrest.CoreMatchers;
@@ -43,7 +44,6 @@ public class OutputChannelsTest
     Assert.assertEquals(IntSets.emptySet(), channels.getPartitionNumbers());
     Assert.assertEquals(Collections.emptyList(), channels.getAllChannels());
     Assert.assertEquals(Collections.emptyList(), channels.getChannelsForPartition(0));
-    Assert.assertTrue(channels.areReadableChannelsReady());
   }
 
   @Test
@@ -55,7 +55,6 @@ public class OutputChannelsTest
     Assert.assertEquals(1, channels.getAllChannels().size());
     Assert.assertEquals(Collections.emptyList(), channels.getChannelsForPartition(0));
     Assert.assertEquals(1, channels.getChannelsForPartition(1).size());
-    Assert.assertTrue(channels.areReadableChannelsReady());
   }
 
   @Test
@@ -77,28 +76,25 @@ public class OutputChannelsTest
     Assert.assertEquals(IntSet.of(1), readOnlyChannels.getPartitionNumbers());
     Assert.assertEquals(1, readOnlyChannels.getAllChannels().size());
     Assert.assertEquals(1, channels.getChannelsForPartition(1).size());
-    Assert.assertTrue(channels.areReadableChannelsReady());
 
-    final IllegalStateException e = Assert.assertThrows(
-        IllegalStateException.class,
+    final DruidException e = Assert.assertThrows(
+        DruidException.class,
         () -> Iterables.getOnlyElement(readOnlyChannels.getAllChannels()).getWritableChannel()
     );
 
     MatcherAssert.assertThat(
         e,
-        ThrowableMessageMatcher.hasMessage(CoreMatchers.equalTo(
-            "Writable channel is not available. The output channel might be marked as read-only, hence no writes are allowed."))
+        ThrowableMessageMatcher.hasMessage(CoreMatchers.startsWith("Writable channel is not available."))
     );
 
-    final IllegalStateException e2 = Assert.assertThrows(
-        IllegalStateException.class,
+    final DruidException e2 = Assert.assertThrows(
+        DruidException.class,
         () -> Iterables.getOnlyElement(readOnlyChannels.getAllChannels()).getFrameMemoryAllocator()
     );
 
     MatcherAssert.assertThat(
         e2,
-        ThrowableMessageMatcher.hasMessage(CoreMatchers.equalTo(
-            "Frame allocator is not available. The output channel might be marked as read-only, hence memory allocator is not required."))
+        ThrowableMessageMatcher.hasMessage(CoreMatchers.startsWith("Frame memory allocator is not available."))
     );
   }
 
