@@ -61,9 +61,9 @@ public class CgroupV2CpuMonitorTest
   public void testMonitor() throws IOException, InterruptedException
   {
     final CgroupV2CpuMonitor monitor = new CgroupV2CpuMonitor(discoverer);
-    final StubServiceEmitter emitter = new StubServiceEmitter("service", "host");
+    final StubServiceEmitter emitter = StubServiceEmitter.createStarted();
     Assert.assertTrue(monitor.doMonitor(emitter));
-    Assert.assertEquals(0, emitter.getNumEmittedEvents());
+    Assert.assertEquals(2, emitter.getNumEmittedEvents());
 
     emitter.flush();
 
