@@ -21,7 +21,6 @@ package org.apache.druid.query.rowsandcols;
 
 import org.apache.druid.query.rowsandcols.column.Column;
 
-import javax.annotation.Nullable;
 import java.util.Collection;
 
 public class NoAsRowsAndColumns implements RowsAndColumns
@@ -50,12 +49,4 @@ public class NoAsRowsAndColumns implements RowsAndColumns
   {
     return rac.findColumn(name);
   }
-
-  @Nullable
-  @Override
-  public <T> T as(Class<T> clazz)
-  {
-    // Pretend like this doesn't implement any semantic interfaces
-    return null;
-  }
 }
