@@ -83,7 +83,7 @@ public class CustomSegmentizerFactoryTest extends InitializedNullHandlingTest
         data,
         Intervals.of("2011-01-12T00:00:00.000Z/2011-05-01T00:00:00.000Z"),
         segment,
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         null
     );
 
