@@ -30,6 +30,7 @@ import org.apache.druid.query.aggregation.DoubleMaxAggregatorFactory;
 import org.apache.druid.query.aggregation.LongMaxAggregatorFactory;
 import org.apache.druid.query.aggregation.LongSumAggregatorFactory;
 import org.apache.druid.query.aggregation.firstlast.last.LongLastAggregatorFactory;
+import org.apache.druid.segment.projections.AggregateProjectionSchema;
 import org.apache.druid.testing.InitializedNullHandlingTest;
 import org.hamcrest.CoreMatchers;
 import org.hamcrest.MatcherAssert;
@@ -101,13 +102,13 @@ public class MetadataTest extends InitializedNullHandlingTest
     };
     List<AggregateProjectionMetadata> projectionSpecs = List.of(
         new AggregateProjectionMetadata(
-            AggregateProjectionMetadata.schemaBuilder("some_projection")
-                .timeColumnName("__gran")
-                .virtualColumns(Granularities.toVirtualColumn(Granularities.HOUR, "__gran"))
-                .groupAndOrder("a", "b", "__gran")
-                .aggregators(new LongLastAggregatorFactory("atLongLast", "d", null))
-                .ordering("a", "b", "__gran")
-                .build(),
+            AggregateProjectionSchema.schemaBuilder("some_projection")
+                                     .timeColumnName("__gran")
+                                     .virtualColumns(Granularities.toVirtualColumn(Granularities.HOUR, "__gran"))
+                                     .groupAndOrder("a", "b", "__gran")
+                                     .aggregators(new LongLastAggregatorFactory("atLongLast", "d", null))
+                                     .ordering("a", "b", "__gran")
+                                     .build(),
             1234
         )
     );
@@ -274,49 +275,49 @@ public class MetadataTest extends InitializedNullHandlingTest
   {
     List<AggregateProjectionMetadata> p1 = ImmutableList.of(
         new AggregateProjectionMetadata(
-            AggregateProjectionMetadata.schemaBuilder("some_projection")
-                                       .timeColumnName("__gran")
-                                       .virtualColumns(Granularities.toVirtualColumn(Granularities.HOUR, "__gran"))
-                                       .groupAndOrder("a", "b", "__gran")
-                                       .aggregators(new LongLastAggregatorFactory("atLongLast", "d", null))
-                                       .ordering("a", "b", "__gran")
-                                       .build(),
+            AggregateProjectionSchema.schemaBuilder("some_projection")
+                                     .timeColumnName("__gran")
+                                     .virtualColumns(Granularities.toVirtualColumn(Granularities.HOUR, "__gran"))
+                                     .groupAndOrder("a", "b", "__gran")
+                                     .aggregators(new LongLastAggregatorFactory("atLongLast", "d", null))
+                                     .ordering("a", "b", "__gran")
+                                     .build(),
             654321
         )
     );
 
     List<AggregateProjectionMetadata> p2 = ImmutableList.of(
         new AggregateProjectionMetadata(
-            AggregateProjectionMetadata.schemaBuilder("some_projection")
-                                       .timeColumnName("__gran")
-                                       .virtualColumns(Granularities.toVirtualColumn(Granularities.HOUR, "__gran"))
-                                       .groupAndOrder("a", "b", "_gran")
-                                       .aggregators(new LongSumAggregatorFactory("longSum", "d"))
-                                       .ordering("a", "b", "_gran")
-                                       .build(),
+            AggregateProjectionSchema.schemaBuilder("some_projection")
+                                     .timeColumnName("__gran")
+                                     .virtualColumns(Granularities.toVirtualColumn(Granularities.HOUR, "__gran"))
+                                     .groupAndOrder("a", "b", "_gran")
+                                     .aggregators(new LongSumAggregatorFactory("longSum", "d"))
+                                     .ordering("a", "b", "_gran")
+                                     .build(),
             1234
         )
     );
 
     List<AggregateProjectionMetadata> p3 = ImmutableList.of(
         new AggregateProjectionMetadata(
-            AggregateProjectionMetadata.schemaBuilder("some_projection")
-                                       .timeColumnName("__gran")
-                                       .virtualColumns(Granularities.toVirtualColumn(Granularities.HOUR, "__gran"))
-                                       .groupAndOrder("a", "b", "__gran")
-                                       .aggregators(new LongLastAggregatorFactory("atLongLast", "d", null))
-                                       .ordering("a", "b", "__gran")
-                                       .build(),
+            AggregateProjectionSchema.schemaBuilder("some_projection")
+                                     .timeColumnName("__gran")
+                                     .virtualColumns(Granularities.toVirtualColumn(Granularities.HOUR, "__gran"))
+                                     .groupAndOrder("a", "b", "__gran")
+                                     .aggregators(new LongLastAggregatorFactory("atLongLast", "d", null))
+                                     .ordering("a", "b", "__gran")
+                                     .build(),
             12121
         ),
         new AggregateProjectionMetadata(
-            AggregateProjectionMetadata.schemaBuilder("some_projection2")
-                                       .timeColumnName("__gran")
-                                       .virtualColumns(Granularities.toVirtualColumn(Granularities.DAY, "__gran"))
-                                       .groupAndOrder("__gran", "a")
-                                       .aggregators(new LongSumAggregatorFactory("longSum", "d"))
-                                       .ordering("__gran", "a")
-                                       .build(),
+            AggregateProjectionSchema.schemaBuilder("some_projection2")
+                                     .timeColumnName("__gran")
+                                     .virtualColumns(Granularities.toVirtualColumn(Granularities.DAY, "__gran"))
+                                     .groupAndOrder("__gran", "a")
+                                     .aggregators(new LongSumAggregatorFactory("longSum", "d"))
+                                     .ordering("__gran", "a")
+                                     .build(),
             555
         )
     );
