@@ -23,7 +23,6 @@ import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.Iterables;
 import com.google.common.collect.Lists;
-import org.apache.druid.common.config.NullHandling;
 import org.apache.druid.java.util.common.DateTimes;
 import org.apache.druid.java.util.common.Intervals;
 import org.apache.druid.java.util.common.Pair;
@@ -402,7 +401,7 @@ public class SchemalessTestFullTest extends InitializedNullHandlingTest
                     .put("addRowsIndexConstant", 103.0D)
                     .put("uniques", UNIQUES_1)
                     .put("maxIndex", 100.0D)
-                    .put("minIndex", NullHandling.replaceWithDefault() ? 0.0D : 100.0D)
+                    .put("minIndex", 100.0D)
                     .build()
             )
         )
@@ -749,7 +748,7 @@ public class SchemalessTestFullTest extends InitializedNullHandlingTest
                     .put("addRowsIndexConstant", 103.0D)
                     .put("uniques", UNIQUES_1)
                     .put("maxIndex", 100.0D)
-                    .put("minIndex", NullHandling.replaceWithDefault() ? 0.0D : 100.0D)
+                    .put("minIndex", 100.0D)
                     .build()
             )
         )
@@ -868,11 +867,11 @@ public class SchemalessTestFullTest extends InitializedNullHandlingTest
             new TimeseriesResultValue(
                 TestHelper.makeMap(
                     "rows", 1L,
-                    "index", NullHandling.replaceWithDefault() ? 0.0D : null,
-                    "addRowsIndexConstant", NullHandling.replaceWithDefault() ? 2.0D : null,
+                    "index", null,
+                    "addRowsIndexConstant", null,
                     "uniques", 0.0D,
-                    "maxIndex", NullHandling.replaceWithDefault() ? 0.0D : null,
-                    "minIndex", NullHandling.replaceWithDefault() ? 0.0D : null
+                    "maxIndex", null,
+                    "minIndex", null
                 ))
         )
     );
@@ -883,11 +882,11 @@ public class SchemalessTestFullTest extends InitializedNullHandlingTest
             new TimeseriesResultValue(
                 TestHelper.makeMap(
                     "rows", 0L,
-                    "index", NullHandling.replaceWithDefault() ? 0.0D : null,
-                    "addRowsIndexConstant", NullHandling.replaceWithDefault() ? 1.0D : null,
+                    "index", null,
+                    "addRowsIndexConstant", null,
                     "uniques", 0.0D,
-                    "maxIndex", NullHandling.replaceWithDefault() ? Double.NEGATIVE_INFINITY : null,
-                    "minIndex", NullHandling.replaceWithDefault() ? Double.POSITIVE_INFINITY : null
+                    "maxIndex", null,
+                    "minIndex", null
                 )
             )
         )
@@ -1178,12 +1177,12 @@ public class SchemalessTestFullTest extends InitializedNullHandlingTest
             DateTimes.of("2011-01-12T00:00:00.000Z"),
             new TimeseriesResultValue(
                 ImmutableMap.<String, Object>builder()
-                    .put("rows", NullHandling.sqlCompatible() ? 11L : 10L)
+                    .put("rows", 11L)
                     .put("index", 900.0D)
-                    .put("addRowsIndexConstant", NullHandling.sqlCompatible() ? 912.0D : 911.0D)
+                    .put("addRowsIndexConstant", 912.0D)
                     .put("uniques", UNIQUES_1)
                     .put("maxIndex", 100.0D)
-                    .put("minIndex", NullHandling.replaceWithDefault() ? 0.0D : 100.0D)
+                    .put("minIndex", 100.0D)
                     .build()
             )
         )
