@@ -44,7 +44,7 @@ import org.apache.druid.segment.TestHelper;
 import org.apache.druid.segment.TestIndex;
 import org.apache.druid.segment.column.ColumnCapabilities;
 import org.apache.druid.segment.column.ColumnCapabilitiesImpl;
-import org.apache.druid.segment.column.ValueType;
+import org.apache.druid.segment.column.ColumnType;
 import org.apache.druid.timeline.SegmentId;
 import org.junit.Before;
 import org.junit.Rule;
@@ -120,7 +120,7 @@ public class VectorizedVirtualColumnTest
   public void testGroupBySingleValueString()
   {
     testGroupBy(new ColumnCapabilitiesImpl()
-                    .setType(ValueType.STRING)
+                    .setType(ColumnType.STRING)
                     .setDictionaryEncoded(true)
                     .setDictionaryValuesUnique(true)
                     .setHasMultipleValues(false)
@@ -133,7 +133,7 @@ public class VectorizedVirtualColumnTest
     // cannot currently group by string columns that might be multi valued
     cannotVectorize();
     testGroupBy(new ColumnCapabilitiesImpl()
-                    .setType(ValueType.STRING)
+                    .setType(ColumnType.STRING)
                     .setDictionaryEncoded(true)
                     .setDictionaryValuesUnique(true)
                     .setHasMultipleValues(true)
@@ -146,7 +146,7 @@ public class VectorizedVirtualColumnTest
     // cannot currently group by string columns that might be multi valued
     cannotVectorize();
     testGroupBy(new ColumnCapabilitiesImpl()
-                    .setType(ValueType.STRING)
+                    .setType(ColumnType.STRING)
                     .setDictionaryEncoded(true)
                     .setDictionaryValuesUnique(true)
     );
@@ -156,7 +156,7 @@ public class VectorizedVirtualColumnTest
   public void testGroupBySingleValueStringNotDictionaryEncoded()
   {
     testGroupBy(new ColumnCapabilitiesImpl()
-                    .setType(ValueType.STRING)
+                    .setType(ColumnType.STRING)
                     .setDictionaryEncoded(false)
                     .setDictionaryValuesUnique(false)
                     .setHasMultipleValues(false)
@@ -169,7 +169,7 @@ public class VectorizedVirtualColumnTest
     // cannot currently group by string columns that might be multi valued
     cannotVectorize();
     testGroupBy(new ColumnCapabilitiesImpl()
-                    .setType(ValueType.STRING)
+                    .setType(ColumnType.STRING)
                     .setDictionaryEncoded(false)
                     .setDictionaryValuesUnique(false)
                     .setHasMultipleValues(true)
@@ -179,26 +179,26 @@ public class VectorizedVirtualColumnTest
   @Test
   public void testGroupByLong()
   {
-    testGroupBy(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.LONG));
+    testGroupBy(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.LONG));
   }
 
   @Test
   public void testGroupByDouble()
   {
-    testGroupBy(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.DOUBLE));
+    testGroupBy(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.DOUBLE));
   }
 
   @Test
   public void testGroupByFloat()
   {
-    testGroupBy(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT));
+    testGroupBy(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT));
   }
 
   @Test
   public void testTimeseriesSingleValueString()
   {
     testTimeseries(new ColumnCapabilitiesImpl()
-                       .setType(ValueType.STRING)
+                       .setType(ColumnType.STRING)
                        .setDictionaryEncoded(true)
                        .setDictionaryValuesUnique(true)
                        .setHasMultipleValues(false)
@@ -209,7 +209,7 @@ public class VectorizedVirtualColumnTest
   public void testTimeseriesMultiValueString()
   {
     testTimeseries(new ColumnCapabilitiesImpl()
-                       .setType(ValueType.STRING)
+                       .setType(ColumnType.STRING)
                        .setDictionaryEncoded(true)
                        .setDictionaryValuesUnique(true)
                        .setHasMultipleValues(true)
@@ -220,7 +220,7 @@ public class VectorizedVirtualColumnTest
   public void testTimeseriesMultiValueStringUnknown()
   {
     testTimeseries(new ColumnCapabilitiesImpl()
-                       .setType(ValueType.STRING)
+                       .setType(ColumnType.STRING)
                        .setDictionaryEncoded(true)
                        .setDictionaryValuesUnique(true)
     );
@@ -230,7 +230,7 @@ public class VectorizedVirtualColumnTest
   public void testTimeseriesSingleValueStringNotDictionaryEncoded()
   {
     testTimeseries(new ColumnCapabilitiesImpl()
-                       .setType(ValueType.STRING)
+                       .setType(ColumnType.STRING)
                        .setDictionaryEncoded(false)
                        .setDictionaryValuesUnique(false)
                        .setHasMultipleValues(false)
@@ -241,7 +241,7 @@ public class VectorizedVirtualColumnTest
   public void testTimeseriesMultiValueStringNotDictionaryEncoded()
   {
     testTimeseries(new ColumnCapabilitiesImpl()
-                       .setType(ValueType.STRING)
+                       .setType(ColumnType.STRING)
                        .setDictionaryEncoded(false)
                        .setDictionaryValuesUnique(false)
                        .setHasMultipleValues(true)
@@ -251,19 +251,19 @@ public class VectorizedVirtualColumnTest
   @Test
   public void testTimeseriesLong()
   {
-    testTimeseries(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.LONG));
+    testTimeseries(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.LONG));
   }
 
   @Test
   public void testTimeseriesDouble()
   {
-    testTimeseries(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.DOUBLE));
+    testTimeseries(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.DOUBLE));
   }
 
   @Test
   public void testTimeseriesFloat()
   {
-    testTimeseries(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT));
+    testTimeseries(ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT));
   }
 
   @Test
@@ -271,7 +271,7 @@ public class VectorizedVirtualColumnTest
   {
     cannotVectorize();
     testTimeseries(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_VECTORIZE_FORCE,
         false
     );
@@ -282,18 +282,17 @@ public class VectorizedVirtualColumnTest
   {
     cannotVectorize();
     testTimeseries(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_VECTORIZE_TRUE_VIRTUAL_FORCE,
         false
     );
   }
 
   @Test
-  public void testTimeseriesTrueVirtualContextCannotVectorize()
+  public void testTimeseriesTrueVirtualContextDefault()
   {
-    expectNonvectorized();
     testTimeseries(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_USE_DEFAULTS,
         true
     );
@@ -304,7 +303,7 @@ public class VectorizedVirtualColumnTest
   {
     expectNonvectorized();
     testTimeseries(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_CONTRADICTION_VECTORIZE_FALSE_VIRTUAL_FORCE,
         true
     );
@@ -315,7 +314,7 @@ public class VectorizedVirtualColumnTest
   {
     cannotVectorize();
     testTimeseries(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_CONTRADICTION_VECTORIZE_FORCE_VIRTUAL_FALSE,
         true
     );
@@ -325,7 +324,7 @@ public class VectorizedVirtualColumnTest
   public void testTimeseriesContradictionVectorizeFalseVirtualForceNoVirtualColumns()
   {
     testTimeseriesNoVirtual(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_CONTRADICTION_VECTORIZE_FALSE_VIRTUAL_FORCE
     );
   }
@@ -333,7 +332,7 @@ public class VectorizedVirtualColumnTest
   public void testTimeseriesContradictionVectorizeForceVirtualFalseNoVirtual()
   {
     testTimeseriesNoVirtual(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_CONTRADICTION_VECTORIZE_FORCE_VIRTUAL_FALSE
     );
   }
@@ -342,7 +341,7 @@ public class VectorizedVirtualColumnTest
   public void testTimeseriesForceDoestAffectWhenNoVirtualColumns()
   {
     testTimeseriesNoVirtual(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_VECTORIZE_TRUE_VIRTUAL_FORCE
     );
   }
@@ -352,7 +351,7 @@ public class VectorizedVirtualColumnTest
   {
     cannotVectorize();
     testGroupBy(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_VECTORIZE_FORCE,
         false
     );
@@ -364,7 +363,7 @@ public class VectorizedVirtualColumnTest
     cannotVectorize();
     testGroupBy(
         new ColumnCapabilitiesImpl()
-            .setType(ValueType.STRING)
+            .setType(ColumnType.STRING)
             .setDictionaryEncoded(true)
             .setDictionaryValuesUnique(true)
             .setHasMultipleValues(false),
@@ -378,7 +377,7 @@ public class VectorizedVirtualColumnTest
   {
     expectNonvectorized();
     testGroupBy(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_USE_DEFAULTS,
         false
     );
@@ -389,7 +388,7 @@ public class VectorizedVirtualColumnTest
   {
     expectNonvectorized();
     testGroupBy(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_CONTRADICTION_VECTORIZE_FALSE_VIRTUAL_FORCE,
         true
     );
@@ -400,7 +399,7 @@ public class VectorizedVirtualColumnTest
   {
     cannotVectorize();
     testGroupBy(
-        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ValueType.FLOAT),
+        ColumnCapabilitiesImpl.createSimpleNumericColumnCapabilities(ColumnType.FLOAT),
         CONTEXT_CONTRADICTION_VECTORIZE_FORCE_VIRTUAL_FALSE,
         true
     );
@@ -411,7 +410,7 @@ public class VectorizedVirtualColumnTest
   {
     testGroupByNoVirtual(
         new ColumnCapabilitiesImpl()
-            .setType(ValueType.STRING)
+            .setType(ColumnType.STRING)
             .setDictionaryEncoded(true)
             .setDictionaryValuesUnique(true)
             .setHasMultipleValues(false),
@@ -424,7 +423,7 @@ public class VectorizedVirtualColumnTest
   {
     testGroupByNoVirtual(
         new ColumnCapabilitiesImpl()
-            .setType(ValueType.STRING)
+            .setType(ColumnType.STRING)
             .setDictionaryEncoded(true)
             .setDictionaryValuesUnique(true)
             .setHasMultipleValues(false),
@@ -437,7 +436,7 @@ public class VectorizedVirtualColumnTest
   {
     testGroupByNoVirtual(
         new ColumnCapabilitiesImpl()
-            .setType(ValueType.STRING)
+            .setType(ColumnType.STRING)
             .setDictionaryEncoded(true)
             .setDictionaryValuesUnique(true)
             .setHasMultipleValues(false),
@@ -534,7 +533,7 @@ public class VectorizedVirtualColumnTest
         .setVirtualColumns(
             new AlwaysTwoVectorizedVirtualColumn(ALWAYS_TWO, capabilities, canVectorize)
         )
-        .addDimension(new DefaultDimensionSpec(ALWAYS_TWO, ALWAYS_TWO, capabilities.getType()))
+        .addDimension(new DefaultDimensionSpec(ALWAYS_TWO, ALWAYS_TWO, capabilities.toColumnType()))
         .setAggregatorSpecs(new AlwaysTwoCounterAggregatorFactory(COUNT, ALWAYS_TWO))
         .setInterval("2000/2030")
         .setContext(context)
@@ -563,7 +562,7 @@ public class VectorizedVirtualColumnTest
         .setDataSource(QueryRunnerTestHelper.DATA_SOURCE)
         .setGranularity(Granularities.ALL)
         .setVirtualColumns()
-        .addDimension(new DefaultDimensionSpec("placement", "placement", capabilities.getType()))
+        .addDimension(new DefaultDimensionSpec("placement", "placement", capabilities.toColumnType()))
         .setAggregatorSpecs(new CountAggregatorFactory(COUNT))
         .setInterval("2000/2030")
         .setContext(context)
