@@ -24,6 +24,7 @@ import com.fasterxml.jackson.annotation.JsonInclude;
 import com.fasterxml.jackson.annotation.JsonProperty;
 import com.google.common.base.Preconditions;
 import org.apache.druid.data.input.impl.AggregateProjectionSpec;
+import org.apache.druid.indexer.CompactionEngine;
 import org.apache.druid.query.aggregation.AggregatorFactory;
 import org.apache.druid.segment.transform.CompactionTransformSpec;
 
@@ -161,6 +162,14 @@ public class ClientCompactionTaskQuery implements ClientTaskQuery
     return compactionRunner;
   }
 
+  /**
+   * @return true if this is an MSQ compaction task.
+   */
+  public boolean isMsq()
+  {
+    return compactionRunner != null && compactionRunner.getType() == CompactionEngine.MSQ;
+  }
+
   @Override
   public boolean equals(Object o)
   {
