@@ -43,6 +43,10 @@ public interface SegmentCacheManager
    */
   boolean canHandleSegments();
 
+  boolean canLoadSegmentsOnDemand();
+
+  boolean canLoadSegmentOnDemand(DataSegment segment);
+
   /**
    * Return a list of cached segments from local disk, if any. This should be called only when
    * {@link #canHandleSegments()} is true.
@@ -134,4 +138,10 @@ public interface SegmentCacheManager
   void shutdownBootstrap();
 
   void shutdown();
+
+  /**
+   * Collect {@link StorageStats}, if available.
+   */
+  @Nullable
+  StorageStats getStorageStats();
 }
