@@ -77,6 +77,14 @@ public class SegmentLoaderConfig
   @JsonProperty("virtualStorageLoadThreads")
   private int virtualStorageLoadThreads = 2 * runtimeInfo.getAvailableProcessors();
 
+  /**
+   * When enabled, weakly-held cache entries are evicted immediately upon release of all holds, rather than
+   * waiting for space pressure to trigger eviction. This setting is not intended to be configured directly by
+   * administrators. Instead, it is expected to be set when appropriate via {@link #setVirtualStorage}.
+   */
+  @JsonProperty("virtualStorageIsEphemeral")
+  private boolean virtualStorageIsEphemeral = false;
+
   private long combinedMaxSize = 0;
 
   public List<StorageLocationConfig> getLocations()
@@ -154,6 +162,11 @@ public class SegmentLoaderConfig
     return virtualStorageLoadThreads;
   }
 
+  public boolean isVirtualStorageEphemeral()
+  {
+    return virtualStorageIsEphemeral;
+  }
+
   public SegmentLoaderConfig withLocations(List<StorageLocationConfig> locations)
   {
     SegmentLoaderConfig retVal = new SegmentLoaderConfig();
@@ -163,6 +176,19 @@ public class SegmentLoaderConfig
     return retVal;
   }
 
+  /**
+   * Sets {@link #virtualStorage} and {@link #virtualStorageIsEphemeral}.
+   */
+  public SegmentLoaderConfig setVirtualStorage(
+      boolean virtualStorage,
+      boolean virtualStorageFabricEphemeral
+  )
+  {
+    this.virtualStorage = virtualStorage;
+    this.virtualStorageIsEphemeral = virtualStorageFabricEphemeral;
+    return this;
+  }
+
   /**
    * Convert a list of {@link StorageLocationConfig} objects to {@link StorageLocation} objects.
    * <p>
@@ -193,8 +219,9 @@ public class SegmentLoaderConfig
            ", numThreadsToLoadSegmentsIntoPageCacheOnBootstrap=" + numThreadsToLoadSegmentsIntoPageCacheOnBootstrap +
            ", infoDir=" + infoDir +
            ", statusQueueMaxSize=" + statusQueueMaxSize +
-           ", useVirtualStorageFabric=" + virtualStorage +
-           ", virtualStorageFabricLoadThreads=" + virtualStorageLoadThreads +
+           ", virtualStorage=" + virtualStorage +
+           ", virtualStorageLoadThreads=" + virtualStorageLoadThreads +
+           ", virtualStorageIsEphemeral=" + virtualStorageIsEphemeral +
            ", combinedMaxSize=" + combinedMaxSize +
            '}';
   }
