@@ -80,6 +80,11 @@ import java.util.function.Supplier;
  * is repeated until either a sufficient amount of space has been reclaimed, or no additional space is able to be
  * reclaimed, in which case the new reservation fails.
  * <p>
+ * There is an auxilary mode for weak references when {@link #areWeakEntriesEphemeral} is set to true. In this mode, weak
+ * entries are short-lived entries that only exist while one or more reservation hold are active, and are unmounted when
+ * the holds are released. This is useful in cases where entries are unlikely to be re-used such as in asynchronous
+ * tasks.
+ * <p>
  * This class is thread-safe, so that multiple threads can update its state at the same time.
  * One example usage is that a historical server can use multiple threads to load different segments in parallel
  * from deep storage.
@@ -106,18 +111,17 @@ public class StorageLocation
   @GuardedBy("lock")
   private WeakCacheEntry hand;
 
-  /**
-   * Current total size of files in bytes, including weak entries.
-   */
+  private volatile boolean areWeakEntriesEphemeral = false;
 
   /**
    * Current total size of files in bytes, including weak entries.
    */
   private final AtomicLong currSizeBytes = new AtomicLong(0);
-
+  private final AtomicLong currStaticSizeBytes = new AtomicLong(0);
   private final AtomicLong currWeakSizeBytes = new AtomicLong(0);
 
-  private final AtomicReference<Stats> stats = new AtomicReference<>();
+  private final AtomicReference<StaticStats> staticStats = new AtomicReference<>();
+  private final AtomicReference<WeakStats> weakStats = new AtomicReference<>();
 
   /**
    * A {@link ReentrantReadWriteLock.ReadLock} may be used for any operations to access {@link #staticCacheEntries} or
@@ -147,7 +151,8 @@ public class StorageLocation
     } else {
       this.freeSpaceToKeep = 0;
     }
-    resetStats();
+    resetStaticStats();
+    resetWeakStats();
   }
 
   /**
@@ -169,6 +174,15 @@ public class StorageLocation
     return path;
   }
 
+  /**
+   * Sets whether weak cache entries should be retained after all holds are released. If true, weak references are
+   * removed and unmounted immediately after all holds are released
+   */
+  public void setAreWeakEntriesEphemeral(final boolean areWeakEntriesEphemeral)
+  {
+    this.areWeakEntriesEphemeral = areWeakEntriesEphemeral;
+  }
+
   public <T extends CacheEntry> T getStaticCacheEntry(CacheEntryIdentifier entryId)
   {
     lock.readLock().lock();
@@ -259,6 +273,8 @@ public class StorageLocation
       if (reclaimResult.isSuccess()) {
         staticCacheEntries.put(entry.getId(), entry);
         currSizeBytes.getAndAdd(entry.getSize());
+        currStaticSizeBytes.getAndAdd(entry.getSize());
+        staticStats.getAndUpdate(s -> s.load(entry.getSize()));
       }
       return reclaimResult.isSuccess();
     }
@@ -306,7 +322,7 @@ public class StorageLocation
         final WeakCacheEntry newEntry = new WeakCacheEntry(entry);
         linkNewWeakEntry(newEntry);
         weakCacheEntries.put(entry.getId(), newEntry);
-        stats.get().load();
+        weakStats.getAndUpdate(s -> s.load(entry.getSize()));
       }
       return reclaimResult.isSuccess();
     }
@@ -335,8 +351,11 @@ public class StorageLocation
       WeakCacheEntry existingEntry = weakCacheEntries.get(entryId);
       if (existingEntry != null && existingEntry.hold()) {
         existingEntry.visited = true;
-        stats.get().hit();
-        return new ReservationHold<>((T) existingEntry.cacheEntry, existingEntry::release);
+        weakStats.getAndUpdate(WeakStats::hit);
+        return new ReservationHold<>(
+            (T) existingEntry.cacheEntry,
+            createWeakEntryReleaseRunnable(existingEntry, false)
+        );
       }
       return null;
     }
@@ -369,8 +388,11 @@ public class StorageLocation
       WeakCacheEntry retryExistingEntry = weakCacheEntries.get(entryId);
       if (retryExistingEntry != null && retryExistingEntry.hold()) {
         retryExistingEntry.visited = true;
-        stats.get().hit();
-        return new ReservationHold<>((T) retryExistingEntry.cacheEntry, retryExistingEntry::release);
+        weakStats.getAndUpdate(WeakStats::hit);
+        return new ReservationHold<>(
+            (T) retryExistingEntry.cacheEntry,
+            createWeakEntryReleaseRunnable(retryExistingEntry, false)
+        );
       }
       final CacheEntry newEntry = entrySupplier.get();
       final ReclaimResult reclaimResult = canHandleWeak(newEntry);
@@ -381,34 +403,13 @@ public class StorageLocation
         newWeakEntry.hold();
         linkNewWeakEntry(newWeakEntry);
         weakCacheEntries.put(newEntry.getId(), newWeakEntry);
-        stats.get().load();
+        weakStats.getAndUpdate(s -> s.load(newEntry.getSize()));
         hold = new ReservationHold<>(
             (T) newEntry,
-            () -> {
-              newWeakEntry.release();
-              lock.writeLock().lock();
-              try {
-                weakCacheEntries.computeIfPresent(
-                    newEntry.getId(),
-                    (cacheEntryIdentifier, weakCacheEntry) -> {
-                      if (!weakCacheEntry.cacheEntry.isMounted()) {
-                        // if we never successfully mounted, go ahead and remove so we don't have a dead entry
-                        unlinkWeakEntry(weakCacheEntry);
-                        // we call unmount anyway to terminate the phaser
-                        weakCacheEntry.unmount();
-                        return null;
-                      }
-                      return weakCacheEntry;
-                    }
-                );
-              }
-              finally {
-                lock.writeLock().unlock();
-              }
-            }
+            createWeakEntryReleaseRunnable(newWeakEntry, true)
         );
       } else {
-        stats.get().reject();
+        weakStats.getAndUpdate(WeakStats::reject);
         hold = null;
       }
       return hold;
@@ -419,23 +420,20 @@ public class StorageLocation
   }
 
   /**
-   * Removes an item from {@link #staticCacheEntries} or {@link #weakCacheEntries}, reducing {@link #currSizeBytes}
-   * by {@link CacheEntry#getSize()}
+   * Removes an item from {@link #staticCacheEntries}, reducing {@link #currSizeBytes} by {@link CacheEntry#getSize()}.
+   * If the cache entry exists in {@link #weakCacheEntries}, it is left in place to be removed by
+   * {@link #reclaim(long)} instead.
    */
   public void release(CacheEntry entry)
   {
     lock.writeLock().lock();
     try {
-
       if (staticCacheEntries.containsKey(entry.getId())) {
         final CacheEntry toRemove = staticCacheEntries.remove(entry.getId());
         toRemove.unmount();
         currSizeBytes.getAndAdd(-entry.getSize());
-      } else if (weakCacheEntries.containsKey(entry.getId())) {
-        final WeakCacheEntry toRemove = weakCacheEntries.remove(entry.getId());
-        unlinkWeakEntry(toRemove);
-        toRemove.unmount();
-        stats.get().unmount();
+        currStaticSizeBytes.getAndAdd(-entry.getSize());
+        staticStats.getAndUpdate(s -> s.drop(entry.getSize()));
       }
     }
     finally {
@@ -443,6 +441,52 @@ public class StorageLocation
     }
   }
 
+  /**
+   * Creates a release runnable for a {@link WeakCacheEntry} that handles immediate eviction when configured.
+   * If {@link #evictImmediately} is true and there are no more holds after releasing, the entry is immediately
+   * evicted from the cache. For new entries (isNewEntry=true), unmounted entries are also removed.
+   */
+  private Runnable createWeakEntryReleaseRunnable(
+      final WeakCacheEntry weakEntry,
+      final boolean isNewEntry
+  )
+  {
+    return () -> {
+      weakEntry.release();
+
+      if (!isNewEntry && !areWeakEntriesEphemeral) {
+        // No need to consider removal from weakCacheEntries on hold release.
+        return;
+      }
+
+      lock.writeLock().lock();
+      try {
+        weakCacheEntries.computeIfPresent(
+            weakEntry.cacheEntry.getId(),
+            (cacheEntryIdentifier, weakCacheEntry) -> {
+              // If we never successfully mounted, go ahead and remove so we don't have a dead entry.
+              // Furthermore, if evictImmediatelyOnHoldRelease is set, evict on release if all holds are gone.
+              final boolean isMounted = weakCacheEntry.cacheEntry.isMounted();
+              if ((isNewEntry && !isMounted)
+                  || (areWeakEntriesEphemeral && !weakCacheEntry.isHeld())) {
+                unlinkWeakEntry(weakCacheEntry);
+                weakCacheEntry.unmount(); // call even if never mounted, to terminate the phaser
+                if (isMounted) {
+                  weakStats.getAndUpdate(s -> s.evict(weakCacheEntry.cacheEntry.getSize()));
+                }
+                return null;
+              } else {
+                return weakCacheEntry;
+              }
+            }
+        );
+      }
+      finally {
+        lock.writeLock().unlock();
+      }
+    };
+  }
+
   /**
    * Inserts a new {@link WeakCacheEntry}, inserting it as {@link #head} (or both {@link #head} and {@link #tail} if it
    * is the only entry), tracking size in {@link #currSizeBytes} and {@link #currWeakSizeBytes}
@@ -583,7 +627,7 @@ public class StorageLocation
             cacheEntryIdentifier -> {
               if (!staticCacheEntries.containsKey(cacheEntryIdentifier)) {
                 removed.unmount();
-                stats.get().unmount();
+                weakStats.getAndUpdate(WeakStats::unmount);
               }
               return null;
             }
@@ -615,14 +659,47 @@ public class StorageLocation
     }
   }
 
-  public Stats getStats()
+  /**
+   * Unmounts all static and weakly held cache entries and resets stats and size tracking. Currently only for testing.
+   */
+  @VisibleForTesting
+  public void reset()
   {
-    return stats.get();
+    lock.writeLock().lock();
+    try {
+      for (CacheEntry entry : staticCacheEntries.values()) {
+        entry.unmount();
+      }
+      staticCacheEntries.clear();
+      while (head != null) {
+        head.unmount();
+        head = head.next;
+      }
+      weakCacheEntries.clear();
+    }
+    finally {
+      lock.writeLock().unlock();
+    }
+    currSizeBytes.set(0);
+    currWeakSizeBytes.set(0);
+    currStaticSizeBytes.set(0);
+    resetStaticStats();
+    resetWeakStats();
   }
 
-  public void resetStats()
+  public WeakStats getWeakStats()
   {
-    stats.set(new Stats());
+    return weakStats.get();
+  }
+
+  public StaticStats resetStaticStats()
+  {
+    return staticStats.getAndSet(new StaticStats(currStaticSizeBytes));
+  }
+
+  public WeakStats resetWeakStats()
+  {
+    return weakStats.getAndSet(new WeakStats(currWeakSizeBytes));
   }
 
   /**
@@ -680,11 +757,11 @@ public class StorageLocation
           );
         }
         unlinkWeakEntry(removed);
-        stats.get().evict();
-        toRemove.next = null;
-        toRemove.prev = null;
-        droppedEntries.add(toRemove);
-        sizeFreed += toRemove.cacheEntry.getSize();
+        weakStats.getAndUpdate(s -> s.evict(removed.cacheEntry.getSize()));
+        removed.next = null;
+        removed.prev = null;
+        droppedEntries.add(removed);
+        sizeFreed += removed.cacheEntry.getSize();
         startEntry = null;
       }
 
@@ -876,62 +953,158 @@ public class StorageLocation
     }
   }
 
-  public static final class Stats
+  public static final class StaticStats implements StorageLocationStats
   {
+    private final AtomicLong sizeUsed;
     private final AtomicLong loadCount = new AtomicLong(0);
-    private final AtomicLong rejectionCount = new AtomicLong(0);
-    private final AtomicLong hitCount = new AtomicLong(0);
-    private final AtomicLong evictionCount = new AtomicLong(0);
-    private final AtomicLong unmountCount = new AtomicLong(0);
+    private final AtomicLong loadBytes = new AtomicLong(0);
+    private final AtomicLong dropCount = new AtomicLong(0);
+    private final AtomicLong dropBytes = new AtomicLong(0);
 
-    public void hit()
+    public StaticStats(AtomicLong sizeUsed)
     {
-      hitCount.getAndIncrement();
+      this.sizeUsed = sizeUsed;
     }
 
-    public long getHitCount()
-    {
-      return hitCount.get();
-    }
-
-    public void load()
+    public StaticStats load(long size)
     {
       loadCount.getAndIncrement();
+      loadBytes.getAndAdd(size);
+      return this;
     }
 
+    public StaticStats drop(long size)
+    {
+      dropCount.getAndIncrement();
+      dropBytes.getAndAdd(size);
+      return this;
+    }
+
+    @Override
+    public long getUsedBytes()
+    {
+      return sizeUsed.get();
+    }
+
+    @Override
     public long getLoadCount()
     {
       return loadCount.get();
     }
 
-    public void evict()
+    @Override
+    public long getLoadBytes()
     {
-      evictionCount.getAndIncrement();
+      return loadBytes.get();
     }
 
+    @Override
+    public long getDropCount()
+    {
+      return dropCount.get();
+    }
+
+    @Override
+    public long getDropBytes()
+    {
+      return dropBytes.get();
+    }
+  }
+
+  public static final class WeakStats implements VirtualStorageLocationStats
+  {
+    private final AtomicLong sizeUsed;
+    private final AtomicLong loadCount = new AtomicLong(0);
+    private final AtomicLong loadBytes = new AtomicLong(0);
+    private final AtomicLong rejectionCount = new AtomicLong(0);
+    private final AtomicLong hitCount = new AtomicLong(0);
+    private final AtomicLong evictionCount = new AtomicLong(0);
+    private final AtomicLong evictionBytes = new AtomicLong(0);
+    private final AtomicLong unmountCount = new AtomicLong(0);
+
+    public WeakStats(AtomicLong sizeUsed)
+    {
+      this.sizeUsed = sizeUsed;
+    }
+
+    public WeakStats hit()
+    {
+      hitCount.getAndIncrement();
+      return this;
+    }
+
+    public WeakStats load(long size)
+    {
+      loadCount.getAndIncrement();
+      loadBytes.getAndAdd(size);
+      return this;
+    }
+
+    public WeakStats evict(long size)
+    {
+      evictionCount.getAndIncrement();
+      evictionBytes.getAndAdd(size);
+      return this;
+    }
+
+    public WeakStats unmount()
+    {
+      unmountCount.getAndIncrement();
+      return this;
+    }
+
+    public WeakStats reject()
+    {
+      rejectionCount.getAndIncrement();
+      return this;
+    }
+
+    @Override
+    public long getUsedBytes()
+    {
+      return sizeUsed.get();
+    }
+
+    @Override
+    public long getHitCount()
+    {
+      return hitCount.get();
+    }
+
+    @Override
+    public long getLoadCount()
+    {
+      return loadCount.get();
+    }
+
+    @Override
+    public long getLoadBytes()
+    {
+      return loadBytes.get();
+    }
+
+    @Override
     public long getEvictionCount()
     {
       return evictionCount.get();
     }
 
-    public void unmount()
+    @Override
+    public long getEvictionBytes()
     {
-      unmountCount.getAndIncrement();
-    }
-
-    public long getUnmountCount()
-    {
-      return unmountCount.get();
-    }
-
-    public void reject()
-    {
-      rejectionCount.getAndIncrement();
+      return evictionBytes.get();
     }
 
+    @Override
     public long getRejectCount()
     {
       return rejectionCount.get();
     }
+
+    @VisibleForTesting
+    public long getUnmountCount()
+    {
+      return unmountCount.get();
+    }
   }
 }
