@@ -20,6 +20,7 @@
 package org.apache.druid.server;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
+import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.Lists;
 import com.google.common.util.concurrent.Futures;
 import com.google.common.util.concurrent.ListenableFuture;
@@ -33,6 +34,7 @@ import org.apache.druid.guice.annotations.Smile;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.guava.FunctionalIterable;
 import org.apache.druid.java.util.common.guava.Sequence;
+import org.apache.druid.java.util.common.guava.Sequences;
 import org.apache.druid.java.util.common.io.Closer;
 import org.apache.druid.java.util.emitter.EmittingLogger;
 import org.apache.druid.java.util.emitter.service.ServiceEmitter;
@@ -41,6 +43,7 @@ import org.apache.druid.query.CPUTimeMetricQueryRunner;
 import org.apache.druid.query.DataSegmentAndDescriptor;
 import org.apache.druid.query.DataSource;
 import org.apache.druid.query.FinalizeResultsQueryRunner;
+import org.apache.druid.query.LeafSegmentsBundle;
 import org.apache.druid.query.MetricsEmittingQueryRunner;
 import org.apache.druid.query.NoopQueryRunner;
 import org.apache.druid.query.PerSegmentOptimizingQueryRunner;
@@ -56,7 +59,6 @@ import org.apache.druid.query.QueryRunnerFactoryConglomerate;
 import org.apache.druid.query.QuerySegmentWalker;
 import org.apache.druid.query.QueryToolChest;
 import org.apache.druid.query.QueryUnsupportedException;
-import org.apache.druid.query.ReportTimelineMissingSegmentQueryRunner;
 import org.apache.druid.query.SegmentDescriptor;
 import org.apache.druid.query.context.ResponseContext;
 import org.apache.druid.query.metadata.metadata.SegmentMetadataQuery;
@@ -64,12 +66,12 @@ import org.apache.druid.query.planning.ExecutionVertex;
 import org.apache.druid.query.policy.PolicyEnforcer;
 import org.apache.druid.query.spec.SpecificSegmentQueryRunner;
 import org.apache.druid.query.spec.SpecificSegmentSpec;
-import org.apache.druid.segment.ReferenceCountedObjectProvider;
 import org.apache.druid.segment.Segment;
 import org.apache.druid.segment.SegmentMapFunction;
 import org.apache.druid.segment.SegmentReference;
 import org.apache.druid.segment.TimeBoundaryInspector;
 import org.apache.druid.segment.loading.AcquireSegmentAction;
+import org.apache.druid.segment.loading.AcquireSegmentResult;
 import org.apache.druid.segment.loading.VirtualPlaceholderSegment;
 import org.apache.druid.server.initialization.ServerConfig;
 import org.apache.druid.timeline.DataSegment;
@@ -80,6 +82,7 @@ import org.apache.druid.utils.CloseableUtils;
 import org.apache.druid.utils.JvmUtils;
 import org.joda.time.Interval;
 
+import javax.annotation.Nullable;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Optional;
@@ -102,7 +105,7 @@ public class ServerManager implements QuerySegmentWalker
   private final Cache cache;
   private final ObjectMapper objectMapper;
   private final CacheConfig cacheConfig;
-  private final SegmentManager segmentManager;
+  protected final SegmentManager segmentManager;
   private final ServerConfig serverConfig;
   private final PolicyEnforcer policyEnforcer;
 
@@ -182,7 +185,10 @@ public class ServerManager implements QuerySegmentWalker
     final Optional<VersionedIntervalTimeline<String, DataSegment>> maybeTimeline =
         segmentManager.getTimeline(ev.getBaseTableDataSource());
     if (maybeTimeline.isEmpty()) {
-      return new ReportTimelineMissingSegmentQueryRunner<>(Lists.newArrayList(specs));
+      return (queryPlus, responseContext) -> {
+        responseContext.addMissingSegments(Lists.newArrayList(specs));
+        return Sequences.empty();
+      };
     }
 
     final QueryRunnerFactory<T, Query<T>> factory = getQueryRunnerFactory(query);
@@ -193,17 +199,15 @@ public class ServerManager implements QuerySegmentWalker
   }
 
   /**
-   * For each {@link SegmentDescriptor}, we try to fetch a {@link DataSegment} from the supplied
-   * {@link VersionedIntervalTimeline} to build a list of {@link DataSegmentAndDescriptor} and then hand off to
-   * {@link #getSegmentReferences(List, SegmentMapFunction, long)} to transform  into {@link SegmentReference}
-   * wrappers. The wrappers contain the {@link SegmentDescriptor} and an {@link Optional<Segment>}, and MUST BE
-   * CLOSED to release the references when processing is complete.
+   * For each {@link SegmentDescriptor}, we try to obtain a {@link DataSegment} from the supplied
+   * {@link VersionedIntervalTimeline} to create a {@link LeafSegmentsBundle} which contains the partitioned segments
+   * into 3 groups: those which are already present in the cache, those which can be loaded on demand, and those which
+   * were missing from the {@link VersionedIntervalTimeline}.
    */
-  protected List<SegmentReference> getSegmentReferences(
+  protected LeafSegmentsBundle getSegmentsBundle(
       VersionedIntervalTimeline<String, DataSegment> timeline,
       Iterable<SegmentDescriptor> segments,
-      SegmentMapFunction segmentMapFunction,
-      final long timeout
+      SegmentMapFunction segmentMapFunction
   )
   {
     // first we build a list of DataSegment we need to get references for, paired with the descriptor from the query
@@ -218,27 +222,78 @@ public class ServerManager implements QuerySegmentWalker
       if (chunk != null) {
         segmentsToMap.add(new DataSegmentAndDescriptor(chunk.getObject(), descriptor));
       } else {
-        segmentsToMap.add(new DataSegmentAndDescriptor(null, descriptor));
+        segmentsToMap.add(DataSegmentAndDescriptor.missing(descriptor));
       }
     }
 
-    return getSegmentReferences(segmentsToMap, segmentMapFunction, timeout);
+    return segmentManager.getSegmentsBundle(segmentsToMap, segmentMapFunction);
+  }
+
+  /**
+   * Combines {@link LeafSegmentsBundle#cachedSegments} with {@link LeafSegmentsBundle#loadableSegments}, loading the
+   * latter set into the cache
+   */
+  protected ArrayList<SegmentReference> getOrLoadBundleSegments(
+      QueryPlus<?> queryPlus,
+      LeafSegmentsBundle segmentsBundle,
+      SegmentMapFunction segmentMapFunction
+  )
+  {
+    final ArrayList<SegmentReference> segmentReferences = new ArrayList<>(
+        segmentsBundle.getCachedSegments().size() + segmentsBundle.getLoadableSegments().size()
+    );
+    segmentReferences.addAll(segmentsBundle.getCachedSegments());
+
+    // loadable segments are skipped for segment metadata queries to not cause disk churn from pulling them all down,
+    // so we use placeholders instead. this is kind of gross, but otherwise we're going to be loading weak assignments
+    // more or less as soon as they are assigned instead of on demand at query time due to the broker issuing metadata
+    // queries to build the SQL schema
+    if (queryPlus.getQuery() instanceof SegmentMetadataQuery) {
+      for (DataSegmentAndDescriptor segment : segmentsBundle.getLoadableSegments()) {
+        segmentReferences.add(
+            new SegmentReference(
+                segment.getDescriptor(),
+                Optional.of(new VirtualPlaceholderSegment(segment.getDataSegment())),
+                null
+            )
+        );
+      }
+    } else {
+      // load the remaining segments
+      try {
+        final LoadSegmentsResult result = getOrLoadSegmentReferences(
+            segmentsBundle.getLoadableSegments(),
+            segmentMapFunction,
+            queryPlus.getQuery().context().getTimeout()
+        );
+        segmentReferences.addAll(result.getSegmentReferences());
+        if (segmentManager.canLoadSegmentsOnDemand()) {
+          result.reportMetrics(queryPlus.getQueryMetrics());
+        }
+      }
+      catch (Throwable t) {
+        throw CloseableUtils.closeAndWrapInCatch(t, segmentsBundle::closeCachedReferences);
+      }
+    }
+
+    return segmentReferences;
   }
 
   /**
    * Given a list of {@link DataSegmentAndDescriptor}, uses {@link SegmentManager#acquireSegment(DataSegment)} for each
-   * to obtain a 'reference' to segments in the cache (or loaded from deep storage if necessary/supported by the
+   * to obtain a 'reference' to segments in the cache (or load from deep storage if necessary/supported by the
    * storage layer).
    * <p>
    * For each of these segments, we then apply a {@link SegmentMapFunction} to prepare for processing. The returned
    * {@link SegmentReference} MUST BE CLOSED to release the reference.
    */
-  private ArrayList<SegmentReference> getSegmentReferences(
+  protected LoadSegmentsResult getOrLoadSegmentReferences(
       List<DataSegmentAndDescriptor> segmentsToMap,
       SegmentMapFunction segmentMapFunction,
       long timeout
   )
   {
+    final long startLoadTime = System.nanoTime();
     // closer to collect everything that needs cleaned up in the event of failure, if we make it out of this function,
     // closing the segment reference handles everything and it is the callers responsibility
     final Closer safetyNet = Closer.create();
@@ -272,7 +327,7 @@ public class ServerManager implements QuerySegmentWalker
     Throwable failure = null;
 
     // getting the future kicks off any background action, so materialize them all to a list to get things started
-    final List<ListenableFuture<ReferenceCountedObjectProvider<Segment>>> futures = new ArrayList<>(actions.size());
+    final List<ListenableFuture<AcquireSegmentResult>> futures = new ArrayList<>(actions.size());
     for (AcquireSegmentAction acquireSegmentAction : actions) {
       // if we haven't failed yet, keep collecting futures
       if (failure == null) {
@@ -283,7 +338,7 @@ public class ServerManager implements QuerySegmentWalker
           failure = t;
         }
       } else {
-        futures.add(Futures.immediateFuture(Optional::empty));
+        futures.add(Futures.immediateFuture(AcquireSegmentResult.empty()));
       }
     }
 
@@ -299,21 +354,30 @@ public class ServerManager implements QuerySegmentWalker
     }
 
     final ArrayList<SegmentReference> segmentReferences = new ArrayList<>(actions.size());
+    long totalSegmentsLoadTime = 0;
+    long totalSegmentsLoadWaitTime = 0;
+    long maxSegmentLoadTime = 0;
+    long maxSegmentWaitTime = 0;
+    long bytesLoaded = 0;
     boolean timedOut = false;
     boolean interrupted = false;
     for (int i = 0; i < actions.size(); i++) {
       try {
         final DataSegmentAndDescriptor segmentAndDescriptor = segmentsToMap.get(i);
         final AcquireSegmentAction action = actions.get(i);
-        final ListenableFuture<ReferenceCountedObjectProvider<Segment>> future = futures.get(i);
-        final ReferenceCountedObjectProvider<Segment> referenceProvider =
-            future.get(timeoutAt - System.currentTimeMillis(), TimeUnit.MILLISECONDS);
-        if (referenceProvider == null) {
+        final ListenableFuture<AcquireSegmentResult> future = futures.get(i);
+        final AcquireSegmentResult result = future.get(timeoutAt - System.currentTimeMillis(), TimeUnit.MILLISECONDS);
+        if (result == null) {
           segmentReferences.add(
               new SegmentReference(segmentAndDescriptor.getDescriptor(), Optional.empty(), action)
           );
         } else {
-          final Optional<Segment> segment = referenceProvider.acquireReference();
+          totalSegmentsLoadTime += result.getLoadTimeNanos();
+          totalSegmentsLoadWaitTime += result.getWaitTimeNanos();
+          maxSegmentLoadTime = Math.max(maxSegmentLoadTime, result.getLoadTimeNanos());
+          maxSegmentWaitTime = Math.max(maxSegmentWaitTime, result.getWaitTimeNanos());
+          bytesLoaded += result.getLoadSizeBytes();
+          final Optional<Segment> segment = result.getReferenceProvider().acquireReference();
           try {
             final Optional<Segment> mappedSegment = segmentMapFunction.apply(segment).map(safetyNet::register);
             segmentReferences.add(
@@ -368,84 +432,29 @@ public class ServerManager implements QuerySegmentWalker
       }
       throw CloseableUtils.closeInCatch(toThrow, safetyNet);
     }
-    return segmentReferences;
-  }
-
-
-  /**
-   * Special handling for {@link SegmentMetadataQuery}, to force it to only use segments that are already stored in the
-   * cache as strong references, using empty placeholder segments with a __time column and 0 rows for all segments that
-   * are in the timeline but are missing from the cache (e.g. weak references)
-   */
-  private List<SegmentReference> getSegmentMetadataSegmentReferences(
-      VersionedIntervalTimeline<String, DataSegment> timeline,
-      Iterable<SegmentDescriptor> segments,
-      SegmentMapFunction segmentMapFn
-  )
-  {
-    // materialize to list to acquire all of the references
-    List<SegmentReference> segmentReferences = new ArrayList<>();
-    for (SegmentDescriptor descriptor : segments) {
-      final PartitionChunk<DataSegment> chunk = timeline.findChunk(
-          descriptor.getInterval(),
-          descriptor.getVersion(),
-          descriptor.getPartitionNumber()
-      );
-      if (chunk == null) {
-        segmentReferences.add(SegmentReference.missing(descriptor));
-      } else {
-        final DataSegment dataSegment = chunk.getObject();
-        final Optional<Segment> theSegment = segmentMapFn.apply(segmentManager.acquireCachedSegment(dataSegment));
-        if (theSegment.isPresent()) {
-          segmentReferences.add(
-              new SegmentReference(
-                  descriptor,
-                  theSegment,
-                  null
-              )
-          );
-        } else {
-          // make a stub to run the segment metadata query instead of being a 'missing' segment
-          segmentReferences.add(
-              new SegmentReference(
-                  descriptor,
-                  Optional.of(new VirtualPlaceholderSegment(dataSegment)),
-                  null
-              )
-          );
-        }
-      }
-    }
-    return segmentReferences;
+    final long loadTime = System.nanoTime() - startLoadTime;
+    final long count = actions.size();
+    return new LoadSegmentsResult(
+        segmentReferences,
+        loadTime,
+        maxSegmentLoadTime,
+        count == 0 ? 0 : totalSegmentsLoadTime / count,
+        maxSegmentWaitTime,
+        count == 0 ? 0 : totalSegmentsLoadWaitTime / count,
+        bytesLoaded,
+        count
+    );
   }
 
   protected <T> FunctionalIterable<QueryRunner<T>> getQueryRunnersForSegments(
-      final VersionedIntervalTimeline<String, DataSegment> timeline,
-      final Iterable<SegmentDescriptor> specs,
       final Query<T> query,
       final QueryRunnerFactory<T, Query<T>> factory,
       final QueryToolChest<T, Query<T>> toolChest,
-      final SegmentMapFunction segmentMapFn,
+      final List<SegmentReference> segmentReferences,
       final AtomicLong cpuTimeAccumulator,
-      final Optional<byte[]> cacheKeyPrefix,
-      final Closer closer
+      final Optional<byte[]> cacheKeyPrefix
   )
   {
-    final List<SegmentReference> segmentReferences;
-    // this is kind of gross, but otherwise we're going to be loading weak assignments more or less as soon as they
-    // are assigned instead of on demand at query time
-    if (query instanceof SegmentMetadataQuery) {
-      segmentReferences = getSegmentMetadataSegmentReferences(timeline, specs, segmentMapFn);
-    } else {
-      segmentReferences = getSegmentReferences(
-          timeline,
-          specs,
-          segmentMapFn,
-          query.context().getTimeout()
-      );
-    }
-    closer.registerAll(segmentReferences);
-
     return FunctionalIterable
         .create(segmentReferences)
         .transform(
@@ -460,8 +469,8 @@ public class ServerManager implements QuerySegmentWalker
                                 cpuTimeAccumulator,
                                 cacheKeyPrefix
                             )
-                   ).orElse(
-                       new ReportTimelineMissingSegmentQueryRunner<>(ref.getSegmentDescriptor())
+                   ).orElseThrow(
+                       () -> DruidException.defensive("Unexpected missing segment[%s]", ref.getSegmentDescriptor())
                    )
         );
   }
@@ -545,8 +554,7 @@ public class ServerManager implements QuerySegmentWalker
     );
   }
 
-
-  private <T> QueryRunnerFactory<T, Query<T>> getQueryRunnerFactory(Query<T> query)
+  protected <T> QueryRunnerFactory<T, Query<T>> getQueryRunnerFactory(Query<T> query)
   {
     final DataSource dataSourceFromQuery = query.getDataSource();
     final QueryRunnerFactory<T, Query<T>> factory = conglomerate.findFactory(query);
@@ -562,7 +570,7 @@ public class ServerManager implements QuerySegmentWalker
     return factory;
   }
 
-  private static <T> QueryToolChest<T, Query<T>> getQueryToolChest(Query<T> query, QueryRunnerFactory<T, Query<T>> factory)
+  protected static <T> QueryToolChest<T, Query<T>> getQueryToolChest(Query<T> query, QueryRunnerFactory<T, Query<T>> factory)
   {
     final DataSource dataSourceFromQuery = query.getDataSource();
     final QueryToolChest<T, Query<T>> toolChest = factory.getToolchest();
@@ -580,7 +588,7 @@ public class ServerManager implements QuerySegmentWalker
    * which are registered with a closer as they are acquired, and then released in the baggage of merged result
    * {@link Sequence}
    */
-  public final class ResourceManagingQueryRunner<T> implements QueryRunner<T>
+  public class ResourceManagingQueryRunner<T> implements QueryRunner<T>
   {
     private final VersionedIntervalTimeline<String, DataSegment> timeline;
     private final QueryRunnerFactory<T, Query<T>> factory;
@@ -603,13 +611,12 @@ public class ServerManager implements QuerySegmentWalker
       this.specs = specs;
     }
 
-
     @Override
     public Sequence<T> run(QueryPlus<T> queryPlus, ResponseContext responseContext)
     {
       queryPlus = queryPlus.withQuery(
           ResourceIdPopulatingQueryRunner.populateResourceId(queryPlus.getQuery())
-      );
+      ).withQueryMetrics(toolChest);
       final Query<T> query = queryPlus.getQuery();
       final AtomicLong cpuTimeAccumulator = new AtomicLong(0L);
       final SegmentMapFunction segmentMapFn = JvmUtils.safeAccumulateThreadCpuTime(
@@ -623,16 +630,24 @@ public class ServerManager implements QuerySegmentWalker
       // closer to track all used resources
       final Closer closer = Closer.create();
       try {
+        final LeafSegmentsBundle segmentsBundle = getLeafSegmentsBundle(query, segmentMapFn);
+
+        responseContext.addMissingSegments(segmentsBundle.getMissingSegments());
+
+        final List<SegmentReference> segmentReferences = getOrLoadBundleSegments(
+            queryPlus,
+            segmentsBundle,
+            segmentMapFn
+        );
+        closer.registerAll(segmentReferences);
+
         final FunctionalIterable<QueryRunner<T>> queryRunners = getQueryRunnersForSegments(
-            timeline,
-            specs,
             query,
             factory,
             toolChest,
-            segmentMapFn,
+            segmentReferences,
             cpuTimeAccumulator,
-            cacheKeyPrefix,
-            closer
+            cacheKeyPrefix
         );
         final QueryRunner<T> queryRunner = CPUTimeMetricQueryRunner.safeBuild(
             new FinalizeResultsQueryRunner<>(
@@ -650,5 +665,63 @@ public class ServerManager implements QuerySegmentWalker
         throw CloseableUtils.closeAndWrapInCatch(t, closer);
       }
     }
+
+
+    @VisibleForTesting
+    protected LeafSegmentsBundle getLeafSegmentsBundle(Query<T> query, SegmentMapFunction segmentMapFunction)
+    {
+      return ServerManager.this.getSegmentsBundle(timeline, specs, segmentMapFunction);
+    }
+  }
+
+  public static class LoadSegmentsResult
+  {
+    private final ArrayList<SegmentReference> segmentReferences;
+    private final long wallTimeNanos;
+    private final long maxTimeNanos;
+    private final long avgTimeNanos;
+    private final long maxWaitNanos;
+    private final long avgWaitNanos;
+    private final long totalBytes;
+    private final long count;
+
+    public LoadSegmentsResult(
+        ArrayList<SegmentReference> segmentReferences,
+        long wallTimeNanos,
+        long maxTimeNanos,
+        long avgTimeNanos,
+        long maxWaitNanos,
+        long avgWaitNanos,
+        long totalBytes,
+        long count
+    )
+    {
+      this.segmentReferences = segmentReferences;
+      this.wallTimeNanos = wallTimeNanos;
+      this.maxTimeNanos = maxTimeNanos;
+      this.avgTimeNanos = avgTimeNanos;
+      this.maxWaitNanos = maxWaitNanos;
+      this.avgWaitNanos = avgWaitNanos;
+      this.totalBytes = totalBytes;
+      this.count = count;
+    }
+
+    public List<SegmentReference> getSegmentReferences()
+    {
+      return segmentReferences;
+    }
+
+    public void reportMetrics(@Nullable QueryMetrics<?> queryMetrics)
+    {
+      if (queryMetrics != null) {
+        queryMetrics.reportSegmentOnDemandLoadTime(wallTimeNanos);
+        queryMetrics.reportSegmentOnDemandLoadTimeMax(maxTimeNanos);
+        queryMetrics.reportSegmentOnDemandLoadTimeAvg(avgTimeNanos);
+        queryMetrics.reportSegmentOnDemandLoadWaitTimeMax(maxWaitNanos);
+        queryMetrics.reportSegmentOnDemandLoadWaitTimeAvg(avgWaitNanos);
+        queryMetrics.reportSegmentOnDemandLoadBytes(totalBytes);
+        queryMetrics.reportSegmentOnDemandLoadCount(count);
+      }
+    }
   }
 }
