@@ -19,9 +19,7 @@
 
 package org.apache.druid.server.compaction;
 
-import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.commons.lang3.ArrayUtils;
-import org.apache.druid.client.indexing.ClientCompactionTaskGranularitySpec;
 import org.apache.druid.client.indexing.ClientCompactionTaskQueryTuningConfig;
 import org.apache.druid.common.config.Configs;
 import org.apache.druid.data.input.impl.DimensionSchema;
@@ -38,11 +36,17 @@ import org.apache.druid.segment.transform.CompactionTransformSpec;
 import org.apache.druid.server.coordinator.DataSourceCompactionConfig;
 import org.apache.druid.server.coordinator.UserCompactionTaskGranularityConfig;
 import org.apache.druid.timeline.CompactionState;
+import org.apache.druid.timeline.DataSegment;
 import org.apache.druid.utils.CollectionUtils;
+import org.joda.time.Interval;
 
 import javax.annotation.Nullable;
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
+import java.util.Set;
 import java.util.function.Function;
 import java.util.stream.Collectors;
 
@@ -51,7 +55,7 @@ import java.util.stream.Collectors;
  */
 public class CompactionStatus
 {
-  private static final CompactionStatus COMPLETE = new CompactionStatus(State.COMPLETE, null);
+  private static final CompactionStatus COMPLETE = new CompactionStatus(State.COMPLETE, null, null, null);
 
   public enum State
   {
@@ -65,7 +69,6 @@ public class CompactionStatus
    */
   private static final List<Function<Evaluator, CompactionStatus>> CHECKS = Arrays.asList(
       Evaluator::segmentsHaveBeenCompactedAtLeastOnce,
-      Evaluator::allCandidatesHaveSameCompactionState,
       Evaluator::partitionsSpecIsUpToDate,
       Evaluator::indexSpecIsUpToDate,
       Evaluator::segmentGranularityIsUpToDate,
@@ -79,11 +82,20 @@ public class CompactionStatus
 
   private final State state;
   private final String reason;
+  private final CompactionStatistics compactedStats;
+  private final CompactionStatistics uncompactedStats;
 
-  private CompactionStatus(State state, String reason)
+  private CompactionStatus(
+      State state,
+      String reason,
+      CompactionStatistics compactedStats,
+      CompactionStatistics uncompactedStats
+  )
   {
     this.state = state;
     this.reason = reason;
+    this.compactedStats = compactedStats;
+    this.uncompactedStats = uncompactedStats;
   }
 
   public boolean isComplete()
@@ -106,21 +118,53 @@ public class CompactionStatus
     return state;
   }
 
+  public CompactionStatistics getCompactedStats()
+  {
+    return compactedStats;
+  }
+
+  public CompactionStatistics getUncompactedStats()
+  {
+    return uncompactedStats;
+  }
+
   @Override
   public String toString()
   {
     return "CompactionStatus{" +
            "state=" + state +
            ", reason=" + reason +
+           ", compactedStats=" + compactedStats +
+           ", uncompactedStats=" + uncompactedStats +
            '}';
   }
 
-  private static CompactionStatus incomplete(String reasonFormat, Object... args)
+  public static CompactionStatus pending(String reasonFormat, Object... args)
   {
-    return new CompactionStatus(State.PENDING, StringUtils.format(reasonFormat, args));
+    return new CompactionStatus(State.PENDING, StringUtils.format(reasonFormat, args), null, null);
   }
 
-  private static <T> CompactionStatus completeIfEqual(
+  public static CompactionStatus pending(
+      CompactionStatistics compactedStats,
+      CompactionStatistics uncompactedStats,
+      String reasonFormat,
+      Object... args
+  )
+  {
+    return new CompactionStatus(
+        State.PENDING,
+        StringUtils.format(reasonFormat, args),
+        compactedStats,
+        uncompactedStats
+    );
+  }
+
+  /**
+   * Computes compaction status for the given field. The status is assumed to be
+   * COMPLETE (i.e. no further compaction is required) if the configured value
+   * of the field is null or equal to the current value.
+   */
+  private static <T> CompactionStatus completeIfNullOrEqual(
       String field,
       T configured,
       T current,
@@ -141,7 +185,7 @@ public class CompactionStatus
       Function<T, String> stringFunction
   )
   {
-    return CompactionStatus.incomplete(
+    return CompactionStatus.pending(
         "'%s' mismatch: required[%s], current[%s]",
         field,
         target == null ? null : stringFunction.apply(target),
@@ -187,40 +231,44 @@ public class CompactionStatus
     }
   }
 
-  static CompactionStatus skipped(String reasonFormat, Object... args)
+  public static CompactionStatus skipped(String reasonFormat, Object... args)
   {
-    return new CompactionStatus(State.SKIPPED, StringUtils.format(reasonFormat, args));
+    return new CompactionStatus(State.SKIPPED, StringUtils.format(reasonFormat, args), null, null);
   }
 
-  static CompactionStatus running(String reasonForCompaction)
+  public static CompactionStatus running(String message)
   {
-    return new CompactionStatus(State.RUNNING, reasonForCompaction);
+    return new CompactionStatus(State.RUNNING, message, null, null);
   }
 
   /**
    * Determines the CompactionStatus of the given candidate segments by evaluating
    * the {@link #CHECKS} one by one. If any check returns an incomplete status,
-   * further checks are not performed and the incomplete status is returned.
+   * further checks are still performed to determine the number of uncompacted
+   * segments but only the first incomplete status is returned.
    */
   static CompactionStatus compute(
       CompactionCandidate candidateSegments,
-      DataSourceCompactionConfig config,
-      ObjectMapper objectMapper
+      DataSourceCompactionConfig config
   )
   {
-    final Evaluator evaluator = new Evaluator(candidateSegments, config, objectMapper);
-    return CHECKS.stream()
-                 .map(f -> f.apply(evaluator))
-                 .filter(status -> !status.isComplete())
-                 .findFirst().orElse(COMPLETE);
+    return new Evaluator(candidateSegments, config).evaluate();
   }
 
+  @Nullable
   static PartitionsSpec findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig tuningConfig)
   {
     final PartitionsSpec partitionsSpecFromTuningConfig = tuningConfig.getPartitionsSpec();
     if (partitionsSpecFromTuningConfig == null) {
-      final long maxTotalRows = Configs.valueOrDefault(tuningConfig.getMaxTotalRows(), Long.MAX_VALUE);
-      return new DynamicPartitionsSpec(tuningConfig.getMaxRowsPerSegment(), maxTotalRows);
+      final Long maxTotalRows = tuningConfig.getMaxTotalRows();
+      final Integer maxRowsPerSegment = tuningConfig.getMaxRowsPerSegment();
+
+      if (maxTotalRows == null && maxRowsPerSegment == null) {
+        // If not specified, return null so that partitionsSpec is not compared
+        return null;
+      } else {
+        return new DynamicPartitionsSpec(maxRowsPerSegment, maxTotalRows);
+      }
     } else if (partitionsSpecFromTuningConfig instanceof DynamicPartitionsSpec) {
       return new DynamicPartitionsSpec(
           partitionsSpecFromTuningConfig.getMaxRowsPerSegment(),
@@ -272,68 +320,137 @@ public class CompactionStatus
   }
 
   /**
-   * Evaluates {@link #CHECKS} to determine the compaction status.
+   * Evaluates {@link #CHECKS} to determine the compaction status of a
+   * {@link CompactionCandidate}.
    */
   private static class Evaluator
   {
-    private final ObjectMapper objectMapper;
     private final DataSourceCompactionConfig compactionConfig;
     private final CompactionCandidate candidateSegments;
-    private final CompactionState lastCompactionState;
     private final ClientCompactionTaskQueryTuningConfig tuningConfig;
-    private final ClientCompactionTaskGranularitySpec existingGranularitySpec;
     private final UserCompactionTaskGranularityConfig configuredGranularitySpec;
 
+    private final List<DataSegment> uncompactedSegments = new ArrayList<>();
+    private final Map<CompactionState, List<DataSegment>> unknownStateToSegments = new HashMap<>();
+
     private Evaluator(
         CompactionCandidate candidateSegments,
-        DataSourceCompactionConfig compactionConfig,
-        ObjectMapper objectMapper
+        DataSourceCompactionConfig compactionConfig
     )
     {
       this.candidateSegments = candidateSegments;
-      this.objectMapper = objectMapper;
-      this.lastCompactionState = candidateSegments.getSegments().get(0).getLastCompactionState();
       this.compactionConfig = compactionConfig;
       this.tuningConfig = ClientCompactionTaskQueryTuningConfig.from(compactionConfig);
       this.configuredGranularitySpec = compactionConfig.getGranularitySpec();
-      if (lastCompactionState == null) {
-        this.existingGranularitySpec = null;
+    }
+
+    private CompactionStatus evaluate()
+    {
+      final CompactionStatus inputBytesCheck = inputBytesAreWithinLimit();
+      if (inputBytesCheck.isSkipped()) {
+        return inputBytesCheck;
+      }
+
+      final List<String> reasonsForCompaction =
+          CHECKS.stream()
+                .map(f -> f.apply(this))
+                .filter(status -> !status.isComplete())
+                .map(CompactionStatus::getReason)
+                .collect(Collectors.toList());
+
+      // Consider segments which have passed all checks to be compacted
+      final List<DataSegment> compactedSegments = unknownStateToSegments
+          .values()
+          .stream()
+          .flatMap(List::stream)
+          .collect(Collectors.toList());
+
+      if (reasonsForCompaction.isEmpty()) {
+        return COMPLETE;
       } else {
-        this.existingGranularitySpec = convertIfNotNull(
-            lastCompactionState.getGranularitySpec(),
-            ClientCompactionTaskGranularitySpec.class
+        return CompactionStatus.pending(
+            createStats(compactedSegments),
+            createStats(uncompactedSegments),
+            reasonsForCompaction.get(0)
         );
       }
     }
 
     private CompactionStatus segmentsHaveBeenCompactedAtLeastOnce()
     {
-      if (lastCompactionState == null) {
-        return CompactionStatus.incomplete("not compacted yet");
-      } else {
-        return COMPLETE;
+      // Identify the compaction states of all the segments
+      for (DataSegment segment : candidateSegments.getSegments()) {
+        final CompactionState segmentState = segment.getLastCompactionState();
+        if (segmentState == null) {
+          uncompactedSegments.add(segment);
+        } else {
+          unknownStateToSegments.computeIfAbsent(segmentState, s -> new ArrayList<>()).add(segment);
+        }
       }
-    }
 
-    private CompactionStatus allCandidatesHaveSameCompactionState()
-    {
-      final boolean allHaveSameCompactionState = candidateSegments.getSegments().stream().allMatch(
-          segment -> lastCompactionState.equals(segment.getLastCompactionState())
-      );
-      if (allHaveSameCompactionState) {
+      if (uncompactedSegments.isEmpty()) {
         return COMPLETE;
       } else {
-        return CompactionStatus.incomplete("segments have different last compaction states");
+        return CompactionStatus.pending("not compacted yet");
       }
     }
 
     private CompactionStatus partitionsSpecIsUpToDate()
+    {
+      return evaluateForAllCompactionStates(this::partitionsSpecIsUpToDate);
+    }
+
+    private CompactionStatus indexSpecIsUpToDate()
+    {
+      return evaluateForAllCompactionStates(this::indexSpecIsUpToDate);
+    }
+
+    private CompactionStatus projectionsAreUpToDate()
+    {
+      return evaluateForAllCompactionStates(this::projectionsAreUpToDate);
+    }
+
+    private CompactionStatus segmentGranularityIsUpToDate()
+    {
+      return evaluateForAllCompactionStates(this::segmentGranularityIsUpToDate);
+    }
+
+    private CompactionStatus rollupIsUpToDate()
+    {
+      return evaluateForAllCompactionStates(this::rollupIsUpToDate);
+    }
+
+    private CompactionStatus queryGranularityIsUpToDate()
+    {
+      return evaluateForAllCompactionStates(this::queryGranularityIsUpToDate);
+    }
+
+    private CompactionStatus dimensionsSpecIsUpToDate()
+    {
+      return evaluateForAllCompactionStates(this::dimensionsSpecIsUpToDate);
+    }
+
+    private CompactionStatus metricsSpecIsUpToDate()
+    {
+      return evaluateForAllCompactionStates(this::metricsSpecIsUpToDate);
+    }
+
+    private CompactionStatus transformSpecFilterIsUpToDate()
+    {
+      return evaluateForAllCompactionStates(this::transformSpecFilterIsUpToDate);
+    }
+
+    private CompactionStatus partitionsSpecIsUpToDate(CompactionState lastCompactionState)
     {
       PartitionsSpec existingPartionsSpec = lastCompactionState.getPartitionsSpec();
       if (existingPartionsSpec instanceof DimensionRangePartitionsSpec) {
         existingPartionsSpec = getEffectiveRangePartitionsSpec((DimensionRangePartitionsSpec) existingPartionsSpec);
+      } else if (existingPartionsSpec instanceof DynamicPartitionsSpec) {
+        existingPartionsSpec = new DynamicPartitionsSpec(
+            existingPartionsSpec.getMaxRowsPerSegment(),
+            ((DynamicPartitionsSpec) existingPartionsSpec).getMaxTotalRowsOr(Long.MAX_VALUE));
       }
-      return CompactionStatus.completeIfEqual(
+      return CompactionStatus.completeIfNullOrEqual(
           "partitionsSpec",
           findPartitionsSpecFromConfig(tuningConfig),
           existingPartionsSpec,
@@ -341,19 +458,19 @@ public class CompactionStatus
       );
     }
 
-    private CompactionStatus indexSpecIsUpToDate()
+    private CompactionStatus indexSpecIsUpToDate(CompactionState lastCompactionState)
     {
-      return CompactionStatus.completeIfEqual(
+      return CompactionStatus.completeIfNullOrEqual(
           "indexSpec",
           Configs.valueOrDefault(tuningConfig.getIndexSpec(), IndexSpec.getDefault()).getEffectiveSpec(),
-          objectMapper.convertValue(lastCompactionState.getIndexSpec(), IndexSpec.class).getEffectiveSpec(),
+          lastCompactionState.getIndexSpec().getEffectiveSpec(),
           String::valueOf
       );
     }
 
-    private CompactionStatus projectionsAreUpToDate()
+    private CompactionStatus projectionsAreUpToDate(CompactionState lastCompactionState)
     {
-      return CompactionStatus.completeIfEqual(
+      return CompactionStatus.completeIfNullOrEqual(
           "projections",
           compactionConfig.getProjections(),
           lastCompactionState.getProjections(),
@@ -361,7 +478,20 @@ public class CompactionStatus
       );
     }
 
-    private CompactionStatus segmentGranularityIsUpToDate()
+    private CompactionStatus inputBytesAreWithinLimit()
+    {
+      final long inputSegmentSize = compactionConfig.getInputSegmentSizeBytes();
+      if (candidateSegments.getTotalBytes() > inputSegmentSize) {
+        return CompactionStatus.skipped(
+            "'inputSegmentSize' exceeded: Total segment size[%d] is larger than allowed inputSegmentSize[%d]",
+            candidateSegments.getTotalBytes(), inputSegmentSize
+        );
+      } else {
+        return COMPLETE;
+      }
+    }
+
+    private CompactionStatus segmentGranularityIsUpToDate(CompactionState lastCompactionState)
     {
       if (configuredGranularitySpec == null
           || configuredGranularitySpec.getSegmentGranularity() == null) {
@@ -369,6 +499,7 @@ public class CompactionStatus
       }
 
       final Granularity configuredSegmentGranularity = configuredGranularitySpec.getSegmentGranularity();
+      final UserCompactionTaskGranularityConfig existingGranularitySpec = getGranularitySpec(lastCompactionState);
       final Granularity existingSegmentGranularity
           = existingGranularitySpec == null ? null : existingGranularitySpec.getSegmentGranularity();
 
@@ -377,11 +508,12 @@ public class CompactionStatus
       } else if (existingSegmentGranularity == null) {
         // Candidate segments were compacted without segment granularity specified
         // Check if the segments already have the desired segment granularity
-        boolean needsCompaction = candidateSegments.getSegments().stream().anyMatch(
+        final List<DataSegment> segmentsForState = unknownStateToSegments.get(lastCompactionState);
+        boolean needsCompaction = segmentsForState.stream().anyMatch(
             segment -> !configuredSegmentGranularity.isAligned(segment.getInterval())
         );
         if (needsCompaction) {
-          return CompactionStatus.incomplete(
+          return CompactionStatus.pending(
               "segmentGranularity: segments do not align with target[%s]",
               asString(configuredSegmentGranularity)
           );
@@ -398,12 +530,14 @@ public class CompactionStatus
       return COMPLETE;
     }
 
-    private CompactionStatus rollupIsUpToDate()
+    private CompactionStatus rollupIsUpToDate(CompactionState lastCompactionState)
     {
       if (configuredGranularitySpec == null) {
         return COMPLETE;
       } else {
-        return CompactionStatus.completeIfEqual(
+        final UserCompactionTaskGranularityConfig existingGranularitySpec
+            = getGranularitySpec(lastCompactionState);
+        return CompactionStatus.completeIfNullOrEqual(
             "rollup",
             configuredGranularitySpec.isRollup(),
             existingGranularitySpec == null ? null : existingGranularitySpec.isRollup(),
@@ -412,12 +546,14 @@ public class CompactionStatus
       }
     }
 
-    private CompactionStatus queryGranularityIsUpToDate()
+    private CompactionStatus queryGranularityIsUpToDate(CompactionState lastCompactionState)
     {
       if (configuredGranularitySpec == null) {
         return COMPLETE;
       } else {
-        return CompactionStatus.completeIfEqual(
+        final UserCompactionTaskGranularityConfig existingGranularitySpec
+            = getGranularitySpec(lastCompactionState);
+        return CompactionStatus.completeIfNullOrEqual(
             "queryGranularity",
             configuredGranularitySpec.getQueryGranularity(),
             existingGranularitySpec == null ? null : existingGranularitySpec.getQueryGranularity(),
@@ -431,7 +567,7 @@ public class CompactionStatus
      * which can create a mismatch between expected and actual order of dimensions. Partition dimensions are separately
      * covered in {@link Evaluator#partitionsSpecIsUpToDate()} check.
      */
-    private CompactionStatus dimensionsSpecIsUpToDate()
+    private CompactionStatus dimensionsSpecIsUpToDate(CompactionState lastCompactionState)
     {
       if (compactionConfig.getDimensionsSpec() == null) {
         return COMPLETE;
@@ -450,7 +586,7 @@ public class CompactionStatus
             ? IndexSpec.getDefault()
             : compactionConfig.getTuningConfig().getIndexSpec()
         );
-        return CompactionStatus.completeIfEqual(
+        return CompactionStatus.completeIfNullOrEqual(
             "dimensionsSpec",
             configuredDimensions,
             existingDimensions,
@@ -459,7 +595,7 @@ public class CompactionStatus
       }
     }
 
-    private CompactionStatus metricsSpecIsUpToDate()
+    private CompactionStatus metricsSpecIsUpToDate(CompactionState lastCompactionState)
     {
       final AggregatorFactory[] configuredMetricsSpec = compactionConfig.getMetricsSpec();
       if (ArrayUtils.isEmpty(configuredMetricsSpec)) {
@@ -483,17 +619,14 @@ public class CompactionStatus
       }
     }
 
-    private CompactionStatus transformSpecFilterIsUpToDate()
+    private CompactionStatus transformSpecFilterIsUpToDate(CompactionState lastCompactionState)
     {
       if (compactionConfig.getTransformSpec() == null) {
         return COMPLETE;
       }
 
-      CompactionTransformSpec existingTransformSpec = convertIfNotNull(
-          lastCompactionState.getTransformSpec(),
-          CompactionTransformSpec.class
-      );
-      return CompactionStatus.completeIfEqual(
+      CompactionTransformSpec existingTransformSpec = lastCompactionState.getTransformSpec();
+      return CompactionStatus.completeIfNullOrEqual(
           "transformSpec filter",
           compactionConfig.getTransformSpec().getFilter(),
           existingTransformSpec == null ? null : existingTransformSpec.getFilter(),
@@ -501,14 +634,44 @@ public class CompactionStatus
       );
     }
 
-    @Nullable
-    private <T> T convertIfNotNull(Object object, Class<T> clazz)
+    /**
+     * Evaluates the given check for each entry in the {@link #unknownStateToSegments}.
+     * If any entry fails the given check by returning a status which is not
+     * COMPLETE, all the segments with that state are moved to {@link #uncompactedSegments}.
+     *
+     * @return The first status which is not COMPLETE.
+     */
+    private CompactionStatus evaluateForAllCompactionStates(
+        Function<CompactionState, CompactionStatus> check
+    )
     {
-      if (object == null) {
-        return null;
-      } else {
-        return objectMapper.convertValue(object, clazz);
+      CompactionStatus firstIncompleteStatus = null;
+      for (CompactionState state : List.copyOf(unknownStateToSegments.keySet())) {
+        final CompactionStatus status = check.apply(state);
+        if (!status.isComplete()) {
+          uncompactedSegments.addAll(unknownStateToSegments.remove(state));
+          if (firstIncompleteStatus == null) {
+            firstIncompleteStatus = status;
+          }
+        }
       }
+
+      return firstIncompleteStatus == null ? COMPLETE : firstIncompleteStatus;
+    }
+
+    private static UserCompactionTaskGranularityConfig getGranularitySpec(
+        CompactionState compactionState
+    )
+    {
+      return UserCompactionTaskGranularityConfig.from(compactionState.getGranularitySpec());
+    }
+
+    private static CompactionStatistics createStats(List<DataSegment> segments)
+    {
+      final Set<Interval> segmentIntervals =
+          segments.stream().map(DataSegment::getInterval).collect(Collectors.toSet());
+      final long totalBytes = segments.stream().mapToLong(DataSegment::getSize).sum();
+      return CompactionStatistics.create(totalBytes, segments.size(), segmentIntervals.size());
     }
   }
 }
