@@ -20,7 +20,9 @@
 package org.apache.druid.server.compaction;
 
 import com.google.common.annotations.VisibleForTesting;
+import com.google.common.base.Function;
 import com.google.common.base.Preconditions;
+import com.google.common.collect.Iterators;
 import com.google.common.collect.Lists;
 import org.apache.druid.java.util.common.DateTimes;
 import org.apache.druid.java.util.common.Intervals;
@@ -33,6 +35,7 @@ import org.apache.druid.timeline.DataSegment;
 import org.apache.druid.timeline.Partitions;
 import org.apache.druid.timeline.SegmentTimeline;
 import org.apache.druid.timeline.TimelineObjectHolder;
+import org.apache.druid.timeline.VersionedIntervalTimeline;
 import org.apache.druid.timeline.partition.NumberedPartitionChunk;
 import org.apache.druid.timeline.partition.NumberedShardSpec;
 import org.apache.druid.timeline.partition.PartitionChunk;
@@ -65,8 +68,6 @@ public class DataSourceCompactibleSegmentIterator implements CompactionSegmentIt
 
   private final String dataSource;
   private final DataSourceCompactionConfig config;
-  private final CompactionStatusTracker statusTracker;
-  private final CompactionCandidateSearchPolicy searchPolicy;
 
   private final List<CompactionCandidate> compactedSegments = new ArrayList<>();
   private final List<CompactionCandidate> skippedSegments = new ArrayList<>();
@@ -83,14 +84,11 @@ public class DataSourceCompactibleSegmentIterator implements CompactionSegmentIt
       DataSourceCompactionConfig config,
       SegmentTimeline timeline,
       List<Interval> skipIntervals,
-      CompactionCandidateSearchPolicy searchPolicy,
-      CompactionStatusTracker statusTracker
+      CompactionCandidateSearchPolicy searchPolicy
   )
   {
-    this.statusTracker = statusTracker;
     this.config = config;
     this.dataSource = config.getDataSource();
-    this.searchPolicy = searchPolicy;
     this.queue = new PriorityQueue<>(searchPolicy::compareCandidates);
 
     populateQueue(timeline, skipIntervals);
@@ -117,11 +115,12 @@ public class DataSourceCompactibleSegmentIterator implements CompactionSegmentIt
             }
           }
           if (!partialEternitySegments.isEmpty()) {
-            CompactionCandidate candidatesWithStatus = CompactionCandidate.from(partialEternitySegments).withCurrentStatus(
-                CompactionStatus.skipped("Segments have partial-eternity intervals")
-            );
+            // Do not use the target segment granularity in the CompactionCandidate
+            // as Granularities.getIterable() will cause OOM due to the above issue
+            CompactionCandidate candidatesWithStatus = CompactionCandidate
+                .from(partialEternitySegments, null)
+                .withCurrentStatus(CompactionStatus.skipped("Segments have partial-eternity intervals"));
             skippedSegments.add(candidatesWithStatus);
-            statusTracker.onCompactionStatusComputed(candidatesWithStatus, config);
             return;
           }
 
@@ -141,18 +140,29 @@ public class DataSourceCompactibleSegmentIterator implements CompactionSegmentIt
           final String temporaryVersion = DateTimes.nowUtc().toString();
           for (Map.Entry<Interval, Set<DataSegment>> partitionsPerInterval : intervalToPartitionMap.entrySet()) {
             Interval interval = partitionsPerInterval.getKey();
-            int partitionNum = 0;
             Set<DataSegment> segmentSet = partitionsPerInterval.getValue();
             int partitions = segmentSet.size();
-            for (DataSegment segment : segmentSet) {
-              DataSegment segmentsForCompact = segment.withShardSpec(new NumberedShardSpec(partitionNum, partitions));
-              timelineWithConfiguredSegmentGranularity.add(
-                  interval,
-                  temporaryVersion,
-                  NumberedPartitionChunk.make(partitionNum, partitions, segmentsForCompact)
-              );
-              partitionNum += 1;
-            }
+            timelineWithConfiguredSegmentGranularity.addAll(
+                Iterators.transform(
+                    segmentSet.iterator(),
+                    new Function<>()
+                    {
+                      int partitionNum = 0;
+
+                      @Override
+                      public VersionedIntervalTimeline.PartitionChunkEntry<String, DataSegment> apply(DataSegment segment)
+                      {
+                        final DataSegment segmentForCompact =
+                            segment.withShardSpec(new NumberedShardSpec(partitionNum, partitions));
+                        return new VersionedIntervalTimeline.PartitionChunkEntry<>(
+                            interval,
+                            temporaryVersion,
+                            NumberedPartitionChunk.make(partitionNum++, partitions, segmentForCompact)
+                        );
+                      }
+                    }
+                )
+            );
           }
           // PartitionHolder can only holds chunks of one partition space
           // However, partition in the new timeline (timelineWithConfiguredSegmentGranularity) can be hold multiple
@@ -315,11 +325,9 @@ public class DataSourceCompactibleSegmentIterator implements CompactionSegmentIt
         continue;
       }
 
-      final CompactionCandidate candidates = CompactionCandidate.from(segments);
-      final CompactionStatus compactionStatus
-          = statusTracker.computeCompactionStatus(candidates, config, searchPolicy);
+      final CompactionCandidate candidates = CompactionCandidate.from(segments, config.getSegmentGranularity());
+      final CompactionStatus compactionStatus = CompactionStatus.compute(candidates, config);
       final CompactionCandidate candidatesWithStatus = candidates.withCurrentStatus(compactionStatus);
-      statusTracker.onCompactionStatusComputed(candidatesWithStatus, config);
 
       if (compactionStatus.isComplete()) {
         compactedSegments.add(candidatesWithStatus);
@@ -360,10 +368,10 @@ public class DataSourceCompactibleSegmentIterator implements CompactionSegmentIt
           timeline.findNonOvershadowedObjectsInInterval(skipInterval, Partitions.ONLY_COMPLETE)
       );
       if (!CollectionUtils.isNullOrEmpty(segments)) {
-        final CompactionCandidate candidates = CompactionCandidate.from(segments);
+        final CompactionCandidate candidates = CompactionCandidate.from(segments, config.getSegmentGranularity());
 
         final CompactionStatus reason;
-        if (candidates.getUmbrellaInterval().overlaps(latestSkipInterval)) {
+        if (candidates.getCompactionInterval().overlaps(latestSkipInterval)) {
           reason = CompactionStatus.skipped("skip offset from latest[%s]", skipOffset);
         } else {
           reason = CompactionStatus.skipped("interval locked by another task");
@@ -371,7 +379,6 @@ public class DataSourceCompactibleSegmentIterator implements CompactionSegmentIt
 
         final CompactionCandidate candidatesWithStatus = candidates.withCurrentStatus(reason);
         skippedSegments.add(candidatesWithStatus);
-        statusTracker.onCompactionStatusComputed(candidatesWithStatus, config);
       }
     }
 
