@@ -48,14 +48,11 @@ import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.java.util.emitter.service.ServiceEmitter;
 import org.apache.druid.java.util.emitter.service.ServiceMetricEvent;
 import org.apache.druid.java.util.metrics.AbstractMonitor;
-import org.apache.druid.java.util.metrics.MonitorUtils;
 import org.apache.druid.server.DruidNode;
 import org.apache.druid.server.StatusResource;
 import org.apache.druid.server.initialization.ServerConfig;
 import org.apache.druid.server.initialization.TLSServerConfig;
-import org.apache.druid.server.metrics.DataSourceTaskIdHolder;
 import org.apache.druid.server.metrics.MetricsModule;
-import org.apache.druid.server.metrics.MonitorsConfig;
 import org.apache.druid.server.security.CustomCheckX509TrustManager;
 import org.apache.druid.server.security.TLSCertificateChecker;
 import org.eclipse.jetty.server.ConnectionFactory;
@@ -92,7 +89,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
-import java.util.Map;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.atomic.AtomicInteger;
 
@@ -212,7 +208,7 @@ public class JettyServerModule extends JerseyServletModule
     threadPool.setDaemon(true);
     jettyServerThreadPool = threadPool;
 
-    final Server server = new Server(threadPool);
+    final Server server = new Server(jettyServerThreadPool);
 
     // Without this bean set, the default ScheduledExecutorScheduler runs as non-daemon, causing lifecycle hooks to fail
     // to fire on main exit. Related bug: https://github.com/apache/druid/pull/1627
@@ -517,29 +513,26 @@ public class JettyServerModule extends JerseyServletModule
 
   @Provides
   @LazySingleton
-  public JettyMonitor getJettyMonitor(DataSourceTaskIdHolder dataSourceTaskIdHolder)
+  public JettyMonitor getJettyMonitor()
   {
-    return new JettyMonitor(dataSourceTaskIdHolder.getDataSource(), dataSourceTaskIdHolder.getTaskId());
+    return new JettyMonitor();
   }
 
   public static class JettyMonitor extends AbstractMonitor
   {
-    private final Map<String, String[]> dimensions;
-
-    public JettyMonitor(String dataSource, String taskId)
-    {
-      this.dimensions = MonitorsConfig.mapOfDatasourceAndTaskID(dataSource, taskId);
-    }
-
     @Override
     public boolean doMonitor(ServiceEmitter emitter)
     {
       final ServiceMetricEvent.Builder builder = new ServiceMetricEvent.Builder();
-      MonitorUtils.addDimensionsToBuilder(builder, dimensions);
       emitter.emit(builder.setMetric("jetty/numOpenConnections", ACTIVE_CONNECTIONS.get()));
       if (jettyServerThreadPool != null) {
         emitter.emit(builder.setMetric("jetty/threadPool/total", jettyServerThreadPool.getThreads()));
         emitter.emit(builder.setMetric("jetty/threadPool/idle", jettyServerThreadPool.getIdleThreads()));
+
+        emitter.emit(builder.setMetric("jetty/threadPool/ready", jettyServerThreadPool.getReadyThreads()));
+        emitter.emit(builder.setMetric("jetty/threadPool/utilized", jettyServerThreadPool.getUtilizedThreads()));
+        emitter.emit(builder.setMetric("jetty/threadPool/utilizationRate", jettyServerThreadPool.getUtilizationRate()));
+
         emitter.emit(builder.setMetric("jetty/threadPool/isLowOnThreads", jettyServerThreadPool.isLowOnThreads() ? 1 : 0));
         emitter.emit(builder.setMetric("jetty/threadPool/min", jettyServerThreadPool.getMinThreads()));
         emitter.emit(builder.setMetric("jetty/threadPool/max", jettyServerThreadPool.getMaxThreads()));
