@@ -36,7 +36,7 @@ public class AuthTestUtils
       @Override
       public Authorizer getAuthorizer(String name)
       {
-        return new AllowAllAuthorizer();
+        return new AllowAllAuthorizer(null);
       }
     };
   }
