@@ -46,7 +46,7 @@ import java.util.Set;
  */
 public class AuthorizationUtils
 {
-  static final ImmutableSet<String> RESTRICTION_APPLICABLE_RESOURCE_TYPES = ImmutableSet.of(
+  public static final ImmutableSet<String> RESTRICTION_APPLICABLE_RESOURCE_TYPES = ImmutableSet.of(
       ResourceType.DATASOURCE
   );
 
@@ -204,10 +204,21 @@ public class AuthorizationUtils
         return AuthorizationResult.deny(access.getMessage());
       } else {
         resultCache.add(resourceAction);
-        if (resourceAction.getAction().equals(Action.READ)
-            && RESTRICTION_APPLICABLE_RESOURCE_TYPES.contains(resourceAction.getResource().getType())) {
+        if (shouldApplyPolicy(resourceAction.getResource(), resourceAction.getAction())) {
           // For every table read, we check on the policy returned from authorizer and add it to the map.
-          policyFilters.put(resourceAction.getResource().getName(), access.getPolicy());
+          final String resourceName = resourceAction.getResource().getName();
+          final Optional<Policy> prevPolicy =
+              policyFilters.put(resourceName, access.getPolicy());
+          if (prevPolicy != null) {
+            // Shouldn't have two policies for the same resource name, because only tables have policies and
+            // each table should only be processed one time. If it does happen, throw a defensive exception.
+            throw DruidException.defensive(
+                "Cannot have two policies on the same resourceName[%s]: policyA[%s], policyB[%s]",
+                resourceName,
+                prevPolicy,
+                access.getPolicy()
+            );
+          }
         } else if (access.getPolicy().isPresent()) {
           throw DruidException.defensive(
               "Policy should only present when reading a table, but was present for a different kind of resource action [%s]",
@@ -222,6 +233,15 @@ public class AuthorizationUtils
     return AuthorizationResult.allowWithRestriction(policyFilters);
   }
 
+  /**
+   * Whether a {@link Policy} from {@link Access#getPolicy()} should apply to the provided resource-action pair.
+   * As mentioned in the javadoc for {@link Access#getPolicy()}, policies only apply to reading tables.
+   */
+  public static boolean shouldApplyPolicy(Resource resource, Action action)
+  {
+    return Action.READ.equals(action) && RESTRICTION_APPLICABLE_RESOURCE_TYPES.contains(resource.getType());
+  }
+
 
   /**
    * Performs authorization check on a list of resource-actions based on the authentication fields from the request.
