@@ -38,7 +38,7 @@ import org.apache.druid.client.BatchServerInventoryView;
 import org.apache.druid.client.DruidServer;
 import org.apache.druid.client.ServerView;
 import org.apache.druid.curator.PotentiallyGzippedCompressionProvider;
-import org.apache.druid.curator.announcement.Announcer;
+import org.apache.druid.curator.announcement.NodeAnnouncer;
 import org.apache.druid.java.util.common.DateTimes;
 import org.apache.druid.java.util.common.ISE;
 import org.apache.druid.java.util.common.Pair;
@@ -88,7 +88,7 @@ public class BatchServerInventoryViewTest
   private TestingCluster testingCluster;
   private CuratorFramework cf;
   private ObjectMapper jsonMapper;
-  private Announcer announcer;
+  private NodeAnnouncer nodeAnnouncer;
   private BatchDataSegmentAnnouncer segmentAnnouncer;
   private DataSegmentServerAnnouncer serverAnnouncer;
   private Set<DataSegment> testSegments;
@@ -116,11 +116,8 @@ public class BatchServerInventoryViewTest
 
     jsonMapper = TestHelper.makeJsonMapper();
 
-    announcer = new Announcer(
-        cf,
-        Execs.directExecutor()
-    );
-    announcer.start();
+    nodeAnnouncer = new NodeAnnouncer(cf, Execs.directExecutor());
+    nodeAnnouncer.start();
 
     DruidServerMetadata serverMetadata = new DruidServerMetadata(
         "id",
@@ -144,7 +141,7 @@ public class BatchServerInventoryViewTest
     serverAnnouncer = new CuratorDataSegmentServerAnnouncer(
         serverMetadata,
         zkPathsConfig,
-        announcer,
+        nodeAnnouncer,
         jsonMapper
     );
     serverAnnouncer.announce();
@@ -160,7 +157,7 @@ public class BatchServerInventoryViewTest
           }
         },
         zkPathsConfig,
-        announcer,
+        nodeAnnouncer,
         jsonMapper
     );
 
@@ -225,7 +222,7 @@ public class BatchServerInventoryViewTest
     batchServerInventoryView.stop();
     filteredBatchServerInventoryView.stop();
     serverAnnouncer.unannounce();
-    announcer.stop();
+    nodeAnnouncer.stop();
     cf.close();
     testingCluster.stop();
   }
@@ -425,7 +422,10 @@ public class BatchServerInventoryViewTest
   public void testSameTimeZnode() throws Exception
   {
     final int numThreads = INITIAL_SEGMENTS / 10;
-    final ListeningExecutorService executor = MoreExecutors.listeningDecorator(Execs.multiThreaded(numThreads, "BatchServerInventoryViewTest-%d"));
+    final ListeningExecutorService executor = MoreExecutors.listeningDecorator(Execs.multiThreaded(
+        numThreads,
+        "BatchServerInventoryViewTest-%d"
+    ));
 
     segmentAnnouncer.announceSegments(testSegments);
 
@@ -474,7 +474,7 @@ public class BatchServerInventoryViewTest
                           return TEST_BASE_PATH;
                         }
                       },
-                      announcer,
+                      nodeAnnouncer,
                       jsonMapper
                   );
                   List<DataSegment> segments = new ArrayList<>();
