@@ -58,7 +58,7 @@ public class DiscoveryDruidNodeTest
   public void testEquals()
   {
     EqualsVerifier.forClass(DiscoveryDruidNode.class)
-                  .withNonnullFields("druidNode", "nodeRole", "services")
+                  .withNonnullFields("druidNode", "nodeRole", "services", "availableProcessors", "totalMemory")
                   .withIgnoredFields("startTime")
                   .usingGetClass()
                   .verify();
@@ -156,7 +156,9 @@ public class DiscoveryDruidNodeTest
                         + "      \"serverType\" : \"broker\",\n"
                         + "      \"priority\" : 0\n"
                         + "    }\n"
-                        + "  }\n"
+                        + "  },\n"
+                        + " \"availableProcessors\" : 3,\n"
+                        + " \"totalMemory\" : 1234\n"
                         + "}";
     Assert.assertEquals(
         new DiscoveryDruidNode(
@@ -175,7 +177,10 @@ public class DiscoveryDruidNodeTest
             ImmutableMap.of(
                 "dataNodeService",
                 new DataNodeService("_default_tier", 1000000000, ServerType.BROKER, 0)
-            )
+            ),
+            null,
+            3,
+            1234L
         ),
         mapper.readValue(json, DiscoveryDruidNode.class)
     );
@@ -206,7 +211,9 @@ public class DiscoveryDruidNodeTest
                         + "      \"serverType\" : \"broker\",\n"
                         + "      \"priority\" : 0\n"
                         + "    }\n"
-                        + "  }\n"
+                        + "  },\n"
+                        + " \"availableProcessors\" : 6,\n"
+                        + " \"totalMemory\" : 5432\n"
                         + "}";
     Assert.assertEquals(
         new DiscoveryDruidNode(
@@ -225,7 +232,10 @@ public class DiscoveryDruidNodeTest
             ImmutableMap.of(
                 "dataNodeService",
                 new DataNodeService("_default_tier", 1000000000, ServerType.BROKER, 0)
-            )
+            ),
+            null,
+            6,
+            5432L
         ),
         mapper.readValue(json, DiscoveryDruidNode.class)
     );
@@ -257,7 +267,9 @@ public class DiscoveryDruidNodeTest
                         + "      \"serverType\" : \"broker\",\n"
                         + "      \"priority\" : 0\n"
                         + "    }\n"
-                        + "  }\n"
+                        + "  },\n"
+                        + " \"availableProcessors\" : 4,\n"
+                        + " \"totalMemory\" : 246810\n"
                         + "}";
     Assert.assertEquals(
         new DiscoveryDruidNode(
@@ -273,7 +285,10 @@ public class DiscoveryDruidNodeTest
                 null
             ),
             NodeRole.BROKER,
-            ImmutableMap.of()
+            ImmutableMap.of(),
+            null,
+            4,
+            246810L
         ),
         mapper.readValue(json, DiscoveryDruidNode.class)
     );
