@@ -23,6 +23,7 @@ import org.apache.druid.segment.Segment;
 import org.apache.druid.segment.SegmentLazyLoadFailCallback;
 import org.apache.druid.timeline.DataSegment;
 
+import javax.annotation.Nullable;
 import java.io.File;
 import java.util.List;
 import java.util.Optional;
@@ -39,6 +40,18 @@ public class NoopSegmentCacheManager implements SegmentCacheManager
     throw new UnsupportedOperationException();
   }
 
+  @Override
+  public boolean canLoadSegmentsOnDemand()
+  {
+    return false;
+  }
+
+  @Override
+  public boolean canLoadSegmentOnDemand(DataSegment segment)
+  {
+    return false;
+  }
+
   @Override
   public List<DataSegment> getCachedSegments()
   {
@@ -104,4 +117,11 @@ public class NoopSegmentCacheManager implements SegmentCacheManager
   {
     throw new UnsupportedOperationException();
   }
+
+  @Nullable
+  @Override
+  public StorageStats getStorageStats()
+  {
+    return null;
+  }
 }
