@@ -27,6 +27,7 @@ import com.google.common.collect.ImmutableMap;
 import org.apache.druid.error.DruidException;
 import org.apache.druid.jackson.DefaultObjectMapper;
 import org.apache.druid.java.util.common.DateTimes;
+import org.apache.druid.java.util.common.FileUtils;
 import org.apache.druid.java.util.common.Intervals;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.concurrent.Execs;
@@ -34,7 +35,6 @@ import org.apache.druid.java.util.common.io.Closer;
 import org.apache.druid.java.util.emitter.EmittingLogger;
 import org.apache.druid.segment.IndexIO;
 import org.apache.druid.segment.PhysicalSegmentInspector;
-import org.apache.druid.segment.ReferenceCountedObjectProvider;
 import org.apache.druid.segment.Segment;
 import org.apache.druid.segment.TestHelper;
 import org.apache.druid.segment.TestIndex;
@@ -78,6 +78,8 @@ class SegmentLocalCacheManagerConcurrencyTest
 
   private File localSegmentCacheFolder;
   private File otherLocalSegmentCacheFolder;
+  private SegmentLoaderConfig loaderConfig;
+  private SegmentLoaderConfig vsfLoaderConfig;
   private SegmentLocalCacheManager manager;
   private SegmentLocalCacheManager virtualStorageManager;
   private StorageLocation location;
@@ -127,8 +129,21 @@ class SegmentLocalCacheManagerConcurrencyTest
     locations.add(locationConfig);
     locations.add(locationConfig2);
 
-    final SegmentLoaderConfig loaderConfig = new SegmentLoaderConfig().withLocations(locations);
-    final SegmentLoaderConfig vsfLoaderConfig = new SegmentLoaderConfig()
+    loaderConfig = new SegmentLoaderConfig()
+    {
+      @Override
+      public List<StorageLocationConfig> getLocations()
+      {
+        return locations;
+      }
+
+      @Override
+      public File getInfoDir()
+      {
+        return new File(tempDir, "info");
+      }
+    };
+    vsfLoaderConfig = new SegmentLoaderConfig()
     {
       @Override
       public List<StorageLocationConfig> getLocations()
@@ -147,6 +162,12 @@ class SegmentLocalCacheManagerConcurrencyTest
       {
         return Runtime.getRuntime().availableProcessors();
       }
+
+      @Override
+      public File getInfoDir()
+      {
+        return new File(tempDir, "info");
+      }
     };
     final List<StorageLocation> storageLocations = loaderConfig.toStorageLocations();
     location = storageLocations.get(0);
@@ -165,6 +186,8 @@ class SegmentLocalCacheManagerConcurrencyTest
         TestIndex.INDEX_IO,
         jsonMapper
     );
+    manager.getCachedSegments();
+    virtualStorageManager.getCachedSegments();
     executorService = Execs.multiThreaded(
         10,
         "segment-loader-local-cache-manager-concurrency-test-%d"
@@ -182,7 +205,7 @@ class SegmentLocalCacheManagerConcurrencyTest
       virtualStorageManager.drop(segment);
     }
     for (StorageLocation location : virtualStorageManager.getLocations()) {
-      location.resetStats();
+      location.resetWeakStats();
     }
   }
 
@@ -296,7 +319,7 @@ class SegmentLocalCacheManagerConcurrencyTest
     makeSegmentsToLoad(segmentCount, localStorageFolder, interval, segmentsToWeakLoad);
 
     for (boolean sleepy : new boolean[]{true, false}) {
-      testWeakLoad(iterations, segmentCount, concurrentReads, false, sleepy, false);
+      testWeakLoad(iterations, segmentCount, concurrentReads, false, sleepy, false, false);
     }
   }
 
@@ -314,7 +337,7 @@ class SegmentLocalCacheManagerConcurrencyTest
     makeSegmentsToLoad(segmentCount, localStorageFolder, interval, segmentsToWeakLoad);
 
     for (boolean sleepy : new boolean[]{true, false}) {
-      testWeakLoad(iterations, segmentCount, concurrentReads, true, sleepy, true);
+      testWeakLoad(iterations, segmentCount, concurrentReads, true, sleepy, true, false);
     }
   }
 
@@ -332,7 +355,7 @@ class SegmentLocalCacheManagerConcurrencyTest
     makeSegmentsToLoad(segmentCount, localStorageFolder, interval, segmentsToWeakLoad);
 
     for (boolean sleepy : new boolean[]{true, false}) {
-      testWeakLoad(iterations, segmentCount, concurrentReads, true, sleepy, true);
+      testWeakLoad(iterations, segmentCount, concurrentReads, true, sleepy, true, false);
     }
   }
 
@@ -346,11 +369,11 @@ class SegmentLocalCacheManagerConcurrencyTest
     final File localStorageFolder = new File(tempDir, "local_storage_folder");
 
     final Interval interval = Intervals.of("2019-01-01/P1D");
-
     makeSegmentsToLoad(segmentCount, localStorageFolder, interval, segmentsToWeakLoad);
 
     for (boolean sleepy : new boolean[]{true, false}) {
-      testWeakLoad(iterations, segmentCount, concurrentReads, true, sleepy, true);
+      // use different segments for each run, otherwise the 2nd run is all cache hits
+      testWeakLoad(iterations, segmentCount, concurrentReads, true, sleepy, true, true);
     }
   }
 
@@ -404,10 +427,11 @@ class SegmentLocalCacheManagerConcurrencyTest
     Assertions.assertEquals(0, location2.getActiveWeakHolds());
     Assertions.assertTrue(4 >= location.getWeakEntryCount());
     Assertions.assertTrue(4 >= location2.getWeakEntryCount());
-    Assertions.assertTrue(4 >= location.getPath().listFiles().length);
-    Assertions.assertTrue(4 >= location2.getPath().listFiles().length);
-    Assertions.assertEquals(location.getStats().getEvictionCount(), location.getStats().getUnmountCount());
-    Assertions.assertEquals(location2.getStats().getEvictionCount(), location2.getStats().getUnmountCount());
+    // 5 because __drop path
+    Assertions.assertTrue(5 >= location.getPath().listFiles().length);
+    Assertions.assertTrue(5 >= location2.getPath().listFiles().length);
+    Assertions.assertEquals(location.getWeakStats().getEvictionCount(), location.getWeakStats().getUnmountCount());
+    Assertions.assertEquals(location2.getWeakStats().getEvictionCount(), location2.getWeakStats().getUnmountCount());
   }
 
   @Test
@@ -464,8 +488,8 @@ class SegmentLocalCacheManagerConcurrencyTest
       }
     }
 
-    Assertions.assertTrue(location.getStats().getHitCount() >= 0);
-    Assertions.assertTrue(location2.getStats().getHitCount() >= 0);
+    Assertions.assertTrue(location.getWeakStats().getHitCount() >= 0);
+    Assertions.assertTrue(location2.getWeakStats().getHitCount() >= 0);
     assertNoLooseEnds();
   }
 
@@ -540,8 +564,8 @@ class SegmentLocalCacheManagerConcurrencyTest
     Assertions.assertTrue(totalSuccess > ((iterations / 10) * minLoadCount));
     // expect at least some empties from the segment not being cached
     Assertions.assertTrue(totalEmpty > 0);
-    Assertions.assertTrue(location.getStats().getHitCount() >= 0);
-    Assertions.assertTrue(location2.getStats().getHitCount() >= 0);
+    Assertions.assertTrue(location.getWeakStats().getHitCount() >= 0);
+    Assertions.assertTrue(location2.getWeakStats().getHitCount() >= 0);
 
     assertNoLooseEnds();
   }
@@ -552,7 +576,8 @@ class SegmentLocalCacheManagerConcurrencyTest
       int concurrentReads,
       boolean random,
       boolean sleepy,
-      boolean expectHits
+      boolean expectHits,
+      boolean expectNoFailures
   )
   {
     int totalSuccess = 0;
@@ -562,8 +587,8 @@ class SegmentLocalCacheManagerConcurrencyTest
     for (DataSegment segment : segmentsToWeakLoad) {
       virtualStorageManager.drop(segment);
     }
-    location.resetStats();
-    location2.resetStats();
+    location.reset();
+    location2.reset();
     for (int i = 0; i < iterations; i++) {
       int segment = random ? ThreadLocalRandom.current().nextInt(segmentCount) : i % segmentCount;
       currentBatch.add(segmentsToWeakLoad.get(segment));
@@ -575,17 +600,17 @@ class SegmentLocalCacheManagerConcurrencyTest
         totalFailures += result.exceptions.size();
         Assertions.assertEquals(
             totalSuccess,
-            location.getStats().getLoadCount() +
-            location.getStats().getHitCount() +
-            location2.getStats().getLoadCount() +
-            location2.getStats().getHitCount(),
+            location.getWeakStats().getLoadCount() +
+            location.getWeakStats().getHitCount() +
+            location2.getWeakStats().getLoadCount() +
+            location2.getWeakStats().getHitCount(),
             StringUtils.format(
                 "iteration[%s] - loc1: loads[%s] hits[%s] loc2: loads[%s] hits[%s]",
                 i,
-                location.getStats().getLoadCount(),
-                location.getStats().getHitCount(),
-                location2.getStats().getLoadCount(),
-                location2.getStats().getHitCount()
+                location.getWeakStats().getLoadCount(),
+                location.getWeakStats().getHitCount(),
+                location2.getWeakStats().getLoadCount(),
+                location2.getWeakStats().getHitCount()
             )
         );
 
@@ -602,23 +627,35 @@ class SegmentLocalCacheManagerConcurrencyTest
     Assertions.assertEquals(iterations, totalSuccess + totalFailures);
     Assertions.assertEquals(
         totalSuccess,
-        location.getStats().getLoadCount()
-        + location.getStats().getHitCount()
-        + location2.getStats().getLoadCount()
-        + location2.getStats().getHitCount()
+        location.getWeakStats().getLoadCount()
+        + location.getWeakStats().getHitCount()
+        + location2.getWeakStats().getLoadCount()
+        + location2.getWeakStats().getHitCount()
     );
-    Assertions.assertTrue(totalFailures <= location.getStats().getRejectCount() + location2.getStats()
-                                                                                           .getRejectCount());
+    Assertions.assertTrue(totalFailures <= location.getWeakStats().getRejectCount() + location2.getWeakStats()
+                                                                                               .getRejectCount());
 
+    if (expectNoFailures) {
+      Assertions.assertEquals(0, totalFailures);
+      Assertions.assertEquals(iterations, totalSuccess);
+    }
     if (expectHits) {
-      Assertions.assertTrue(location.getStats().getHitCount() >= 0);
-      Assertions.assertTrue(location2.getStats().getHitCount() >= 0);
+      Assertions.assertTrue(location.getWeakStats().getHitCount() >= 0);
+      Assertions.assertTrue(location2.getWeakStats().getHitCount() >= 0);
     } else {
-      Assertions.assertEquals(0, location.getStats().getHitCount());
-      Assertions.assertEquals(0, location2.getStats().getHitCount());
+      Assertions.assertEquals(0, location.getWeakStats().getHitCount());
+      Assertions.assertEquals(0, location2.getWeakStats().getHitCount());
     }
 
     assertNoLooseEnds();
+
+    try {
+      FileUtils.deleteDirectory(location.getPath());
+      FileUtils.deleteDirectory(location2.getPath());
+    }
+    catch (IOException e) {
+      throw new RuntimeException(e);
+    }
   }
 
   private BatchResult testWeakBatch(int iteration, List<DataSegment> currentBatch, boolean sleepy)
@@ -676,7 +713,82 @@ class SegmentLocalCacheManagerConcurrencyTest
     return new BatchResult(exceptions, success, rows);
   }
 
+  @Test
+  public void testAcquireSegmentOnDemandRandomSegmentWithInterrupt() throws IOException, InterruptedException
+  {
+    final int segmentCount = 8;
+    final int iterations = 2000;
+    final int concurrentReads = 10;
+    final File localStorageFolder = new File(tempDir, "local_storage_folder");
 
+    final Interval interval = Intervals.of("2019-01-01/P1D");
+
+    makeSegmentsToLoad(segmentCount, localStorageFolder, interval, segmentsToWeakLoad);
+
+    final List<DataSegment> currentBatch = new ArrayList<>();
+    for (int i = 0; i < iterations; i++) {
+      currentBatch.add(segmentsToWeakLoad.get(ThreadLocalRandom.current().nextInt(segmentCount)));
+      // process batches of 10 requests at a time
+      if (currentBatch.size() == concurrentReads) {
+        final List<InterruptedLoad> weakLoads = currentBatch
+            .stream()
+            .map(segment -> new InterruptedLoad(virtualStorageManager, segment))
+            .collect(Collectors.toList());
+        final List<Future<Integer>> futures = new ArrayList<>();
+        for (InterruptedLoad weakLoad : weakLoads) {
+          futures.add(executorService.submit(weakLoad));
+        }
+        for (Future<Integer> future : futures) {
+          try {
+            future.get(20L, TimeUnit.MILLISECONDS);
+          }
+          catch (Throwable t) {
+          }
+        }
+        while (true) {
+          boolean allDone = true;
+          for (Future<?> f : futures) {
+            allDone = allDone && f.isDone();
+          }
+          if (allDone) {
+            break;
+          }
+          Thread.sleep(5);
+        }
+        Assertions.assertEquals(0, location.getActiveWeakHolds());
+        Assertions.assertEquals(0, location2.getActiveWeakHolds());
+        currentBatch.clear();
+      }
+    }
+
+    Assertions.assertTrue(location.getWeakStats().getHitCount() >= 0);
+    Assertions.assertTrue(location2.getWeakStats().getHitCount() >= 0);
+
+    // now ensure that we can successfully do stuff after all those interrupts
+    int totalSuccess = 0;
+    int totalFailures = 0;
+    for (int i = 0; i < iterations; i++) {
+      int segment = ThreadLocalRandom.current().nextInt(segmentCount);
+      currentBatch.add(segmentsToWeakLoad.get(segment));
+      // process batches of 10 requests at a time
+      if (currentBatch.size() == concurrentReads) {
+
+        BatchResult result = testWeakBatch(i, currentBatch, false);
+        totalSuccess += result.success;
+        totalFailures += result.exceptions.size();
+        currentBatch.clear();
+      }
+    }
+    Assertions.assertEquals(iterations, totalSuccess);
+    Assertions.assertEquals(0, totalFailures);
+    Assertions.assertEquals(0, location.getActiveWeakHolds());
+    Assertions.assertEquals(0, location2.getActiveWeakHolds());
+    Assertions.assertTrue(4 >= location.getWeakEntryCount());
+    Assertions.assertTrue(4 >= location2.getWeakEntryCount());
+    // 5 because __drop path
+    Assertions.assertTrue(5 >= location.getPath().listFiles().length);
+    Assertions.assertTrue(5 >= location2.getPath().listFiles().length);
+  }
 
   private void assertNoLooseEnds()
   {
@@ -684,16 +796,17 @@ class SegmentLocalCacheManagerConcurrencyTest
     Assertions.assertEquals(0, location2.getActiveWeakHolds());
     Assertions.assertTrue(4 >= location.getWeakEntryCount());
     Assertions.assertTrue(4 >= location2.getWeakEntryCount());
-    Assertions.assertTrue(4 >= location.getPath().listFiles().length);
-    Assertions.assertTrue(4 >= location2.getPath().listFiles().length);
-    Assertions.assertTrue(location.getStats().getLoadCount() >= 4);
-    Assertions.assertTrue(location2.getStats().getLoadCount() >= 4);
-    Assertions.assertEquals(location.getStats().getEvictionCount(), location.getStats().getUnmountCount());
-    Assertions.assertEquals(location2.getStats().getEvictionCount(), location2.getStats().getUnmountCount());
-    Assertions.assertEquals(location.getStats().getLoadCount() - 4, location.getStats().getEvictionCount());
-    Assertions.assertEquals(location2.getStats().getLoadCount() - 4, location2.getStats().getEvictionCount());
-    Assertions.assertEquals(location.getStats().getLoadCount() - 4, location.getStats().getUnmountCount());
-    Assertions.assertEquals(location2.getStats().getLoadCount() - 4, location2.getStats().getUnmountCount());
+    // 5 because __drop path
+    Assertions.assertTrue(5 >= location.getPath().listFiles().length);
+    Assertions.assertTrue(5 >= location2.getPath().listFiles().length);
+    Assertions.assertTrue(location.getWeakStats().getLoadCount() >= 4);
+    Assertions.assertTrue(location2.getWeakStats().getLoadCount() >= 4);
+    Assertions.assertEquals(location.getWeakStats().getEvictionCount(), location.getWeakStats().getUnmountCount());
+    Assertions.assertEquals(location2.getWeakStats().getEvictionCount(), location2.getWeakStats().getUnmountCount());
+    Assertions.assertEquals(location.getWeakStats().getLoadCount() - 4, location.getWeakStats().getEvictionCount());
+    Assertions.assertEquals(location2.getWeakStats().getLoadCount() - 4, location2.getWeakStats().getEvictionCount());
+    Assertions.assertEquals(location.getWeakStats().getLoadCount() - 4, location.getWeakStats().getUnmountCount());
+    Assertions.assertEquals(location2.getWeakStats().getLoadCount() - 4, location2.getWeakStats().getUnmountCount());
   }
 
   private void makeSegmentsToLoad(
@@ -822,12 +935,12 @@ class SegmentLocalCacheManagerConcurrencyTest
           segmentManager.acquireSegment(segment)
       );
       try {
-        final ReferenceCountedObjectProvider<Segment> referenceProvider =
+        final AcquireSegmentResult result =
             action.getSegmentFuture().get(timeout, TimeUnit.MILLISECONDS);
-        if (referenceProvider == null) {
+        if (result == null) {
           Assertions.fail("this shouldn't happen");
         }
-        final Optional<Segment> segment = referenceProvider.acquireReference().map(closer::register);
+        final Optional<Segment> segment = result.getReferenceProvider().acquireReference().map(closer::register);
         if (segment.isPresent()) {
           PhysicalSegmentInspector gadget = segment.get().as(PhysicalSegmentInspector.class);
           if (delayMin >= 0 && delayMax > 0) {
@@ -892,4 +1005,41 @@ class SegmentLocalCacheManagerConcurrencyTest
       }
     }
   }
+
+  private static class InterruptedLoad implements Callable<Integer>
+  {
+    private final SegmentLocalCacheManager segmentManager;
+    private final DataSegment segment;
+
+    private InterruptedLoad(
+        SegmentLocalCacheManager segmentManager,
+        DataSegment segment
+    )
+    {
+      this.segmentManager = segmentManager;
+      this.segment = segment;
+    }
+
+    @Override
+    public Integer call() throws SegmentLoadingException
+    {
+      final Closer closer = Closer.create();
+      final AcquireSegmentAction action = closer.register(
+          segmentManager.acquireSegment(segment)
+      );
+      try {
+        final Future<AcquireSegmentResult> result = action.getSegmentFuture();
+        Thread.sleep(ThreadLocalRandom.current().nextInt(50));
+        result.cancel(true);
+        Thread.currentThread().interrupt();
+      }
+      catch (Throwable t) {
+        throw new RuntimeException(t);
+      }
+      finally {
+        CloseableUtils.closeAndWrapExceptions(closer);
+      }
+      return null;
+    }
+  }
 }
