@@ -25,7 +25,6 @@ import org.apache.druid.segment.SchemaPayloadPlus;
 import org.apache.druid.segment.SegmentMetadata;
 import org.apache.druid.segment.column.ColumnType;
 import org.apache.druid.segment.column.RowSignature;
-import org.apache.druid.server.metrics.NoopServiceEmitter;
 import org.apache.druid.timeline.SegmentId;
 import org.junit.Assert;
 import org.junit.Test;
@@ -38,12 +37,12 @@ public class SegmentSchemaCacheTest
   @Test
   public void testCacheRealtimeSegmentSchema()
   {
-    SegmentSchemaCache cache = new SegmentSchemaCache(new NoopServiceEmitter());
+    SegmentSchemaCache cache = new SegmentSchemaCache();
 
     RowSignature rowSignature = RowSignature.builder().add("cx", ColumnType.FLOAT).build();
     SchemaPayloadPlus expected = new SchemaPayloadPlus(new SchemaPayload(rowSignature), 20L);
     SegmentId id = SegmentId.dummy("ds");
-    cache.addRealtimeSegmentSchema(id, rowSignature, 20);
+    cache.addRealtimeSegmentSchema(id, expected);
 
     Assert.assertTrue(cache.isSchemaCached(id));
     Optional<SchemaPayloadPlus> schema = cache.getSchemaForSegment(id);
@@ -58,7 +57,7 @@ public class SegmentSchemaCacheTest
   @Test
   public void testCacheTemporaryMetadataQueryResults()
   {
-    SegmentSchemaCache cache = new SegmentSchemaCache(new NoopServiceEmitter());
+    SegmentSchemaCache cache = new SegmentSchemaCache();
 
     RowSignature rowSignature = RowSignature.builder().add("cx", ColumnType.FLOAT).build();
     SchemaPayloadPlus expected = new SchemaPayloadPlus(new SchemaPayload(rowSignature, Collections.emptyMap()), 20L);
@@ -66,10 +65,10 @@ public class SegmentSchemaCacheTest
     SegmentId id2 = SegmentId.dummy("ds2");
 
     // this call shouldn't result in any error
-    cache.markMetadataQueryResultPublished(id);
+    cache.markSchemaPersisted(id);
 
-    cache.addTemporaryMetadataQueryResult(id, rowSignature, Collections.emptyMap(), 20);
-    cache.addTemporaryMetadataQueryResult(id2, rowSignature, Collections.emptyMap(), 20);
+    cache.addSchemaPendingBackfill(id, expected);
+    cache.addSchemaPendingBackfill(id2, expected);
 
     Assert.assertTrue(cache.isSchemaCached(id));
     Assert.assertTrue(cache.isSchemaCached(id2));
@@ -80,8 +79,8 @@ public class SegmentSchemaCacheTest
     Assert.assertTrue(schema2.isPresent());
     Assert.assertEquals(expected, schema2.get());
 
-    cache.markMetadataQueryResultPublished(id);
-    cache.markMetadataQueryResultPublished(id2);
+    cache.markSchemaPersisted(id);
+    cache.markSchemaPersisted(id2);
 
     schema = cache.getSchemaForSegment(id);
     Assert.assertTrue(schema.isPresent());
@@ -95,10 +94,7 @@ public class SegmentSchemaCacheTest
     ImmutableMap.Builder<String, SchemaPayload> schemaPayloadBuilder = ImmutableMap.builder();
     schemaPayloadBuilder.put("fp", new SchemaPayload(rowSignature));
 
-    SegmentSchemaCache.FinalizedSegmentSchemaInfo finalizedSegmentSchemaInfo =
-        new SegmentSchemaCache.FinalizedSegmentSchemaInfo(segmentMetadataBuilder.build(), schemaPayloadBuilder.build());
-
-    cache.updateFinalizedSegmentSchema(finalizedSegmentSchemaInfo);
+    cache.resetSchemaForPublishedSegments(segmentMetadataBuilder.build(), schemaPayloadBuilder.build());
 
     Assert.assertNull(cache.getTemporaryPublishedMetadataQueryResults(id));
     Assert.assertNotNull(cache.getTemporaryPublishedMetadataQueryResults(id2));
@@ -114,7 +110,7 @@ public class SegmentSchemaCacheTest
   @Test
   public void testCacheFinalizedSegmentSchema()
   {
-    SegmentSchemaCache cache = new SegmentSchemaCache(new NoopServiceEmitter());
+    SegmentSchemaCache cache = new SegmentSchemaCache();
 
     Assert.assertFalse(cache.isInitialized());
 
@@ -128,7 +124,7 @@ public class SegmentSchemaCacheTest
     ImmutableMap.Builder<SegmentId, SegmentMetadata> segmentMetadataBuilder = new ImmutableMap.Builder<>();
     segmentMetadataBuilder.put(id, new SegmentMetadata(20L, "fp1"));
 
-    cache.updateFinalizedSegmentSchema(new SegmentSchemaCache.FinalizedSegmentSchemaInfo(segmentMetadataBuilder.build(), schemaPayloadBuilder.build()));
+    cache.resetSchemaForPublishedSegments(segmentMetadataBuilder.build(), schemaPayloadBuilder.build());
 
     Assert.assertTrue(cache.isInitialized());
     Assert.assertTrue(cache.isSchemaCached(id));
