@@ -518,7 +518,7 @@ public class AsyncManagementForwardingServletTest extends BaseJettyTest
               injector.getInstance(DruidHttpClientConfig.class),
               coordinatorLeaderSelector,
               overlordLeaderSelector,
-              new AuthorizerMapper(ImmutableMap.of("allowAll", new AllowAllAuthorizer()))
+              new AuthorizerMapper(ImmutableMap.of("allowAll", new AllowAllAuthorizer(null)))
           )
       );
 
