@@ -19,7 +19,6 @@
 
 package org.apache.druid.server.compaction;
 
-import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.druid.client.indexing.ClientCompactionTaskQueryTuningConfig;
 import org.apache.druid.data.input.impl.AggregateProjectionSpec;
 import org.apache.druid.data.input.impl.DimensionsSpec;
@@ -31,7 +30,6 @@ import org.apache.druid.indexer.partitions.DimensionRangePartitionsSpec;
 import org.apache.druid.indexer.partitions.DynamicPartitionsSpec;
 import org.apache.druid.indexer.partitions.HashedPartitionsSpec;
 import org.apache.druid.indexer.partitions.PartitionsSpec;
-import org.apache.druid.jackson.DefaultObjectMapper;
 import org.apache.druid.java.util.common.Intervals;
 import org.apache.druid.java.util.common.granularity.Granularities;
 import org.apache.druid.query.aggregation.LongSumAggregatorFactory;
@@ -47,6 +45,7 @@ import org.apache.druid.server.coordinator.UserCompactionTaskGranularityConfig;
 import org.apache.druid.server.coordinator.UserCompactionTaskQueryTuningConfig;
 import org.apache.druid.timeline.CompactionState;
 import org.apache.druid.timeline.DataSegment;
+import org.apache.druid.timeline.SegmentId;
 import org.junit.Assert;
 import org.junit.Test;
 
@@ -55,14 +54,9 @@ import java.util.List;
 
 public class CompactionStatusTest
 {
-  private static final ObjectMapper OBJECT_MAPPER = new DefaultObjectMapper();
-
   private static final DataSegment WIKI_SEGMENT
-      = DataSegment.builder()
-                   .dataSource(TestDataSource.WIKI)
-                   .interval(Intervals.of("2013-01-01/PT1H"))
+      = DataSegment.builder(SegmentId.of(TestDataSource.WIKI, Intervals.of("2013-01-01/PT1H"), "v1", 0))
                    .size(100_000_000L)
-                   .version("v1")
                    .build();
 
   @Test
@@ -70,8 +64,7 @@ public class CompactionStatusTest
   {
     final ClientCompactionTaskQueryTuningConfig tuningConfig
         = ClientCompactionTaskQueryTuningConfig.from(null);
-    Assert.assertEquals(
-        new DynamicPartitionsSpec(null, Long.MAX_VALUE),
+    Assert.assertNull(
         CompactionStatus.findPartitionsSpecFromConfig(tuningConfig)
     );
   }
@@ -203,9 +196,14 @@ public class CompactionStatusTest
   @Test
   public void testStatusWhenLastCompactionStateIsEmpty()
   {
+    final PartitionsSpec requiredPartitionsSpec = new DynamicPartitionsSpec(5_000_000, null);
     verifyCompactionStatusIsPendingBecause(
         new CompactionState(null, null, null, null, null, null, null),
-        InlineSchemaDataSourceCompactionConfig.builder().forDataSource(TestDataSource.WIKI).build(),
+        InlineSchemaDataSourceCompactionConfig
+            .builder()
+            .withTuningConfig(createTuningConfig(requiredPartitionsSpec, null))
+            .forDataSource(TestDataSource.WIKI)
+            .build(),
         "'partitionsSpec' mismatch: required['dynamic' with 5,000,000 rows], current[null]"
     );
   }
@@ -213,12 +211,16 @@ public class CompactionStatusTest
   @Test
   public void testStatusOnPartitionsSpecMismatch()
   {
-    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, 0L);
+    final PartitionsSpec requiredPartitionsSpec = new DynamicPartitionsSpec(5_000_000, null);
+    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, null);
 
     final CompactionState lastCompactionState
         = new CompactionState(currentPartitionsSpec, null, null, null, null, null, null);
-    final DataSourceCompactionConfig compactionConfig
-        = InlineSchemaDataSourceCompactionConfig.builder().forDataSource(TestDataSource.WIKI).build();
+    final DataSourceCompactionConfig compactionConfig = InlineSchemaDataSourceCompactionConfig
+        .builder()
+        .withTuningConfig(createTuningConfig(requiredPartitionsSpec, null))
+        .forDataSource(TestDataSource.WIKI)
+        .build();
 
     verifyCompactionStatusIsPendingBecause(
         lastCompactionState,
@@ -234,7 +236,7 @@ public class CompactionStatusTest
     final IndexSpec currentIndexSpec
         = IndexSpec.builder().withDimensionCompression(CompressionStrategy.ZSTD).build();
 
-    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, 0L);
+    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, null);
     final CompactionState lastCompactionState = new CompactionState(
         currentPartitionsSpec,
         null,
@@ -255,10 +257,12 @@ public class CompactionStatusTest
         compactionConfig,
         "'indexSpec' mismatch: "
         + "required[IndexSpec{bitmapSerdeFactory=RoaringBitmapSerdeFactory{},"
+        + " metadataCompression=none,"
         + " dimensionCompression=lz4, stringDictionaryEncoding=Utf8{},"
         + " metricCompression=lz4, longEncoding=longs, complexMetricCompression=null,"
         + " autoColumnFormatSpec=null, jsonCompression=null, segmentLoader=null}], "
         + "current[IndexSpec{bitmapSerdeFactory=RoaringBitmapSerdeFactory{},"
+        + " metadataCompression=none,"
         + " dimensionCompression=zstd, stringDictionaryEncoding=Utf8{},"
         + " metricCompression=lz4, longEncoding=longs, complexMetricCompression=null,"
         + " autoColumnFormatSpec=null, jsonCompression=null, segmentLoader=null}]"
@@ -271,7 +275,7 @@ public class CompactionStatusTest
     final GranularitySpec currentGranularitySpec
         = new UniformGranularitySpec(Granularities.HOUR, null, null);
 
-    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, 0L);
+    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, null);
     final IndexSpec currentIndexSpec
         = IndexSpec.builder().withDimensionCompression(CompressionStrategy.ZSTD).build();
     final CompactionState lastCompactionState = new CompactionState(
@@ -302,7 +306,7 @@ public class CompactionStatusTest
   {
     final GranularitySpec currentGranularitySpec
         = new UniformGranularitySpec(Granularities.HOUR, null, null);
-    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, 0L);
+    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, null);
     final IndexSpec currentIndexSpec
         = IndexSpec.builder().withDimensionCompression(CompressionStrategy.ZSTD).build();
     final CompactionState lastCompactionState = new CompactionState(
@@ -323,9 +327,8 @@ public class CompactionStatusTest
 
     final DataSegment segment = DataSegment.builder(WIKI_SEGMENT).lastCompactionState(lastCompactionState).build();
     final CompactionStatus status = CompactionStatus.compute(
-        CompactionCandidate.from(Collections.singletonList(segment)),
-        compactionConfig,
-        OBJECT_MAPPER
+        CompactionCandidate.from(List.of(segment), Granularities.HOUR),
+        compactionConfig
     );
     Assert.assertTrue(status.isComplete());
   }
@@ -335,7 +338,7 @@ public class CompactionStatusTest
   {
     final GranularitySpec currentGranularitySpec
         = new UniformGranularitySpec(Granularities.HOUR, null, null);
-    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, 0L);
+    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, null);
     final IndexSpec currentIndexSpec
         = IndexSpec.builder().withDimensionCompression(CompressionStrategy.ZSTD).build();
     final AggregateProjectionSpec projection1 =
@@ -373,9 +376,8 @@ public class CompactionStatusTest
 
     final DataSegment segment = DataSegment.builder(WIKI_SEGMENT).lastCompactionState(lastCompactionState).build();
     final CompactionStatus status = CompactionStatus.compute(
-        CompactionCandidate.from(Collections.singletonList(segment)),
-        compactionConfig,
-        OBJECT_MAPPER
+        CompactionCandidate.from(List.of(segment), Granularities.HOUR),
+        compactionConfig
     );
     Assert.assertTrue(status.isComplete());
   }
@@ -385,7 +387,7 @@ public class CompactionStatusTest
   {
     final GranularitySpec currentGranularitySpec
         = new UniformGranularitySpec(Granularities.HOUR, null, null);
-    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, 0L);
+    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, null);
     final IndexSpec currentIndexSpec
         = IndexSpec.builder().withDimensionCompression(CompressionStrategy.ZSTD).build();
     final AggregateProjectionSpec projection1 =
@@ -428,9 +430,8 @@ public class CompactionStatusTest
 
     final DataSegment segment = DataSegment.builder(WIKI_SEGMENT).lastCompactionState(lastCompactionState).build();
     final CompactionStatus status = CompactionStatus.compute(
-        CompactionCandidate.from(Collections.singletonList(segment)),
-        compactionConfig,
-        OBJECT_MAPPER
+        CompactionCandidate.from(List.of(segment), Granularities.HOUR),
+        compactionConfig
     );
     Assert.assertFalse(status.isComplete());
   }
@@ -440,7 +441,7 @@ public class CompactionStatusTest
   {
     final GranularitySpec currentGranularitySpec
         = new UniformGranularitySpec(Granularities.HOUR, null, null);
-    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, 0L);
+    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, null);
 
     final CompactionState lastCompactionState = new CompactionState(
         currentPartitionsSpec,
@@ -482,9 +483,8 @@ public class CompactionStatusTest
 
     final DataSegment segment = DataSegment.builder(WIKI_SEGMENT).lastCompactionState(lastCompactionState).build();
     final CompactionStatus status = CompactionStatus.compute(
-        CompactionCandidate.from(Collections.singletonList(segment)),
-        compactionConfig,
-        OBJECT_MAPPER
+        CompactionCandidate.from(List.of(segment), null),
+        compactionConfig
     );
     Assert.assertTrue(status.isComplete());
   }
@@ -494,7 +494,7 @@ public class CompactionStatusTest
   {
     final GranularitySpec currentGranularitySpec
         = new UniformGranularitySpec(Granularities.HOUR, null, null);
-    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, 0L);
+    final PartitionsSpec currentPartitionsSpec = new DynamicPartitionsSpec(100, null);
 
     final CompactionState lastCompactionState = new CompactionState(
         currentPartitionsSpec,
@@ -536,9 +536,8 @@ public class CompactionStatusTest
 
     final DataSegment segment = DataSegment.builder(WIKI_SEGMENT).lastCompactionState(lastCompactionState).build();
     final CompactionStatus status = CompactionStatus.compute(
-        CompactionCandidate.from(Collections.singletonList(segment)),
-        compactionConfig,
-        OBJECT_MAPPER
+        CompactionCandidate.from(List.of(segment), null),
+        compactionConfig
     );
     Assert.assertFalse(status.isComplete());
   }
@@ -554,9 +553,8 @@ public class CompactionStatusTest
                      .lastCompactionState(lastCompactionState)
                      .build();
     final CompactionStatus status = CompactionStatus.compute(
-        CompactionCandidate.from(Collections.singletonList(segment)),
-        compactionConfig,
-        OBJECT_MAPPER
+        CompactionCandidate.from(List.of(segment), null),
+        compactionConfig
     );
 
     Assert.assertFalse(status.isComplete());
