@@ -20,13 +20,8 @@
 package org.apache.druid.server.http;
 
 import com.google.common.collect.ImmutableMap;
-import com.google.common.util.concurrent.Futures;
-import com.google.common.util.concurrent.ListenableFuture;
 import org.apache.druid.error.DruidExceptionMatcher;
 import org.apache.druid.error.ErrorResponse;
-import org.apache.druid.rpc.indexing.NoopOverlordClient;
-import org.apache.druid.rpc.indexing.OverlordClient;
-import org.apache.druid.server.compaction.CompactionStatistics;
 import org.apache.druid.server.compaction.CompactionStatusResponse;
 import org.apache.druid.server.coordinator.AutoCompactionSnapshot;
 import org.apache.druid.server.coordinator.DruidCoordinator;
@@ -37,19 +32,18 @@ import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
-import javax.annotation.Nullable;
 import javax.ws.rs.core.Response;
 import java.util.Collections;
+import java.util.List;
 import java.util.Map;
 
 public class CoordinatorCompactionResourceTest
 {
   private DruidCoordinator mock;
-  private OverlordClient overlordClient;
   private final String dataSourceName = "datasource_1";
   private final AutoCompactionSnapshot expectedSnapshot = new AutoCompactionSnapshot(
       dataSourceName,
-      AutoCompactionSnapshot.AutoCompactionScheduleStatus.RUNNING,
+      AutoCompactionSnapshot.ScheduleStatus.RUNNING,
       null,
       1,
       1,
@@ -66,14 +60,6 @@ public class CoordinatorCompactionResourceTest
   public void setUp()
   {
     mock = EasyMock.createStrictMock(DruidCoordinator.class);
-    overlordClient = new NoopOverlordClient()
-    {
-      @Override
-      public ListenableFuture<Boolean> isCompactionSupervisorEnabled()
-      {
-        return Futures.immediateFuture(false);
-      }
-    };
   }
 
   @After
@@ -85,7 +71,7 @@ public class CoordinatorCompactionResourceTest
   @Test
   public void testGetCompactionSnapshotForDataSourceWithEmptyQueryParameter()
   {
-    Map<String, AutoCompactionSnapshot> expected = ImmutableMap.of(
+    Map<String, AutoCompactionSnapshot> expected = Map.of(
         dataSourceName,
         expectedSnapshot
     );
@@ -93,9 +79,9 @@ public class CoordinatorCompactionResourceTest
     EasyMock.expect(mock.getAutoCompactionSnapshot()).andReturn(expected).once();
     EasyMock.replay(mock);
 
-    final Response response = new CoordinatorCompactionResource(mock, overlordClient)
+    final Response response = new CoordinatorCompactionResource(mock)
         .getCompactionSnapshotForDataSource("");
-    Assert.assertEquals(new CompactionStatusResponse(expected.values()), response.getEntity());
+    Assert.assertEquals(new CompactionStatusResponse(List.of(expectedSnapshot)), response.getEntity());
     Assert.assertEquals(200, response.getStatus());
   }
 
@@ -111,9 +97,9 @@ public class CoordinatorCompactionResourceTest
     EasyMock.expect(mock.getAutoCompactionSnapshot()).andReturn(expected).once();
     EasyMock.replay(mock);
 
-    final Response response = new CoordinatorCompactionResource(mock, overlordClient)
+    final Response response = new CoordinatorCompactionResource(mock)
         .getCompactionSnapshotForDataSource(null);
-    Assert.assertEquals(new CompactionStatusResponse(expected.values()), response.getEntity());
+    Assert.assertEquals(new CompactionStatusResponse(List.of(expectedSnapshot)), response.getEntity());
     Assert.assertEquals(200, response.getStatus());
   }
 
@@ -126,7 +112,7 @@ public class CoordinatorCompactionResourceTest
             .andReturn(expectedSnapshot).once();
     EasyMock.replay(mock);
 
-    final Response response = new CoordinatorCompactionResource(mock, overlordClient)
+    final Response response = new CoordinatorCompactionResource(mock)
         .getCompactionSnapshotForDataSource(dataSourceName);
     Assert.assertEquals(
         new CompactionStatusResponse(Collections.singletonList(expectedSnapshot)),
@@ -144,7 +130,7 @@ public class CoordinatorCompactionResourceTest
             .andReturn(null).once();
     EasyMock.replay(mock);
 
-    final Response response = new CoordinatorCompactionResource(mock, overlordClient)
+    final Response response = new CoordinatorCompactionResource(mock)
         .getCompactionSnapshotForDataSource(dataSourceName);
     Assert.assertEquals(404, response.getStatus());
   }
@@ -154,7 +140,7 @@ public class CoordinatorCompactionResourceTest
   {
     EasyMock.replay(mock);
 
-    final Response response = new CoordinatorCompactionResource(mock, overlordClient)
+    final Response response = new CoordinatorCompactionResource(mock)
         .getCompactionProgress(null);
     Assert.assertEquals(Response.Status.BAD_REQUEST.getStatusCode(), response.getStatus());
 
@@ -166,38 +152,4 @@ public class CoordinatorCompactionResourceTest
         DruidExceptionMatcher.invalidInput().expectMessageIs("No DataSource specified")
     );
   }
-
-  @Test
-  public void testGetSnapshotRedirectsToOverlordWhenSupervisorIsEnabled()
-  {
-    EasyMock.replay(mock);
-
-    AutoCompactionSnapshot.Builder snapshotBuilder = AutoCompactionSnapshot.builder(dataSourceName);
-    snapshotBuilder.incrementCompactedStats(CompactionStatistics.create(100L, 10L, 1L));
-    final AutoCompactionSnapshot snapshotFromOverlord = snapshotBuilder.build();
-
-    overlordClient = new NoopOverlordClient() {
-      @Override
-      public ListenableFuture<Boolean> isCompactionSupervisorEnabled()
-      {
-        return Futures.immediateFuture(true);
-      }
-
-      @Override
-      public ListenableFuture<CompactionStatusResponse> getCompactionSnapshots(@Nullable String dataSource)
-      {
-        return Futures.immediateFuture(
-            new CompactionStatusResponse(Collections.singletonList(snapshotFromOverlord))
-        );
-      }
-    };
-
-    final Response response = new CoordinatorCompactionResource(mock, overlordClient)
-        .getCompactionSnapshotForDataSource(dataSourceName);
-    Assert.assertEquals(200, response.getStatus());
-    Assert.assertEquals(
-        new CompactionStatusResponse(Collections.singletonList(snapshotFromOverlord)),
-        response.getEntity()
-    );
-  }
 }
