@@ -21,7 +21,10 @@ package org.apache.druid.server.metrics;
 
 import org.apache.druid.collections.BlockingPool;
 import org.apache.druid.collections.DefaultBlockingPool;
+import org.apache.druid.java.util.emitter.core.EventMap;
+import org.apache.druid.java.util.emitter.service.ServiceMetricEvent;
 import org.apache.druid.java.util.metrics.StubServiceEmitter;
+import org.apache.druid.query.DruidMetrics;
 import org.apache.druid.query.groupby.GroupByStatsProvider;
 import org.junit.After;
 import org.junit.Assert;
@@ -31,6 +34,8 @@ import org.junit.Test;
 import java.nio.ByteBuffer;
 import java.util.Collections;
 import java.util.List;
+import java.util.Map;
+import java.util.Objects;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
@@ -52,12 +57,12 @@ public class GroupByStatsMonitorTest
       public synchronized AggregateStats getStatsSince()
       {
         return new AggregateStats(
-                1L,
-                100L,
-                2L,
-                200L,
-                300L
-            );
+            1L,
+            100L,
+            2L,
+            200L,
+            300L
+        );
       }
     };
 
@@ -77,6 +82,7 @@ public class GroupByStatsMonitorTest
     final GroupByStatsMonitor monitor =
         new GroupByStatsMonitor(groupByStatsProvider, mergeBufferPool);
     final StubServiceEmitter emitter = new StubServiceEmitter("service", "host");
+    emitter.start();
     monitor.doMonitor(emitter);
     emitter.flush();
     // Trigger metric emission
@@ -92,6 +98,41 @@ public class GroupByStatsMonitorTest
     emitter.verifyValue("groupBy/mergeDictionarySize", 300L);
   }
 
+  @Test
+  public void testMonitorWithServiceDimensions()
+  {
+    final String dataSource = "fooDs";
+    final String taskId = "taskId1";
+    final String groupId = "test_groupid";
+    final String taskType = "test_tasktype";
+    final GroupByStatsMonitor monitor = new GroupByStatsMonitor(
+        groupByStatsProvider,
+        mergeBufferPool
+    );
+    final StubServiceEmitter emitter = new StubServiceEmitter("service", "host", new TestTaskHolder(dataSource, taskId, taskType, groupId));
+    emitter.start();
+    monitor.doMonitor(emitter);
+    emitter.flush();
+    // Trigger metric emission
+    monitor.doMonitor(emitter);
+
+    final Map<String, Object> dimFilters = Map.of(
+        DruidMetrics.DATASOURCE, dataSource,
+        DruidMetrics.TASK_ID, taskId,
+        DruidMetrics.ID, taskId,
+        DruidMetrics.TASK_TYPE,
+        taskType, DruidMetrics.GROUP_ID, groupId
+    );
+
+    verifyMetricValue(emitter, "mergeBuffer/pendingRequests", dimFilters, 0L);
+    verifyMetricValue(emitter, "mergeBuffer/used", dimFilters, 0L);
+    verifyMetricValue(emitter, "mergeBuffer/queries", dimFilters, 1L);
+    verifyMetricValue(emitter, "mergeBuffer/acquisitionTimeNs", dimFilters, 100L);
+    verifyMetricValue(emitter, "groupBy/spilledQueries", dimFilters, 2L);
+    verifyMetricValue(emitter, "groupBy/spilledBytes", dimFilters, 200L);
+    verifyMetricValue(emitter, "groupBy/mergeDictionarySize", dimFilters, 300L);
+  }
+
   @Test
   public void testMonitoringMergeBuffer_acquiredCount()
       throws ExecutionException, InterruptedException, TimeoutException
@@ -143,4 +184,16 @@ public class GroupByStatsMonitorTest
       // do nothing
     }
   }
+
+  private void verifyMetricValue(StubServiceEmitter emitter, String metricName, Map<String, Object> dimFilters, Number expectedValue)
+  {
+    final List<ServiceMetricEvent> observedMetricEvents = emitter.getMetricEvents(metricName);
+    Assert.assertEquals(1, observedMetricEvents.size());
+    final ServiceMetricEvent event = observedMetricEvents.get(0);
+    final EventMap map = event.toMap();
+    final boolean matchesDims = dimFilters.entrySet().stream()
+                                          .allMatch(e -> Objects.equals(e.getValue(), map.get(e.getKey())));
+    Assert.assertTrue(matchesDims);
+    Assert.assertEquals(expectedValue, event.getValue());
+  }
 }
