@@ -92,6 +92,7 @@ import org.eclipse.jetty.ee8.servlet.ServletHolder;
 import org.eclipse.jetty.http.HttpField;
 import org.eclipse.jetty.http.HttpFields;
 import org.eclipse.jetty.http.HttpVersion;
+import org.eclipse.jetty.io.EofException;
 import org.eclipse.jetty.server.Handler;
 import org.eclipse.jetty.server.Server;
 import org.junit.Assert;
@@ -169,7 +170,7 @@ public class AsyncQueryForwardingServletTest extends BaseJettyTest
                       @Override
                       public Authorizer getAuthorizer(String name)
                       {
-                        return new AllowAllAuthorizer();
+                        return new AllowAllAuthorizer(null);
                       }
                     }
                 );
@@ -499,7 +500,7 @@ public class AsyncQueryForwardingServletTest extends BaseJettyTest
       }
     };
 
-    final StubServiceEmitter stubServiceEmitter = new StubServiceEmitter("", "");
+    final StubServiceEmitter stubServiceEmitter = StubServiceEmitter.createStarted();
     final AsyncQueryForwardingServlet servlet = new AsyncQueryForwardingServlet(
         new MapQueryToolChestWarehouse(ImmutableMap.of()),
         TestHelper.makeJsonMapper(),
@@ -530,6 +531,132 @@ public class AsyncQueryForwardingServletTest extends BaseJettyTest
     Assert.assertEquals("false", stubServiceEmitter.getMetricEvents("query/time").get(0).toMap().get("success"));
   }
 
+  @Test
+  public void testOnCompleteWithClosedException()
+  {
+    final TimeseriesQuery query = Druids.newTimeseriesQueryBuilder()
+                                        .dataSource("foo")
+                                        .intervals("2000/P1D")
+                                        .granularity(Granularities.ALL)
+                                        .context(ImmutableMap.of("queryId", "closed-test"))
+                                        .build();
+
+    final HttpServletRequest requestMock = Mockito.mock(HttpServletRequest.class);
+    Mockito.when(requestMock.getAttribute("org.apache.druid.proxy.avaticaQuery")).thenReturn(null);
+    Mockito.when(requestMock.getAttribute("org.apache.druid.proxy.query")).thenReturn(query);
+    Mockito.when(requestMock.getAttribute("org.apache.druid.proxy.sqlQuery")).thenReturn(null);
+    Mockito.when(requestMock.getRemoteAddr()).thenReturn("127.0.0.1");
+    Mockito.when(requestMock.getAttribute(AuthConfig.DRUID_AUTHENTICATION_RESULT))
+           .thenReturn(new AuthenticationResult("testUser", "basic", "basic", null));
+
+    final Request proxyRequestMock = Mockito.mock(Request.class);
+    final Response responseMock = Mockito.mock(Response.class);
+    Mockito.when(responseMock.getStatus()).thenReturn(200); // Status OK
+    Mockito.when(responseMock.getHeaders()).thenReturn(HttpFields.build());
+    Mockito.when(responseMock.getRequest()).thenReturn(proxyRequestMock);
+
+    // Result where connection is closed prematurely
+    final Result result = new Result(proxyRequestMock, responseMock)
+    {
+      @Override
+      public boolean isSucceeded()
+      {
+        return false;
+      }
+
+      @Override
+      public Throwable getFailure()
+      {
+        return new EofException("Stream closed");
+      }
+    };
+
+    final StubServiceEmitter stubServiceEmitter = StubServiceEmitter.createStarted();
+    final AsyncQueryForwardingServlet servlet = new AsyncQueryForwardingServlet(
+        new MapQueryToolChestWarehouse(ImmutableMap.of()),
+        TestHelper.makeJsonMapper(),
+        TestHelper.makeSmileMapper(),
+        null,
+        null,
+        null,
+        stubServiceEmitter,
+        NoopRequestLogger.instance(),
+        new DefaultGenericQueryMetricsFactory(),
+        new AuthenticatorMapper(ImmutableMap.of()),
+        new Properties(),
+        new ServerConfig()
+    );
+
+    try {
+      servlet.newProxyResponseListener(requestMock, null).onComplete(result);
+    }
+    catch (NullPointerException ignored) {
+    }
+
+    stubServiceEmitter.verifyEmitted("query/time", 1);
+    Assert.assertEquals("closed-test", stubServiceEmitter.getEvents().get(0).toMap().get("id"));
+    Assert.assertEquals(
+        500,
+        stubServiceEmitter.getMetricEvents("query/time").get(0).toMap().get(DruidMetrics.STATUS_CODE)
+    );
+    Assert.assertEquals("false", stubServiceEmitter.getMetricEvents("query/time").get(0).toMap().get("success"));
+  }
+
+  @Test
+  public void testOnFailureWithExceptionAndUnassignedStatusCode()
+  {
+    final TimeseriesQuery query = Druids.newTimeseriesQueryBuilder()
+                                        .dataSource("foo")
+                                        .intervals("2000/P1D")
+                                        .granularity(Granularities.ALL)
+                                        .context(ImmutableMap.of("queryId", "zero-status-test"))
+                                        .build();
+
+    final HttpServletRequest requestMock = Mockito.mock(HttpServletRequest.class);
+    Mockito.when(requestMock.getAttribute("org.apache.druid.proxy.avaticaQuery")).thenReturn(null);
+    Mockito.when(requestMock.getAttribute("org.apache.druid.proxy.query")).thenReturn(query);
+    Mockito.when(requestMock.getAttribute("org.apache.druid.proxy.sqlQuery")).thenReturn(null);
+    Mockito.when(requestMock.getRemoteAddr()).thenReturn("127.0.0.1");
+    Mockito.when(requestMock.getAttribute(AuthConfig.DRUID_AUTHENTICATION_RESULT))
+           .thenReturn(new AuthenticationResult("testUser", "basic", "basic", null));
+
+    final Response responseMock = Mockito.mock(Response.class);
+    Mockito.when(responseMock.getStatus()).thenReturn(0); // Test unassigned http status code case from server
+    Mockito.when(responseMock.getHeaders()).thenReturn(HttpFields.build());
+
+    final StubServiceEmitter stubServiceEmitter = StubServiceEmitter.createStarted();
+    final AsyncQueryForwardingServlet servlet = new AsyncQueryForwardingServlet(
+        new MapQueryToolChestWarehouse(ImmutableMap.of()),
+        TestHelper.makeJsonMapper(),
+        TestHelper.makeSmileMapper(),
+        null,
+        null,
+        null,
+        stubServiceEmitter,
+        NoopRequestLogger.instance(),
+        new DefaultGenericQueryMetricsFactory(),
+        new AuthenticatorMapper(ImmutableMap.of()),
+        new Properties(),
+        new ServerConfig()
+    );
+
+    try {
+      servlet.newProxyResponseListener(requestMock, null)
+             .onFailure(responseMock, new IOException("Connection reset by peer"));
+    }
+    catch (NullPointerException ignored) {
+    }
+
+    stubServiceEmitter.verifyEmitted("query/time", 1);
+    Assert.assertEquals("zero-status-test", stubServiceEmitter.getEvents().get(0).toMap().get("id"));
+    Assert.assertEquals(
+        500, // Should default to 500 when status is 0
+        stubServiceEmitter.getMetricEvents("query/time").get(0).toMap().get(DruidMetrics.STATUS_CODE)
+    );
+    Assert.assertEquals("false", stubServiceEmitter.getMetricEvents("query/time").get(0).toMap().get("success"));
+  }
+
+
   @Test
   public void testNoParseExceptionOnGroupByWithFilteredAggregationOnLookups() throws Exception
   {
@@ -744,7 +871,7 @@ public class AsyncQueryForwardingServletTest extends BaseJettyTest
       }
     };
     final Result result = new Result(proxyRequestMock, response);
-    final StubServiceEmitter stubServiceEmitter = new StubServiceEmitter("", "");
+    final StubServiceEmitter stubServiceEmitter = StubServiceEmitter.createStarted();
     final AsyncQueryForwardingServlet servlet = new AsyncQueryForwardingServlet(
         new MapQueryToolChestWarehouse(ImmutableMap.of()),
         jsonMapper,
