@@ -36,6 +36,8 @@ import java.util.List;
  */
 public class EmbeddedHistorical extends EmbeddedDruidServer<EmbeddedHistorical>
 {
+  private long maxDiskSize = MEM_100_MB;
+
   public EmbeddedHistorical()
   {
     addBeforeStartHook((cluster, self) -> {
@@ -44,12 +46,18 @@ public class EmbeddedHistorical extends EmbeddedDruidServer<EmbeddedHistorical>
           StringUtils.format(
               "[{\"path\":\"%s\",\"maxSize\":\"%s\"}]",
               cluster.getTestFolder().newFolder().getAbsolutePath(),
-              MEM_100_MB
+              maxDiskSize
           )
       );
     });
   }
 
+  public EmbeddedHistorical setDiskSize(long maxDiskSize)
+  {
+    this.maxDiskSize = maxDiskSize;
+    return this;
+  }
+
   @Override
   protected ServerRunnable createRunnable(LifecycleInitHandler handler)
   {
