@@ -369,7 +369,7 @@ public class DruidExpression
 
   public String getDirectColumn()
   {
-    return Preconditions.checkNotNull(simpleExtraction.getColumn());
+    return Preconditions.checkNotNull(simpleExtraction, "simpleExtraction").getColumn();
   }
 
   public boolean isSimpleExtraction()
@@ -401,7 +401,7 @@ public class DruidExpression
       final ExpressionParser parser
   )
   {
-    return virtualColumnCreator.create(name, outputType, expression.get(), parser);
+    return virtualColumnCreator.create(name, outputType, parser, this);
   }
 
   public VirtualColumn toExpressionVirtualColumn(
@@ -410,7 +410,7 @@ public class DruidExpression
       final ExpressionParser parser
   )
   {
-    return DEFAULT_VIRTUAL_COLUMN_BUILDER.create(name, outputType, expression.get(), parser);
+    return DEFAULT_VIRTUAL_COLUMN_BUILDER.create(name, outputType, parser, this);
   }
 
   public NodeType getType()
@@ -418,6 +418,16 @@ public class DruidExpression
     return nodeType;
   }
 
+  /**
+   * Returns whether this expression is {@link NodeType#IDENTIFIER} or {@link NodeType#SPECIALIZED}. Useful because
+   * these are the expressions that can be expected to become direct column references once virtual columns have gone
+   * through a specialization pass.
+   */
+  public boolean isIdentifierOrSpecialized()
+  {
+    return nodeType == NodeType.IDENTIFIER || nodeType == NodeType.SPECIALIZED;
+  }
+
   /**
    * The {@link ColumnType} of this expression as inferred when this expression was created. This is likely the result
    * of converting the output of {@link org.apache.calcite.rex.RexNode#getType()} using
@@ -609,15 +619,28 @@ public class DruidExpression
   @FunctionalInterface
   public interface VirtualColumnCreator
   {
-    VirtualColumn create(String name, ColumnType outputType, String expression, ExpressionParser parser);
+    /**
+     * Create a virtual column for an expression.
+     *
+     * @param name       name of the virtual column
+     * @param outputType type of the virtual column
+     * @param parser     expression parser, if needed
+     * @param self       expression, possibly rewritten to refer to specialized virtual columns
+     */
+    VirtualColumn create(
+        String name,
+        ColumnType outputType,
+        ExpressionParser parser,
+        DruidExpression self
+    );
   }
 
   public static class ExpressionVirtualColumnCreator implements VirtualColumnCreator
   {
     @Override
-    public VirtualColumn create(String name, ColumnType outputType, String expression, ExpressionParser parser)
+    public VirtualColumn create(String name, ColumnType outputType, ExpressionParser parser, DruidExpression self)
     {
-      return new ExpressionVirtualColumn(name, expression, parser.parse(expression), outputType);
+      return new ExpressionVirtualColumn(name, self.getExpression(), parser.parse(self.getExpression()), outputType);
     }
   }
 }
