@@ -25,18 +25,12 @@ import com.fasterxml.jackson.annotation.JsonTypeName;
 import com.google.common.base.Preconditions;
 import org.apache.druid.data.input.InputFormat;
 import org.apache.druid.data.input.InputSource;
-import org.apache.druid.java.util.common.IAE;
-import org.apache.druid.query.DataSource;
-import org.apache.druid.query.Query;
-import org.apache.druid.query.planning.DataSourceAnalysis;
-import org.apache.druid.segment.SegmentReference;
+import org.apache.druid.query.LeafDataSource;
 import org.apache.druid.segment.column.RowSignature;
 
 import java.util.Collections;
-import java.util.List;
 import java.util.Objects;
 import java.util.Set;
-import java.util.function.Function;
 
 /**
  * Represents external data for INSERT queries. Only used by the SQL layer, not by the query stack.
@@ -47,7 +41,7 @@ import java.util.function.Function;
  * This class is exercised in CalciteInsertDmlTest but is not currently exposed to end users.
  */
 @JsonTypeName("external")
-public class ExternalDataSource implements DataSource
+public class ExternalDataSource extends LeafDataSource
 {
   private final InputSource inputSource;
   private final InputFormat inputFormat;
@@ -89,22 +83,6 @@ public class ExternalDataSource implements DataSource
     return Collections.emptySet();
   }
 
-  @Override
-  public List<DataSource> getChildren()
-  {
-    return Collections.emptyList();
-  }
-
-  @Override
-  public DataSource withChildren(final List<DataSource> children)
-  {
-    if (!children.isEmpty()) {
-      throw new IAE("Cannot accept children");
-    }
-
-    return this;
-  }
-
   @Override
   public boolean isCacheable(boolean isBroker)
   {
@@ -118,21 +96,9 @@ public class ExternalDataSource implements DataSource
   }
 
   @Override
-  public boolean isConcrete()
+  public boolean isProcessable()
   {
-    return false;
-  }
-
-  @Override
-  public Function<SegmentReference, SegmentReference> createSegmentMapFunction(Query query)
-  {
-    return Function.identity();
-  }
-
-  @Override
-  public DataSource withUpdatedDataSource(DataSource newSource)
-  {
-    return newSource;
+    return true;
   }
 
   @Override
@@ -141,12 +107,6 @@ public class ExternalDataSource implements DataSource
     return null;
   }
 
-  @Override
-  public DataSourceAnalysis getAnalysis()
-  {
-    return new DataSourceAnalysis(this, null, null, Collections.emptyList(), null);
-  }
-
   @Override
   public boolean equals(Object o)
   {
