@@ -46,11 +46,12 @@ import org.apache.calcite.sql.fun.SqlStdOperatorTable;
 import org.apache.calcite.sql.type.SqlTypeName;
 import org.apache.calcite.tools.RelBuilder;
 import org.apache.calcite.util.ImmutableBitSet;
-import org.apache.druid.common.config.NullHandling;
 import org.apache.druid.error.DruidException;
 import org.apache.druid.java.util.common.StringUtils;
+import org.apache.druid.query.JoinAlgorithm;
 import org.apache.druid.query.LookupDataSource;
 import org.apache.druid.sql.calcite.planner.PlannerContext;
+import org.apache.druid.sql.calcite.planner.QueryUtils;
 import org.apache.druid.sql.calcite.rel.DruidJoinQueryRel;
 import org.apache.druid.sql.calcite.rel.DruidQueryRel;
 import org.apache.druid.sql.calcite.rel.DruidRel;
@@ -130,7 +131,8 @@ public class DruidJoinRule extends RelOptRule
     plannerContext.setPlanningError(conditionAnalysis.errorStr);
     final boolean isLeftDirectAccessPossible = enableLeftScanDirect && (left instanceof DruidQueryRel);
 
-    if (!plannerContext.getJoinAlgorithm().requiresSubquery()
+    final JoinAlgorithm joinAlgorithm = QueryUtils.getJoinAlgorithm(join, plannerContext);
+    if (!joinAlgorithm.requiresSubquery()
         && left.getPartialDruidQuery().stage() == PartialDruidQuery.Stage.SELECT_PROJECT
         && (isLeftDirectAccessPossible || left.getPartialDruidQuery().getWhereFilter() == null)) {
       // Swap the left-side projection above the join, so the left side is a simple scan or mapping. This helps us
@@ -153,7 +155,7 @@ public class DruidJoinRule extends RelOptRule
       leftFilter = null;
     }
 
-    if (!plannerContext.getJoinAlgorithm().requiresSubquery()
+    if (!joinAlgorithm.requiresSubquery()
         && right.getPartialDruidQuery().stage() == PartialDruidQuery.Stage.SELECT_PROJECT
         && right.getPartialDruidQuery().getWhereFilter() == null
         && !right.getPartialDruidQuery().getSelectProject().isMapping()
@@ -270,14 +272,9 @@ public class DruidJoinRule extends RelOptRule
       }
     }
 
-    if (joinType != JoinRelType.INNER || !systemFieldList.isEmpty() || NullHandling.replaceWithDefault()) {
+    if (joinType != JoinRelType.INNER || !systemFieldList.isEmpty()) {
       // I am not sure in what case, the list of system fields will be not empty. I have just picked up this logic
       // directly from https://github.com/apache/calcite/blob/calcite-1.35.0/core/src/main/java/org/apache/calcite/rel/rules/AbstractJoinExtractFilterRule.java#L58
-
-      // Also to avoid results changes for existing queries in non-null handling mode, we don't handle unsupported
-      // conditions. Otherwise, some left/right joins with a condition that doesn't allow nulls on join input will
-      // be converted to inner joins. See Test CalciteJoinQueryTest#testFilterAndGroupByLookupUsingJoinOperatorBackwards
-      // for an example.
       return conditionAnalysis.getUnsupportedOnSubConditions().isEmpty();
     }
 
@@ -452,7 +449,7 @@ public class DruidJoinRule extends RelOptRule
     final List<RexNode> unSupportedSubConditions = new ArrayList<>();
     final Set<RexInputRef> rightColumns = new HashSet<>();
     final int numLeftFields = leftRowType.getFieldCount();
-    final List<String> errors = new ArrayList<String>();
+    final List<String> errors = new ArrayList<>();
 
     for (RexNode subCondition : subConditions) {
       if (RexUtil.isLiteral(subCondition, true)) {
