@@ -199,12 +199,14 @@ public class DruidPlannerResourceAnalyzeTest extends BaseCalciteQueryTest
     testSysTable("SELECT * FROM sys.server_segments", null, PLANNER_CONFIG_DEFAULT);
     testSysTable("SELECT * FROM sys.tasks", null, PLANNER_CONFIG_DEFAULT);
     testSysTable("SELECT * FROM sys.supervisors", null, PLANNER_CONFIG_DEFAULT);
+    testSysTable("SELECT * FROM sys.server_properties", null, PLANNER_CONFIG_DEFAULT);
 
     testSysTable("SELECT * FROM sys.segments", "segments", PLANNER_CONFIG_AUTHORIZE_SYS_TABLES);
     testSysTable("SELECT * FROM sys.servers", "servers", PLANNER_CONFIG_AUTHORIZE_SYS_TABLES);
     testSysTable("SELECT * FROM sys.server_segments", "server_segments", PLANNER_CONFIG_AUTHORIZE_SYS_TABLES);
     testSysTable("SELECT * FROM sys.tasks", "tasks", PLANNER_CONFIG_AUTHORIZE_SYS_TABLES);
     testSysTable("SELECT * FROM sys.supervisors", "supervisors", PLANNER_CONFIG_AUTHORIZE_SYS_TABLES);
+    testSysTable("SELECT * FROM sys.server_properties", "server_properties", PLANNER_CONFIG_AUTHORIZE_SYS_TABLES);
   }
 
   private void testSysTable(String sql, String name, PlannerConfig plannerConfig)
