@@ -28,6 +28,8 @@ import com.google.inject.Key;
 import com.google.inject.Scopes;
 import com.google.inject.TypeLiteral;
 import com.google.inject.name.Names;
+import org.apache.druid.catalog.MapMetadataCatalog;
+import org.apache.druid.catalog.MetadataCatalog;
 import org.apache.druid.client.FilteredServerInventoryView;
 import org.apache.druid.client.TimelineServerView;
 import org.apache.druid.client.coordinator.CoordinatorClient;
@@ -35,8 +37,10 @@ import org.apache.druid.client.coordinator.NoopCoordinatorClient;
 import org.apache.druid.discovery.DruidNodeDiscoveryProvider;
 import org.apache.druid.guice.LazySingleton;
 import org.apache.druid.guice.LifecycleModule;
+import org.apache.druid.guice.annotations.EscalatedClient;
 import org.apache.druid.guice.annotations.Json;
 import org.apache.druid.java.util.emitter.service.ServiceEmitter;
+import org.apache.druid.java.util.http.client.HttpClient;
 import org.apache.druid.query.lookup.LookupExtractorFactoryContainerProvider;
 import org.apache.druid.query.lookup.LookupReferencesManager;
 import org.apache.druid.rpc.indexing.NoopOverlordClient;
@@ -56,7 +60,7 @@ import org.apache.druid.sql.calcite.view.ViewManager;
 import org.easymock.EasyMock;
 import org.easymock.EasyMockExtension;
 import org.easymock.Mock;
-import org.junit.Assert;
+import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.extension.ExtendWith;
@@ -93,6 +97,8 @@ public class DruidCalciteSchemaModuleTest extends CalciteTestBase
   private SegmentManager segmentManager;
   @Mock
   private DruidOperatorTable druidOperatorTable;
+  @Mock
+  private HttpClient httpClient;
 
   private DruidCalciteSchemaModule target;
   private Injector injector;
@@ -120,11 +126,14 @@ public class DruidCalciteSchemaModuleTest extends CalciteTestBase
           binder.bindScope(LazySingleton.class, Scopes.SINGLETON);
           binder.bind(LookupExtractorFactoryContainerProvider.class).toInstance(lookupReferencesManager);
           binder.bind(CatalogResolver.class).toInstance(CatalogResolver.NULL_RESOLVER);
+          binder.bind(MetadataCatalog.class).toInstance(new MapMetadataCatalog(objectMapper));
           binder.bind(ServiceEmitter.class).toInstance(new ServiceEmitter("", "", null));
           binder.bind(OverlordClient.class).to(NoopOverlordClient.class);
           binder.bind(CoordinatorClient.class).to(NoopCoordinatorClient.class);
           binder.bind(CentralizedDatasourceSchemaConfig.class)
                 .toInstance(CentralizedDatasourceSchemaConfig.create());
+          binder.bind(HttpClient.class).toInstance(httpClient);
+          binder.bind(HttpClient.class).annotatedWith(EscalatedClient.class).toInstance(httpClient);
         },
         new LifecycleModule(),
         target);
@@ -134,35 +143,39 @@ public class DruidCalciteSchemaModuleTest extends CalciteTestBase
   public void testDruidSchemaNameIsInjected()
   {
     String schemaName = injector.getInstance(Key.get(String.class, DruidSchemaName.class));
-    Assert.assertEquals(DRUID_SCHEMA_NAME, schemaName);
+    Assertions.assertEquals(DRUID_SCHEMA_NAME, schemaName);
   }
 
   @Test
   public void testDruidSqlSchemaIsInjectedAsSingleton()
   {
     NamedDruidSchema namedDruidSchema = injector.getInstance(NamedDruidSchema.class);
-    Assert.assertNotNull(namedDruidSchema);
+    Assertions.assertNotNull(namedDruidSchema);
     NamedDruidSchema other = injector.getInstance(NamedDruidSchema.class);
-    Assert.assertSame(other, namedDruidSchema);
+    Assertions.assertSame(other, namedDruidSchema);
   }
 
   @Test
   public void testSystemSqlSchemaIsInjectedAsSingleton()
   {
     NamedSystemSchema namedSystemSchema = injector.getInstance(NamedSystemSchema.class);
-    Assert.assertNotNull(namedSystemSchema);
+    Assertions.assertNotNull(namedSystemSchema);
     NamedSystemSchema other = injector.getInstance(NamedSystemSchema.class);
-    Assert.assertSame(other, namedSystemSchema);
+    Assertions.assertSame(other, namedSystemSchema);
   }
 
   @Test
   public void testDruidCalciteSchemasAreInjected()
   {
     Set<NamedSchema> sqlSchemas = injector.getInstance(Key.get(new TypeLiteral<>() {}));
-    Set<Class<? extends NamedSchema>> expectedSchemas =
-        ImmutableSet.of(NamedSystemSchema.class, NamedDruidSchema.class, NamedLookupSchema.class, NamedViewSchema.class);
-    Assert.assertEquals(expectedSchemas.size(), sqlSchemas.size());
-    Assert.assertEquals(
+    Set<Class<? extends NamedSchema>> expectedSchemas = Set.of(
+        NamedSystemSchema.class,
+        NamedDruidSchema.class,
+        NamedLookupSchema.class,
+        NamedViewSchema.class
+    );
+    Assertions.assertEquals(expectedSchemas.size(), sqlSchemas.size());
+    Assertions.assertEquals(
         expectedSchemas,
         sqlSchemas.stream().map(NamedSchema::getClass).collect(Collectors.toSet()));
   }
@@ -171,36 +184,36 @@ public class DruidCalciteSchemaModuleTest extends CalciteTestBase
   public void testDruidSchemaIsInjectedAsSingleton()
   {
     DruidSchema schema = injector.getInstance(DruidSchema.class);
-    Assert.assertNotNull(schema);
+    Assertions.assertNotNull(schema);
     DruidSchema other = injector.getInstance(DruidSchema.class);
-    Assert.assertSame(other, schema);
+    Assertions.assertSame(other, schema);
   }
 
   @Test
   public void testSystemSchemaIsInjectedAsSingleton()
   {
     SystemSchema schema = injector.getInstance(SystemSchema.class);
-    Assert.assertNotNull(schema);
+    Assertions.assertNotNull(schema);
     SystemSchema other = injector.getInstance(SystemSchema.class);
-    Assert.assertSame(other, schema);
+    Assertions.assertSame(other, schema);
   }
 
   @Test
   public void testInformationSchemaIsInjectedAsSingleton()
   {
     InformationSchema schema = injector.getInstance(InformationSchema.class);
-    Assert.assertNotNull(schema);
+    Assertions.assertNotNull(schema);
     InformationSchema other = injector.getInstance(InformationSchema.class);
-    Assert.assertSame(other, schema);
+    Assertions.assertSame(other, schema);
   }
 
   @Test
   public void testLookupSchemaIsInjectedAsSingleton()
   {
     LookupSchema schema = injector.getInstance(LookupSchema.class);
-    Assert.assertNotNull(schema);
+    Assertions.assertNotNull(schema);
     LookupSchema other = injector.getInstance(LookupSchema.class);
-    Assert.assertSame(other, schema);
+    Assertions.assertSame(other, schema);
   }
 
   @Test
@@ -209,22 +222,22 @@ public class DruidCalciteSchemaModuleTest extends CalciteTestBase
     DruidSchemaCatalog rootSchema = injector.getInstance(
         Key.get(DruidSchemaCatalog.class, Names.named(DruidCalciteSchemaModule.INCOMPLETE_SCHEMA))
     );
-    Assert.assertNotNull(rootSchema);
+    Assertions.assertNotNull(rootSchema);
     DruidSchemaCatalog other = injector.getInstance(
         Key.get(DruidSchemaCatalog.class, Names.named(DruidCalciteSchemaModule.INCOMPLETE_SCHEMA))
     );
-    Assert.assertSame(other, rootSchema);
+    Assertions.assertSame(other, rootSchema);
   }
 
   @Test
   public void testRootSchemaIsInjectedAsSingleton()
   {
     DruidSchemaCatalog rootSchema = injector.getInstance(Key.get(DruidSchemaCatalog.class));
-    Assert.assertNotNull(rootSchema);
+    Assertions.assertNotNull(rootSchema);
     DruidSchemaCatalog other = injector.getInstance(
         Key.get(DruidSchemaCatalog.class, Names.named(DruidCalciteSchemaModule.INCOMPLETE_SCHEMA))
     );
-    Assert.assertSame(other, rootSchema);
+    Assertions.assertSame(other, rootSchema);
   }
 
   @Test
@@ -232,7 +245,7 @@ public class DruidCalciteSchemaModuleTest extends CalciteTestBase
   {
     DruidSchemaCatalog rootSchema = injector.getInstance(Key.get(DruidSchemaCatalog.class));
     InformationSchema expectedSchema = injector.getInstance(InformationSchema.class);
-    Assert.assertNotNull(rootSchema);
-    Assert.assertSame(expectedSchema, rootSchema.getSubSchema("INFORMATION_SCHEMA").unwrap(InformationSchema.class));
+    Assertions.assertNotNull(rootSchema);
+    Assertions.assertSame(expectedSchema, rootSchema.getSubSchema("INFORMATION_SCHEMA").unwrap(InformationSchema.class));
   }
 }
