@@ -26,6 +26,7 @@ import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.util.concurrent.Futures;
+import com.google.common.util.concurrent.ListenableFuture;
 import junitparams.converters.Nullable;
 import org.apache.calcite.DataContext;
 import org.apache.calcite.adapter.java.JavaTypeFactory;
@@ -64,9 +65,11 @@ import org.apache.druid.java.util.common.ISE;
 import org.apache.druid.java.util.common.Intervals;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.io.Closer;
+import org.apache.druid.java.util.http.client.HttpClient;
 import org.apache.druid.java.util.http.client.Request;
 import org.apache.druid.java.util.http.client.response.HttpResponseHandler;
 import org.apache.druid.java.util.http.client.response.InputStreamFullResponseHolder;
+import org.apache.druid.java.util.http.client.response.StringFullResponseHandler;
 import org.apache.druid.java.util.http.client.response.StringFullResponseHolder;
 import org.apache.druid.query.QueryRunnerFactoryConglomerate;
 import org.apache.druid.query.aggregation.CountAggregatorFactory;
@@ -111,8 +114,12 @@ import org.apache.druid.timeline.SegmentId;
 import org.apache.druid.timeline.SegmentStatusInCluster;
 import org.apache.druid.timeline.partition.NumberedShardSpec;
 import org.apache.druid.timeline.partition.ShardSpec;
+import org.apache.druid.utils.JvmUtils;
 import org.easymock.EasyMock;
+import org.jboss.netty.handler.codec.http.DefaultHttpResponse;
 import org.jboss.netty.handler.codec.http.HttpResponse;
+import org.jboss.netty.handler.codec.http.HttpResponseStatus;
+import org.jboss.netty.handler.codec.http.HttpVersion;
 import org.joda.time.DateTime;
 import org.junit.Assert;
 import org.junit.jupiter.api.AfterAll;
@@ -183,6 +190,7 @@ public class SystemSchemaTest extends CalciteTestBase
   private MetadataSegmentView metadataView;
   private DruidNodeDiscoveryProvider druidNodeDiscoveryProvider;
   private FilteredServerInventoryView serverInventoryView;
+  private HttpClient httpClient;
 
   @BeforeAll
   public static void setUpClass()
@@ -261,6 +269,7 @@ public class SystemSchemaTest extends CalciteTestBase
     metadataView = EasyMock.createMock(MetadataSegmentView.class);
     druidNodeDiscoveryProvider = EasyMock.createMock(DruidNodeDiscoveryProvider.class);
     serverInventoryView = EasyMock.createMock(FilteredServerInventoryView.class);
+    httpClient = EasyMock.createMock(HttpClient.class);
     schema = new SystemSchema(
         druidSchema,
         metadataView,
@@ -270,7 +279,8 @@ public class SystemSchemaTest extends CalciteTestBase
         coordinatorClient,
         overlordClient,
         druidNodeDiscoveryProvider,
-        MAPPER
+        MAPPER,
+        httpClient
     );
   }
 
@@ -381,6 +391,8 @@ public class SystemSchemaTest extends CalciteTestBase
   final List<DataSegment> realtimeSegments = ImmutableList.of(segment2, segment4, segment5);
 
   private final DateTime startTime = DateTimes.nowUtc();
+  private final long availableProcessors = Runtime.getRuntime().availableProcessors();
+  private final long totalMemory = JvmUtils.getTotalMemory();
 
   private final String version = GuavaUtils.firstNonNull(
           SystemSchemaTest.class.getPackage().getImplementationVersion(),
@@ -532,13 +544,13 @@ public class SystemSchemaTest extends CalciteTestBase
   public void testGetTableMap()
   {
     Assert.assertEquals(
-        ImmutableSet.of("segments", "servers", "server_segments", "tasks", "supervisors"),
+        ImmutableSet.of("segments", "servers", "server_segments", "tasks", "supervisors", "server_properties"),
         schema.getTableNames()
     );
 
     final Map<String, Table> tableMap = schema.getTableMap();
     Assert.assertEquals(
-        ImmutableSet.of("segments", "servers", "server_segments", "tasks", "supervisors"),
+        ImmutableSet.of("segments", "servers", "server_segments", "tasks", "supervisors", "server_properties"),
         tableMap.keySet()
     );
     final SystemSchema.SegmentsTable segmentsTable = (SystemSchema.SegmentsTable) schema.getTableMap().get("segments");
@@ -558,9 +570,15 @@ public class SystemSchemaTest extends CalciteTestBase
     final SystemSchema.ServersTable serversTable = (SystemSchema.ServersTable) schema.getTableMap().get("servers");
     final RelDataType serverRowType = serversTable.getRowType(new JavaTypeFactoryImpl());
     final List<RelDataTypeField> serverFields = serverRowType.getFieldList();
-    Assert.assertEquals(12, serverFields.size());
+    Assert.assertEquals(14, serverFields.size());
     Assert.assertEquals("server", serverFields.get(0).getName());
     Assert.assertEquals(SqlTypeName.VARCHAR, serverFields.get(0).getType().getSqlTypeName());
+
+    final SystemServerPropertiesTable propertiesTable = (SystemServerPropertiesTable) schema.getTableMap()
+                                                                                            .get("server_properties");
+    final RelDataType propertiesRowType = propertiesTable.getRowType(new JavaTypeFactoryImpl());
+    final List<RelDataTypeField> propertiesFields = propertiesRowType.getFieldList();
+    Assert.assertEquals(5, propertiesFields.size());
   }
 
   @Test
@@ -860,7 +878,9 @@ public class SystemSchemaTest extends CalciteTestBase
             nonLeader,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -876,7 +896,9 @@ public class SystemSchemaTest extends CalciteTestBase
             nonLeader,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -892,7 +914,9 @@ public class SystemSchemaTest extends CalciteTestBase
             nonLeader,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -908,7 +932,9 @@ public class SystemSchemaTest extends CalciteTestBase
             nonLeader,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -924,7 +950,9 @@ public class SystemSchemaTest extends CalciteTestBase
             nonLeader,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(createExpectedRow(
@@ -939,7 +967,9 @@ public class SystemSchemaTest extends CalciteTestBase
         nonLeader,
         startTimeStr,
         version,
-        null
+        null,
+        availableProcessors,
+        totalMemory
     ));
     expectedRows.add(
         createExpectedRow(
@@ -954,7 +984,9 @@ public class SystemSchemaTest extends CalciteTestBase
             1L,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -970,7 +1002,9 @@ public class SystemSchemaTest extends CalciteTestBase
             nonLeader,
             startTimeStr,
             version,
-            "{\"brokerKey\":\"brokerValue\",\"brokerKey2\":\"brokerValue2\"}"
+            "{\"brokerKey\":\"brokerValue\",\"brokerKey2\":\"brokerValue2\"}",
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -986,7 +1020,9 @@ public class SystemSchemaTest extends CalciteTestBase
             nonLeader,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -1002,7 +1038,9 @@ public class SystemSchemaTest extends CalciteTestBase
             1L,
             startTimeStr,
             version,
-            "{\"overlordKey\":\"overlordValue\"}"
+            "{\"overlordKey\":\"overlordValue\"}",
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -1018,7 +1056,9 @@ public class SystemSchemaTest extends CalciteTestBase
             0L,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -1034,7 +1074,9 @@ public class SystemSchemaTest extends CalciteTestBase
             0L,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -1050,7 +1092,9 @@ public class SystemSchemaTest extends CalciteTestBase
             nonLeader,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(
@@ -1066,7 +1110,9 @@ public class SystemSchemaTest extends CalciteTestBase
             nonLeader,
             startTimeStr,
             version,
-            null
+            null,
+            availableProcessors,
+            totalMemory
         )
     );
     expectedRows.add(createExpectedRow(
@@ -1081,7 +1127,9 @@ public class SystemSchemaTest extends CalciteTestBase
         nonLeader,
         startTimeStr,
         version,
-        null
+        null,
+        availableProcessors,
+        totalMemory
     ));
     Assert.assertEquals(expectedRows.size(), rows.size());
     for (int i = 0; i < rows.size(); i++) {
@@ -1116,7 +1164,9 @@ public class SystemSchemaTest extends CalciteTestBase
       @Nullable Long isLeader,
       String startTime,
       String version,
-      String labels
+      String labels,
+      long availableProcessors,
+      long totalMemory
   )
   {
     return new Object[]{
@@ -1131,7 +1181,9 @@ public class SystemSchemaTest extends CalciteTestBase
         isLeader,
         startTime,
         version,
-        labels
+        labels,
+        availableProcessors,
+        totalMemory
     };
   }
 
@@ -1448,6 +1500,111 @@ public class SystemSchemaTest extends CalciteTestBase
     // verifyTypes(rows, SystemSchema.SUPERVISOR_SIGNATURE);
   }
 
+  @Test
+  public void testPropertiesTable()
+  {
+    SystemServerPropertiesTable propertiesTable = EasyMock.createMockBuilder(SystemServerPropertiesTable.class)
+                                                          .withConstructor(druidNodeDiscoveryProvider, authMapper, httpClient, MAPPER)
+                                                          .createMock();
+
+    EasyMock.replay(propertiesTable);
+
+    List<Object[]> expectedRows = new ArrayList<>();
+
+    mockNodeDiscovery(NodeRole.BROKER);
+    mockNodeDiscovery(NodeRole.ROUTER);
+    mockNodeDiscovery(NodeRole.HISTORICAL);
+    mockNodeDiscovery(NodeRole.OVERLORD);
+    mockNodeDiscovery(NodeRole.PEON);
+    mockNodeDiscovery(NodeRole.INDEXER);
+
+    mockNodeDiscovery(NodeRole.COORDINATOR, coordinator, coordinator2);
+    HttpResponse coordinatorHttpResponse = new DefaultHttpResponse(HttpVersion.HTTP_1_1, HttpResponseStatus.OK);
+    StringFullResponseHolder coordinatorResponseHolder = new StringFullResponseHolder(coordinatorHttpResponse, StandardCharsets.UTF_8);
+    String coordinatorJson = "{\"druid.test-key\": \"test-value\"}";
+    coordinatorResponseHolder.addChunk(coordinatorJson);
+    expectedRows.add(new Object[]{
+        coordinator.getDruidNode().getHostAndPortToUse(),
+        coordinator.getDruidNode().getServiceName(),
+        ImmutableList.of(coordinator.getNodeRole().getJsonName()).toString(),
+        "druid.test-key", "test-value"
+    });
+
+    HttpResponse coordinator2HttpResponse = new DefaultHttpResponse(HttpVersion.HTTP_1_1, HttpResponseStatus.OK);
+    StringFullResponseHolder coordinator2ResponseHolder = new StringFullResponseHolder(coordinator2HttpResponse, StandardCharsets.UTF_8);
+    String coordinator2Json = "{\"druid.test-key3\": \"test-value3\"}";
+    coordinator2ResponseHolder.addChunk(coordinator2Json);
+    expectedRows
+        .add(new Object[]{
+            coordinator2.getDruidNode().getHostAndPortToUse(),
+            coordinator2.getDruidNode().getServiceName(),
+            ImmutableList.of(coordinator2.getNodeRole().getJsonName()).toString(),
+            "druid.test-key3", "test-value3"
+        });
+
+    mockNodeDiscovery(NodeRole.MIDDLE_MANAGER, middleManager);
+    HttpResponse middleManagerHttpResponse = new DefaultHttpResponse(HttpVersion.HTTP_1_1, HttpResponseStatus.OK);
+    StringFullResponseHolder middleManagerResponseHolder = new StringFullResponseHolder(middleManagerHttpResponse, StandardCharsets.UTF_8);
+    String middleManagerJson = "{\n"
+                               + "\"druid.test-key\": \"test-value\",\n"
+                               + "\"druid.test-key2\": \"test-value2\"\n"
+                               + "}";
+    middleManagerResponseHolder.addChunk(middleManagerJson);
+    expectedRows
+        .add(new Object[]{
+            middleManager.getDruidNode().getHostAndPortToUse(),
+            middleManager.getDruidNode().getServiceName(),
+            ImmutableList.of(middleManager.getNodeRole().getJsonName()).toString(),
+            "druid.test-key", "test-value"
+        });
+    expectedRows
+        .add(new Object[]{
+            middleManager.getDruidNode().getHostAndPortToUse(),
+            middleManager.getDruidNode().getServiceName(),  
+            ImmutableList.of(middleManager.getNodeRole().getJsonName()).toString(),
+            "druid.test-key2", "test-value2"
+        });
+
+    Map<String, ListenableFuture<StringFullResponseHolder>> urlToResponse = ImmutableMap.of(
+        getStatusPropertiesUrl(coordinator), Futures.immediateFuture(coordinatorResponseHolder),
+        getStatusPropertiesUrl(coordinator2), Futures.immediateFuture(coordinator2ResponseHolder),
+        getStatusPropertiesUrl(middleManager), Futures.immediateFuture(middleManagerResponseHolder)
+    );
+
+    EasyMock.expect(
+        httpClient.go(
+            EasyMock.isA(Request.class),
+            EasyMock.isA(StringFullResponseHandler.class)
+        )
+    ).andAnswer(() -> {
+      Request req = (Request) EasyMock.getCurrentArguments()[0];
+      String url = req.getUrl().toString();
+
+      ListenableFuture<StringFullResponseHolder> future = urlToResponse.get(url);
+      if (future != null) {
+        return future;
+      }
+      return Futures.immediateFailedFuture(new AssertionError("Unexpected URL: " + url));
+    }).times(3);
+
+    EasyMock.replay(druidNodeDiscoveryProvider, responseHandler, httpClient);
+
+    DataContext dataContext = createDataContext(Users.SUPER);
+    final List<Object[]> rows = propertiesTable.scan(dataContext).toList();
+    expectedRows.sort((Object[] row1, Object[] row2) -> ((Comparable) row1[0]).compareTo(row2[0]));
+    rows.sort((Object[] row1, Object[] row2) -> ((Comparable) row1[0]).compareTo(row2[0]));
+    Assert.assertEquals(expectedRows.size(), rows.size());
+    for (int i = 0; i < expectedRows.size(); i++) {
+      Assert.assertArrayEquals(expectedRows.get(i), rows.get(i));
+    }
+
+  }
+
+  private String getStatusPropertiesUrl(DiscoveryDruidNode discoveryDruidNode)
+  {
+    return discoveryDruidNode.getDruidNode().getUriToUse().resolve("/status/properties").toString();
+  }
+
   /**
    * Creates a response holder that contains the given json.
    */
@@ -1585,6 +1742,15 @@ public class SystemSchemaTest extends CalciteTestBase
     }
   }
 
+  private DruidNodeDiscovery mockNodeDiscovery(NodeRole nodeRole, DiscoveryDruidNode... discoveryDruidNodes)
+  {
+    final DruidNodeDiscovery druidNodeDiscovery = EasyMock.createMock(DruidNodeDiscovery.class);
+    EasyMock.expect(druidNodeDiscoveryProvider.getForNodeRole(nodeRole)).andReturn(druidNodeDiscovery).once();
+    EasyMock.expect(druidNodeDiscovery.getAllNodes()).andReturn(ImmutableList.copyOf(discoveryDruidNodes)).once();
+    EasyMock.replay(druidNodeDiscovery);
+    return druidNodeDiscovery;
+  }
+
   /**
    * Usernames to be used in tests.
    */
