@@ -16,7 +16,7 @@
  * limitations under the License.
  */
 
-import * as playwright from 'playwright-chromium';
+import type * as playwright from 'playwright-chromium';
 
 import { extractTable } from '../../util/table';
 
@@ -30,29 +30,29 @@ enum TaskColumn {
   GROUP_ID,
   TYPE,
   DATASOURCE,
-  LOCATION,
-  CREATED_TIME,
   STATUS,
+  CREATED_TIME,
   DURATION,
+  LOCATION,
 }
 
 /**
- * Represents ingestion overview tab.
+ * Represents task tab.
  */
-export class IngestionOverview {
+export class TasksOverview {
   private readonly page: playwright.Page;
   private readonly baseUrl: string;
 
   constructor(page: playwright.Page, unifiedConsoleUrl: string) {
     this.page = page;
-    this.baseUrl = unifiedConsoleUrl + '#ingestion';
+    this.baseUrl = unifiedConsoleUrl + '#tasks';
   }
 
   async getTasks(): Promise<IngestionTask[]> {
     await this.page.goto(this.baseUrl);
     await this.page.reload({ waitUntil: 'networkidle' });
 
-    const data = await extractTable(this.page, 'div.bottom-pane div.rt-tr-group', 'div.rt-td');
+    const data = await extractTable(this.page, 'div.rt-tr-group', 'div.rt-td');
 
     return data.map(
       row =>
