@@ -278,12 +278,15 @@ export const DOCTOR_CHECKS: DoctorCheck[] = [
   // Check SQL
   // -------------------------------------
   {
-    name: 'Verify that SQL works',
+    name: 'Verify that native SQL works',
     check: async controls => {
       // Make sure that we can run the simplest query
       let sqlResult: any[];
       try {
-        sqlResult = await queryDruidSql({ query: `SELECT 1 + 1 AS "two"` });
+        sqlResult = await queryDruidSql({
+          query: `SELECT 1 + 1 AS "two"`,
+          context: { engine: 'native' },
+        });
       } catch (e) {
         controls.addIssue(
           `Could not query SQL ensure that "druid.sql.enable" is set to "true" and that there is a Broker service running. Got: ${e.message}`,
@@ -310,6 +313,7 @@ export const DOCTOR_CHECKS: DoctorCheck[] = [
 FROM sys.servers
 WHERE "server_type" = 'historical'
 ORDER BY "fill" DESC`,
+          context: { engine: 'native' },
         });
         // Note: for some reason adding ` AND "curr_size" * 100.0 / "max_size" > 90` to the filter does not work as of this writing Apr 8, 2024
       } catch (e) {
@@ -367,6 +371,7 @@ FROM (
 )
 GROUP BY 1
 ORDER BY "num_bad_time_chunks"`,
+          context: { engine: 'native' },
         });
       } catch (e) {
         return;
