@@ -21,13 +21,14 @@ import * as JSONBig from 'json-bigint-native';
 import React, { useState } from 'react';
 import AceEditor from 'react-ace';
 
-import { validJson } from '../../utils';
+import { AppToaster } from '../../singletons';
+import { offsetToRowColumn } from '../../utils';
 
 import './spec-dialog.scss';
 
 export interface SpecDialogProps {
-  onSubmit: (spec: JSON) => void;
-  onClose: () => void;
+  onSubmit(spec: JSON): void | Promise<void>;
+  onClose(): void;
   title: string;
   initSpec?: any;
 }
@@ -38,9 +39,23 @@ export const SpecDialog = React.memo(function SpecDialog(props: SpecDialogProps)
     initSpec ? JSONBig.stringify(initSpec, undefined, 2) : '',
   );
 
-  function postSpec(): void {
-    if (!validJson(spec)) return;
-    onSubmit(JSON.parse(spec));
+  function handleSubmit(): void {
+    let parsed: any;
+    try {
+      parsed = JSONBig.parse(spec);
+    } catch (e) {
+      const rowColumn = typeof e.at === 'number' ? offsetToRowColumn(spec, e.at) : undefined;
+      AppToaster.show({
+        intent: Intent.DANGER,
+        message: `Could not parse JSON: ${e.message}${
+          rowColumn ? ` (at line ${rowColumn.row + 1}, column ${rowColumn.column + 1})` : ''
+        }`,
+        timeout: 5000,
+      });
+      return;
+    }
+
+    void onSubmit(parsed);
     onClose();
   }
 
@@ -55,7 +70,7 @@ export const SpecDialog = React.memo(function SpecDialog(props: SpecDialogProps)
       <AceEditor
         mode="hjson"
         theme="solarized_dark"
-        className="spec-dialog-textarea"
+        className="spec-dialog-textarea placeholder-padding"
         onChange={setSpec}
         fontSize={12}
         showPrintMargin={false}
@@ -66,19 +81,19 @@ export const SpecDialog = React.memo(function SpecDialog(props: SpecDialogProps)
         setOptions={{
           showLineNumbers: true,
           tabSize: 2,
+          newLineMode: 'unix' as any, // newLineMode is incorrectly assumed to be boolean in the typings
         }}
         style={{}}
         placeholder="{ JSON spec... }"
+        onLoad={editor => {
+          editor.renderer.setPadding(10);
+          editor.renderer.setScrollMargin(10, 10, 0, 0);
+        }}
       />
       <div className={Classes.DIALOG_FOOTER}>
         <div className={Classes.DIALOG_FOOTER_ACTIONS}>
           <Button text="Close" onClick={onClose} />
-          <Button
-            text="Submit"
-            intent={Intent.PRIMARY}
-            onClick={postSpec}
-            disabled={!validJson(spec)}
-          />
+          <Button text="Submit" intent={Intent.PRIMARY} onClick={handleSubmit} disabled={!spec} />
         </div>
       </div>
     </Dialog>
