@@ -287,6 +287,7 @@ describe('WorkbenchQuery', () => {
         engine: 'sql-native',
         query: {
           context: {
+            engine: 'native',
             sqlOuterLimit: 1001,
             sqlQueryId: 'deadbeef-9fb0-499c-8475-ea461e96a4fd',
             sqlStringifyArrays: false,
@@ -315,6 +316,7 @@ describe('WorkbenchQuery', () => {
         engine: 'sql-native',
         query: {
           context: {
+            engine: 'native',
             sqlOuterLimit: 1001,
             sqlQueryId: 'lol',
             sqlStringifyArrays: false,
@@ -354,6 +356,7 @@ describe('WorkbenchQuery', () => {
         engine: 'sql-native',
         query: {
           context: {
+            engine: 'native',
             sqlOuterLimit: 1001,
             sqlQueryId: 'deadbeef-9fb0-499c-8475-ea461e96a4fd',
             sqlStringifyArrays: false,
@@ -395,6 +398,7 @@ describe('WorkbenchQuery', () => {
         engine: 'sql-native',
         query: {
           context: {
+            engine: 'native',
             sqlOuterLimit: 1001,
             sqlQueryId: 'lol',
             sqlStringifyArrays: false,
@@ -410,6 +414,34 @@ describe('WorkbenchQuery', () => {
       });
     });
 
+    it('works with sql (preserves explicit engine context)', () => {
+      const sql = `SELECT * FROM wikipedia`;
+
+      const workbenchQuery = WorkbenchQuery.blank()
+        .changeQueryString(sql)
+        .changeQueryContext({ engine: 'msq-task' });
+
+      const apiQuery = workbenchQuery.getApiQuery(makeQueryId);
+      expect(apiQuery).toEqual({
+        cancelQueryId: 'deadbeef-9fb0-499c-8475-ea461e96a4fd',
+        engine: 'sql-native',
+        query: {
+          context: {
+            engine: 'msq-task',
+            sqlOuterLimit: 1001,
+            sqlQueryId: 'deadbeef-9fb0-499c-8475-ea461e96a4fd',
+            sqlStringifyArrays: false,
+          },
+          header: true,
+          query: 'SELECT * FROM wikipedia',
+          resultFormat: 'array',
+          sqlTypesHeader: true,
+          typesHeader: true,
+        },
+        prefixLines: 0,
+      });
+    });
+
     it('works with sql-task (as SQL string)', () => {
       const sql = `INSERT INTO wiki2 SELECT * FROM wikipedia`;
 
