@@ -16,9 +16,9 @@
  * limitations under the License.
  */
 
-import { sane } from 'druid-query-toolkit';
+import { C, sane } from 'druid-query-toolkit';
 
-import { findAllSqlQueriesInText, findSqlQueryPrefix } from './sql';
+import { findAllSqlQueriesInText, findSqlQueryPrefix, smartTimeFloor } from './sql';
 
 describe('sql', () => {
   describe('getSqlQueryPrefix', () => {
@@ -840,4 +840,92 @@ describe('sql', () => {
       `);
     });
   });
+
+  describe('smartTimeFloor', () => {
+    const timestampColumn = C('__time');
+
+    it('works with PT1H granularity in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT1H', true);
+      expect(result.toString()).toEqual(`TIME_FLOOR("__time", 'PT1H')`);
+    });
+
+    it('works with PT1H granularity not in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT1H', false);
+      expect(result.toString()).toEqual(`TIME_FLOOR("__time", 'PT1H')`);
+    });
+
+    it('aligns PT2H to day boundary when not in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT2H', false);
+      expect(result.toString()).toEqual(
+        `TIME_FLOOR("__time", 'PT2H', TIME_FLOOR("__time", 'P1D'))`,
+      );
+    });
+
+    it('does not align PT2H to day boundary when in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT2H', true);
+      expect(result.toString()).toEqual(`TIME_FLOOR("__time", 'PT2H')`);
+    });
+
+    it('aligns PT3H to day boundary when not in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT3H', false);
+      expect(result.toString()).toEqual(
+        `TIME_FLOOR("__time", 'PT3H', TIME_FLOOR("__time", 'P1D'))`,
+      );
+    });
+
+    it('aligns PT4H to day boundary when not in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT4H', false);
+      expect(result.toString()).toEqual(
+        `TIME_FLOOR("__time", 'PT4H', TIME_FLOOR("__time", 'P1D'))`,
+      );
+    });
+
+    it('aligns PT6H to day boundary when not in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT6H', false);
+      expect(result.toString()).toEqual(
+        `TIME_FLOOR("__time", 'PT6H', TIME_FLOOR("__time", 'P1D'))`,
+      );
+    });
+
+    it('aligns PT8H to day boundary when not in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT8H', false);
+      expect(result.toString()).toEqual(
+        `TIME_FLOOR("__time", 'PT8H', TIME_FLOOR("__time", 'P1D'))`,
+      );
+    });
+
+    it('aligns PT12H to day boundary when not in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT12H', false);
+      expect(result.toString()).toEqual(
+        `TIME_FLOOR("__time", 'PT12H', TIME_FLOOR("__time", 'P1D'))`,
+      );
+    });
+
+    it('aligns PT24H to day boundary when not in UTC', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT24H', false);
+      expect(result.toString()).toEqual(
+        `TIME_FLOOR("__time", 'PT24H', TIME_FLOOR("__time", 'P1D'))`,
+      );
+    });
+
+    it('does not align PT5H (non-divisor) to day boundary', () => {
+      const result = smartTimeFloor(timestampColumn, 'PT5H', false);
+      expect(result.toString()).toEqual(`TIME_FLOOR("__time", 'PT5H')`);
+    });
+
+    it('works with P1D granularity', () => {
+      const result = smartTimeFloor(timestampColumn, 'P1D', false);
+      expect(result.toString()).toEqual(`TIME_FLOOR("__time", 'P1D')`);
+    });
+
+    it('works with P1W granularity', () => {
+      const result = smartTimeFloor(timestampColumn, 'P1W', false);
+      expect(result.toString()).toEqual(`TIME_FLOOR("__time", 'P1W')`);
+    });
+
+    it('works with P1M granularity', () => {
+      const result = smartTimeFloor(timestampColumn, 'P1M', true);
+      expect(result.toString()).toEqual(`TIME_FLOOR("__time", 'P1M')`);
+    });
+  });
 });
