@@ -21,7 +21,6 @@ import { IconNames } from '@blueprintjs/icons';
 import { sum } from 'd3-array';
 import { SqlQuery, T } from 'druid-query-toolkit';
 import React from 'react';
-import type { Filter } from 'react-table';
 import ReactTable from 'react-table';
 
 import {
@@ -51,6 +50,7 @@ import type {
   CompactionConfigs,
   CompactionInfo,
   CompactionStatus,
+  ConsoleViewId,
   QueryWithContext,
   Rule,
 } from '../../druid-models';
@@ -94,6 +94,7 @@ import {
   twoLines,
 } from '../../utils';
 import type { BasicAction } from '../../utils/basic-action';
+import { TableFilter, TableFilters } from '../../utils/table-filters';
 
 import './datasources-view.scss';
 
@@ -304,16 +305,10 @@ function normalizeTaskType(taskType: string): string {
 }
 
 export interface DatasourcesViewProps {
-  filters: Filter[];
-  onFiltersChange(filters: Filter[]): void;
+  filters: TableFilters;
+  onFiltersChange(filters: TableFilters): void;
   goToQuery(queryWithContext: QueryWithContext): void;
-  goToTasks(datasource?: string): void;
-  goToSegments(options: {
-    start?: Date;
-    end?: Date;
-    datasource?: string;
-    realtime?: boolean;
-  }): void;
+  goToView(tab: ConsoleViewId, filters?: TableFilters): void;
   capabilities: Capabilities;
 }
 
@@ -446,7 +441,7 @@ GROUP BY 1, 2`;
         if (capabilities.hasSql()) {
           const query = DatasourcesView.query(visibleColumns);
           setIntermediateQuery(query);
-          datasources = await queryDruidSql({ query }, signal);
+          datasources = await queryDruidSql({ query, context: { engine: 'native' } }, signal);
         } else if (capabilities.hasCoordinatorAccess()) {
           const datasourcesResp = await getApiArray(
             '/druid/coordinator/v1/datasources?simple',
@@ -498,6 +493,7 @@ GROUP BY 1, 2`;
                 const runningTasks = await queryDruidSql<RunningTaskRow>(
                   {
                     query: DatasourcesView.RUNNING_TASK_SQL,
+                    context: { engine: 'native' },
                   },
                   signal,
                 );
@@ -1002,7 +998,7 @@ GROUP BY 1, 2`;
     rules: Rule[] | undefined,
     compactionInfo: CompactionInfo | undefined,
   ): BasicAction[] {
-    const { goToQuery, goToSegments, capabilities } = this.props;
+    const { goToQuery, goToView, capabilities } = this.props;
 
     if (unused) {
       if (!capabilities.hasOverlordAccess()) return [];
@@ -1045,7 +1041,7 @@ GROUP BY 1, 2`;
           icon: getConsoleViewIcon('segments'),
           title: 'Go to segments',
           onAction: () => {
-            goToSegments({ datasource });
+            goToView('segments', TableFilters.eq({ datasource }));
           },
         },
         capabilities.hasCoordinatorAccess()
@@ -1174,7 +1170,7 @@ GROUP BY 1, 2`;
   }
 
   private renderDatasourcesTable() {
-    const { goToTasks, capabilities, filters, onFiltersChange } = this.props;
+    const { goToView, capabilities, filters, onFiltersChange } = this.props;
     const { datasourcesAndDefaultRulesState, showUnused, visibleColumns, showSegmentTimeline } =
       this.state;
 
@@ -1219,8 +1215,8 @@ GROUP BY 1, 2`;
             : '')
         }
         filterable
-        filtered={filters}
-        onFilteredChange={onFiltersChange}
+        filtered={filters.toFilters()}
+        onFilteredChange={filters => onFiltersChange(TableFilters.fromFilters(filters))}
         defaultPageSize={STANDARD_TABLE_PAGE_SIZE}
         pageSizeOptions={STANDARD_TABLE_PAGE_SIZE_OPTIONS}
         showPagination={datasources.length > STANDARD_TABLE_PAGE_SIZE}
@@ -1364,7 +1360,9 @@ GROUP BY 1, 2`;
               if (!runningTasks) return;
               return (
                 <TableClickableCell
-                  onClick={() => goToTasks(original.datasource)}
+                  onClick={() =>
+                    goToView('tasks', TableFilters.eq({ datasource: original.datasource }))
+                  }
                   hoverIcon={IconNames.ARROW_TOP_RIGHT}
                   tooltip="Go to tasks"
                 >
@@ -1719,7 +1717,7 @@ GROUP BY 1, 2`;
   }
 
   render() {
-    const { capabilities, filters, goToSegments } = this.props;
+    const { capabilities, filters, goToView } = this.props;
     const {
       showUnused,
       visibleColumns,
@@ -1751,9 +1749,9 @@ GROUP BY 1, 2`;
                   ? undefined
                   : {
                       capabilities,
-                      datasource: findMap(filters, filter =>
-                        filter.id === 'datasource' && /^=[^=|]+$/.exec(String(filter.value))
-                          ? filter.value.slice(1)
+                      datasource: findMap(filters.toArray(), filter =>
+                        filter.key === 'datasource' && filter.mode === '='
+                          ? filter.value
                           : undefined,
                       ),
                     },
@@ -1791,7 +1789,28 @@ GROUP BY 1, 2`;
                     text="Open in segments view"
                     small
                     rightIcon={IconNames.ARROW_TOP_RIGHT}
-                    onClick={() => goToSegments({ start, end, datasource, realtime })}
+                    onClick={() => {
+                      let filters = TableFilters.empty();
+                      if (datasource) {
+                        filters = filters.addOrUpdate(
+                          new TableFilter('datasource', '=', datasource),
+                        );
+                      }
+                      if (realtime !== undefined) {
+                        filters = filters.addOrUpdate(
+                          new TableFilter('is_realtime', '=', String(realtime ? 1 : 0)),
+                        );
+                      }
+                      if (start && end) {
+                        filters = filters.addOrUpdate(
+                          new TableFilter('start', '>=', start.toISOString()),
+                        );
+                        filters = filters.addOrUpdate(
+                          new TableFilter('end', '<=', end.toISOString()),
+                        );
+                      }
+                      goToView('segments', filters);
+                    }}
                   />
                 );
               }}
