@@ -17,12 +17,15 @@
  */
 
 import { shallow } from '../../utils/shallow-renderer';
+import { TableFilters } from '../../utils/table-filters';
 
 import { LookupsView } from './lookups-view';
 
 describe('LookupsView', () => {
   it('matches snapshot', () => {
-    const lookupsView = shallow(<LookupsView filters={[]} onFiltersChange={() => {}} />);
+    const lookupsView = shallow(
+      <LookupsView filters={TableFilters.empty()} onFiltersChange={() => {}} />,
+    );
     expect(lookupsView).toMatchSnapshot();
   });
 });
