@@ -23,7 +23,7 @@ import { C, L, SqlComparison, SqlExpression } from 'druid-query-toolkit';
 import * as JSONBig from 'json-bigint-native';
 import type { ReactNode } from 'react';
 import React from 'react';
-import type { Filter, SortingRule } from 'react-table';
+import type { SortingRule } from 'react-table';
 import ReactTable from 'react-table';
 
 import {
@@ -49,11 +49,7 @@ import type { QueryContext, QueryWithContext, ShardSpec } from '../../druid-mode
 import { computeSegmentTimeSpan, getConsoleViewIcon, getDatasourceColor } from '../../druid-models';
 import type { Capabilities, CapabilitiesMode } from '../../helpers';
 import {
-  booleanCustomTableFilter,
   BooleanFilterInput,
-  combineModeAndNeedle,
-  parseFilterModeAndNeedle,
-  sqlQueryCustomTableFilter,
   STANDARD_TABLE_PAGE_SIZE,
   STANDARD_TABLE_PAGE_SIZE_OPTIONS,
 } from '../../react-table';
@@ -83,6 +79,7 @@ import {
   twoLines,
 } from '../../utils';
 import type { BasicAction } from '../../utils/basic-action';
+import { TableFilter, TableFilters } from '../../utils/table-filters';
 
 import './segments-view.scss';
 
@@ -158,52 +155,47 @@ function formatRangeDimensionValue(dimension: any, value: any): string {
   return `${C(String(dimension))}=${L(String(value))}`;
 }
 
-function segmentFiltersToExpression(filters: Filter[]): SqlExpression {
+function segmentFiltersToExpression(filters: TableFilters): SqlExpression {
   return SqlExpression.and(
-    ...filterMap(filters, filter => {
-      if (filter.id === 'start' || filter.id === 'end') {
+    ...filterMap(filters.toArray(), filter => {
+      if (filter.key === 'start' || filter.key === 'end') {
         // Dates need to be converted to ISO string for the SQL query
-        const modeAndNeedle = parseFilterModeAndNeedle(filter);
-        if (!modeAndNeedle) return;
-        if (modeAndNeedle.mode === '~') {
-          return sqlQueryCustomTableFilter(filter);
+        if (filter.mode === '~') {
+          return filter.toSqlExpression();
+        }
+        try {
+          const formattedDate = formatDate(filter.value);
+          const filterDate = dayjs(formattedDate).toISOString();
+          const internalFilter = new TableFilter(filter.key, filter.mode, filterDate);
+          return internalFilter.toSqlExpression();
+        } catch {
+          return filter.toSqlExpression();
         }
-        const internalFilter = { ...filter };
-        const formattedDate = formatDate(modeAndNeedle.needle);
-        const filterDate = dayjs(formattedDate).toISOString();
-        filter.value = combineModeAndNeedle(modeAndNeedle.mode, formattedDate);
-        internalFilter.value = combineModeAndNeedle(modeAndNeedle.mode, filterDate);
-        return sqlQueryCustomTableFilter(internalFilter);
       }
-      if (filter.id === 'shard_type') {
+      if (filter.key === 'shard_type') {
         // Special handling for shard_type that needs to be searched for in the shard_spec
         // Creates filters like `shard_spec LIKE '%"type":"numbered"%'`
-        const modeAndNeedle = parseFilterModeAndNeedle(filter);
-        if (!modeAndNeedle) return;
         const shardSpecColumn = C('shard_spec');
-        switch (modeAndNeedle.mode) {
+        switch (filter.mode) {
           case '=':
-            return SqlComparison.like(shardSpecColumn, `%"type":"${modeAndNeedle.needle}"%`);
+            return SqlComparison.like(shardSpecColumn, `%"type":"${filter.value}"%`);
 
           case '!=':
-            return SqlComparison.notLike(shardSpecColumn, `%"type":"${modeAndNeedle.needle}"%`);
+            return SqlComparison.notLike(shardSpecColumn, `%"type":"${filter.value}"%`);
 
           default:
-            return SqlComparison.like(shardSpecColumn, `%"type":"${modeAndNeedle.needle}%`);
+            return SqlComparison.like(shardSpecColumn, `%"type":"${filter.value}%`);
         }
-      } else if (filter.id.startsWith('is_')) {
-        switch (filter.value) {
-          case '=false':
-            return C(filter.id).equal(0);
-
-          case '=true':
-            return C(filter.id).equal(1);
-
-          default:
-            return;
+      } else if (filter.key.startsWith('is_')) {
+        if (filter.mode === '=' && filter.value === 'false') {
+          return C(filter.key).equal(0);
+        } else if (filter.mode === '=' && filter.value === 'true') {
+          return C(filter.key).equal(1);
+        } else {
+          return;
         }
       } else {
-        return sqlQueryCustomTableFilter(filter);
+        return filter.toSqlExpression();
       }
     }),
   );
@@ -242,8 +234,8 @@ interface SegmentsWithAuxiliaryInfo {
 }
 
 export interface SegmentsViewProps {
-  filters: Filter[];
-  onFiltersChange(filters: Filter[]): void;
+  filters: TableFilters;
+  onFiltersChange(filters: TableFilters): void;
   goToQuery(queryWithContext: QueryWithContext): void;
   capabilities: Capabilities;
 }
@@ -347,7 +339,7 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
           const orderByClause = sortedToOrderByClause(effectiveSorted);
 
           let queryParts: string[];
-          const sqlQueryContext: QueryContext = {};
+          const sqlQueryContext: QueryContext = { engine: 'native' };
           if (groupByInterval) {
             const innerQuery = compact([
               `SELECT "start", "end"`,
@@ -360,7 +352,9 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
               page ? `OFFSET ${page * pageSize}` : undefined,
             ]).join('\n');
 
-            const intervals: string = (await queryDruidSql({ query: innerQuery }))
+            const intervals: string = (
+              await queryDruidSql({ query: innerQuery, context: { engine: 'native' } })
+            )
               .map(({ start, end }) => `'${start}/${end}'`)
               .join(', ');
 
@@ -411,6 +405,7 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
               await queryDruidSql<{ cnt: number }>(
                 {
                   query: sqlQuery,
+                  context: { engine: 'native' },
                 },
                 signal,
               )
@@ -422,13 +417,11 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
           });
         } else if (capabilities.hasCoordinatorAccess()) {
           let datasourceList: string[] = [];
-          const datasourceFilter = filtered.find(({ id }) => id === 'datasource');
+          const datasourceFilter = filtered.toArray().find(({ key }) => key === 'datasource');
           if (datasourceFilter) {
             datasourceList = (
               await getApiArray('/druid/coordinator/v1/metadata/datasources', signal)
-            ).filter((datasource: string) =>
-              booleanCustomTableFilter(datasourceFilter, datasource),
-            );
+            ).filter((datasource: string) => datasourceFilter.matches(datasource));
           }
 
           let results = (
@@ -462,13 +455,10 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
             };
           });
 
-          if (filtered.length) {
+          if (filtered.toArray().length) {
             results = results.filter((d: SegmentQueryResultRow) => {
-              return filtered.every(filter => {
-                return booleanCustomTableFilter(
-                  filter,
-                  d[filter.id as keyof SegmentQueryResultRow],
-                );
+              return filtered.toArray().every(filter => {
+                return filter.matches(d[filter.key as keyof SegmentQueryResultRow]);
               });
             });
           }
@@ -548,7 +538,7 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
     });
   };
 
-  private readonly handleFilterChange = (filters: Filter[]) => {
+  private readonly handleFilterChange = (filters: TableFilters) => {
     this.goToFirstPage();
     this.props.onFiltersChange(filters);
   };
@@ -637,9 +627,7 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
     // Only allow filtering of columns other than datasource if in SQL mode, or if we are filtering on an exact datasource
     const allowGeneralFilter =
       hasSql ||
-      filters.some(
-        filter => filter.id === 'datasource' && parseFilterModeAndNeedle(filter)?.mode === '=',
-      );
+      filters.toArray().some(filter => filter.key === 'datasource' && filter.mode === '=');
 
     return (
       <ReactTable
@@ -648,13 +636,13 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
         loading={segmentsState.loading}
         noDataText={
           segmentsState.isEmpty()
-            ? `No segments${filters.length ? ' matching filter' : ''}`
+            ? `No segments${filters.toArray().length ? ' matching filter' : ''}`
             : segmentsState.getErrorMessage() || ''
         }
         manual
         filterable
-        filtered={filters}
-        onFilteredChange={this.handleFilterChange}
+        filtered={filters.toFilters()}
+        onFilteredChange={filters => this.handleFilterChange(TableFilters.fromFilters(filters))}
         sorted={sorted}
         onSortedChange={sorted => this.setState({ sorted })}
         page={page}
@@ -743,8 +731,13 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
             show: visibleColumns.shown('Time span'),
             id: 'time_span',
             className: 'padded',
-            accessor: ({ start, end }) =>
-              computeSegmentTimeSpan(dayjs(start).toISOString(), dayjs(end).toISOString()),
+            accessor: ({ start, end }) => {
+              try {
+                return computeSegmentTimeSpan(dayjs(start).toISOString(), dayjs(end).toISOString());
+              } catch {
+                return 'Invalid start or end';
+              }
+            },
             width: 100,
             sortable: false,
             filterable: false,
@@ -1135,9 +1128,9 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
                   ? undefined
                   : {
                       capabilities,
-                      datasource: findMap(filters, filter =>
-                        filter.id === 'datasource' && /^=[^=|]+$/.exec(String(filter.value))
-                          ? filter.value.slice(1)
+                      datasource: findMap(filters.toArray(), filter =>
+                        filter.key === 'datasource' && filter.mode === '='
+                          ? filter.value
                           : undefined,
                       ),
                     },
@@ -1175,21 +1168,33 @@ export class SegmentsView extends React.PureComponent<SegmentsViewProps, Segment
               getIntervalActionButton={(start, end, datasource, realtime) => {
                 return (
                   <Button
-                    text="Apply fitler to table"
+                    text="Apply filter to table"
                     small
                     rightIcon={IconNames.ARROW_DOWN}
-                    onClick={() =>
-                      this.handleFilterChange(
-                        compact([
-                          start && { id: 'start', value: `>=${start.toISOString()}` },
-                          end && { id: 'end', value: `<${end.toISOString()}` },
-                          datasource && { id: 'datasource', value: `=${datasource}` },
-                          typeof realtime === 'boolean'
-                            ? { id: 'is_realtime', value: `=${realtime}` }
-                            : undefined,
-                        ]),
-                      )
-                    }
+                    onClick={() => {
+                      let filters = TableFilters.empty();
+                      if (start) {
+                        filters = filters.addOrUpdate(
+                          new TableFilter('start', '>=', start.toISOString()),
+                        );
+                      }
+                      if (end) {
+                        filters = filters.addOrUpdate(
+                          new TableFilter('end', '<', end.toISOString()),
+                        );
+                      }
+                      if (datasource) {
+                        filters = filters.addOrUpdate(
+                          new TableFilter('datasource', '=', datasource),
+                        );
+                      }
+                      if (typeof realtime === 'boolean') {
+                        filters = filters.addOrUpdate(
+                          new TableFilter('is_realtime', '=', String(realtime)),
+                        );
+                      }
+                      this.handleFilterChange(filters);
+                    }}
                   />
                 );
               }}
