@@ -18,6 +18,7 @@
 
 import { Capabilities } from '../../helpers';
 import { shallow } from '../../utils/shallow-renderer';
+import { TableFilters } from '../../utils/table-filters';
 
 import { SupervisorsView } from './supervisors-view';
 
@@ -25,13 +26,12 @@ describe('SupervisorsView', () => {
   it('matches snapshot', () => {
     const taskView = shallow(
       <SupervisorsView
-        filters={[]}
+        filters={TableFilters.empty()}
         onFiltersChange={() => {}}
         openSupervisorDialog={undefined}
-        goToDatasource={() => {}}
+        goToView={() => {}}
         goToQuery={() => {}}
         goToStreamingDataLoader={() => {}}
-        goToTasks={() => {}}
         capabilities={Capabilities.FULL}
       />,
     );
